@@ -44,7 +44,7 @@ When we come back from composing, we want set game mode back to origin.
 */
 static int previous_game_mode = -1;
 
-void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties);
+void cupboard_door_clicked(TangleActor* actor, gpointer data);
 
 /*
 It suppose filenames are formatted in this way (will seg fault if not).
@@ -210,7 +210,7 @@ return FALSE;
 }
 
 static void mentor_over(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer sequencer){
-cupboard_door_clicked(NULL,NULL,NULL,NULL);
+	cupboard_door_clicked(NULL,NULL);
 }
 
 /*
@@ -239,11 +239,9 @@ static gboolean load_icons_from_disk (gpointer data){
 		}
 
 	//Scrolling area for icons
-	ClutterActor* scrolling_actor = NULL;
-
-	ClutterActor* container_for_saved_icons;
-	container_for_saved_icons = tangle_widget_new();
-	clutter_actor_set_size(container_for_saved_icons, 210.0, 1800.0);
+	ClutterActor* container_for_saved_icons = jammo_get_actor_by_id("cupboard-container-for-icons");
+	clutter_container_foreach(CLUTTER_CONTAINER(container_for_saved_icons), CLUTTER_CALLBACK(clutter_actor_hide), NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(container_for_saved_icons), CLUTTER_CALLBACK(clutter_actor_destroy), NULL);
 
 	//Load compositions
 	GList* files = file_helper_get_all_files(configure_get_compositions_directory());
@@ -262,7 +260,7 @@ static gboolean load_icons_from_disk (gpointer data){
 		if (icon_filename==NULL)  //probably folder
 			continue;
 		gchar* icon_filename_with_path = tangle_lookup_filename(icon_filename);
-		ClutterActor* image = clutter_texture_new_from_file(icon_filename_with_path, NULL);
+		ClutterActor* image = tangle_texture_new(icon_filename_with_path);
 		g_free(icon_filename_with_path);
 		if (image) { //If filename is missing, suppose whole file is corrupted and do not add it
 			icon = tangle_button_new_with_background_actor(image);
@@ -390,23 +388,26 @@ static gboolean load_icons_from_disk (gpointer data){
 		int i;
 		for (i=0;i<counter;i++)
 			{
-			ClutterActor* b_icon = tangle_button_new_with_background_actors(clutter_texture_new_from_file("/opt/jammo/cupboard_shelf.png", NULL), clutter_texture_new_from_file("/opt/jammo/cupboard_shelf.png", NULL));
+			ClutterActor* b_icon = tangle_button_new_with_background_actors(tangle_texture_new("/opt/jammo/cupboard_shelf.png"), tangle_texture_new("/opt/jammo/cupboard_shelf.png"));
 			g_object_set(b_icon,"depth-position", -2, "width", 290.0, "height", 94.0, "x", 0.0,  "y", -1+i*94.0, NULL);
 			clutter_container_add(CLUTTER_CONTAINER(container_for_saved_icons), b_icon, NULL);
 			}
 
 
-		//Tune size of container
-		clutter_actor_set_size(container_for_saved_icons, 310.0, counter*94.0);
 
+	//Check is there need for scrolling at all:
+	TangleLayout* layout = tangle_widget_get_layout(TANGLE_WIDGET(container_for_saved_icons));
+	GList* trick_list = tangle_layout_get_tricks(layout);
+	ClutterActor* trick = trick_list->data;
+
+	if (counter*94.0>376.0) {
+			g_object_set(trick,"axis",TANGLE_SCROLL_Y_AXIS,NULL);
+		}
+	else {
+		g_object_set(trick,"axis",TANGLE_SCROLL_NO_AXIS,NULL);
+	}
+	g_list_free(trick_list);
 
-	//Scrolling area for icons
-	scrolling_actor = tangle_scrolling_actor_new(container_for_saved_icons);
-	clutter_actor_set_position(scrolling_actor,  210.0, 65.0);
-	
-	clutter_actor_set_size(scrolling_actor, 310.0, counter*94.0<376.0?counter*94.0:376.0);
-	g_object_set(scrolling_actor,"depth-position", -1,NULL);
-	clutter_container_add_actor(CLUTTER_CONTAINER(jammo_get_actor_by_id("cupboard-view")), scrolling_actor);
 
 	clutter_actor_hide(jammo_get_actor_by_id("wait"));
 	jammo_mentor_speak_once_with_callback(jammo_mentor_get_default(),"cupboard_welcome.spx",mentor_over,NULL);
@@ -416,8 +417,8 @@ static gboolean load_icons_from_disk (gpointer data){
 
 
 
-//This is callback for json.
-void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+//This is callback for json. @show-completed
+void cupboard_start_cupboard(TangleActor* actor, gpointer data){
 	cem_add_to_log("cupboard_start_cupboard",J_LOG_DEBUG);
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), ""); //If it takes too long to load
 	ClutterActor* hourglass = jammo_get_actor_by_id("wait");
@@ -426,7 +427,7 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 }
 
 //This is callback for json.
-void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+void cupboard_door_clicked(TangleActor* tangle_actor, gpointer data){
 	cem_add_to_log("cupboard_door_clicked",J_LOG_USER_ACTION);
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	ClutterActor* actor;
