@@ -20,8 +20,10 @@
 #include "../../cem/cem.h"
 static int x_place_for_icon = 0; //Used when making icons for save-menu
 
+//slot=beat. bar=4*beat
+#define WIDTH_OF_BEAT 10.0
+
 
-#define WIDTH_OF_SLOT 40.0
 static gdouble phasing(gdouble start_value, int phase) {
 	gdouble value = start_value;
 	value += phase/100.0;
@@ -311,10 +313,10 @@ static ClutterActor* create_soundfamily_button(jammo_theme* theme, const gchar*
 
 /*
 Make colored rectangles and add them to given parent.
-Returns number of used slots (length of color_coding).
-white=# because it has special meaning. Samples can't be dropped on this slot. (TODO)
+Returns number of used bars (length of color_coding).
+white='#', because it has special meaning. Samples can't be dropped on this bar.
 */
-static ClutterActor* create_backing_track_color_bar(const gchar* color_coding, gfloat slot_size, gfloat y_offset) {
+static ClutterActor* create_backing_track_color_bar(const gchar* color_coding, gfloat bar_size, gfloat y_offset) {
 	ClutterActor* actor;
 	ClutterColor white  = { 255,255,255,   255 };
 	ClutterColor yellow = { 255, 255, 0,   255 };
@@ -348,7 +350,7 @@ static ClutterActor* create_backing_track_color_bar(const gchar* color_coding, g
 			}
 
 		tangle_widget_set_background_color(TANGLE_WIDGET(actor), color);
-		g_object_set(actor, "width", slot_size, "height", 40.0, "x", i* slot_size, "y", 80.0+y_offset, NULL);
+		g_object_set(actor, "width", bar_size, "height", 40.0, "x", i* bar_size, "y", 80.0+y_offset, NULL);
 		clutter_container_add_actor(CLUTTER_CONTAINER(parent), actor);
 		}
 	return parent;
@@ -503,8 +505,8 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	const gchar* background_color_code = "some_default";
 	const gchar* backing_track_filepath = "no_any_backing_track";
 
-	int disabled_slots_for_begin = 0;
-	int disabled_slots_for_end = 0;
+	int disabled_bars_for_begin = 0;
+	int disabled_bars_for_end = 0;
 	int tempo_factory = 4;    //4 is default
 	int beats_per_minute=90; //This value should be overwritten.
 
@@ -523,8 +525,8 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	create_samplebutton("fantasy","140","witch.png",   "castle_140_melody_2.wav",       545.0,  31.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
 
 	background_color_code = "#yyyyyyyyppppppppyyyyyyyypppppppp###";
-	disabled_slots_for_begin = 1;
-	disabled_slots_for_end = 3;
+	disabled_bars_for_begin = 1;
+	disabled_bars_for_end = 3;
 	}
 	else if (strncmp(name,"fantasy",7)==0 && variation==2){
 	create_samplebutton("fantasy","110","dragon.png","castle_110_clarinet_4.wav",      221.0,  39.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
@@ -535,7 +537,7 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	create_samplebutton("fantasy","110","wolf.png",  "castle_110_wolf_4.wav",           81.0, 274.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
 
 	background_color_code = "bbbbbbbbbbbbbbbbrrrrrrrrvvvvvvvvbbbbbbbb##";
-	disabled_slots_for_end = 2;
+	disabled_bars_for_end = 2;
 	tempo_factory = 3;
 	}
 	else if (strncmp(name,"fantasy",7)==0 && variation==3){
@@ -559,7 +561,7 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	create_samplebutton("city","140","motorcycle.png", "city_140_guitar2_2.wav",     306.0, 205.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
 
 	background_color_code = "yyyyyyyybbyyyyyyyybbgggggggbyyyyyyyy##";
-	disabled_slots_for_end = 2;
+	disabled_bars_for_end = 2;
 	}
 	else if (strncmp(name,"city",4)==0 && variation==2){
 	create_samplebutton("city","110",  "beatbox.png", "city_110_beatbox_1.wav",       594.0, 169.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
@@ -570,7 +572,7 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	create_samplebutton("city","110",  "zeppelin.png","city_110_bass_strings_2.wav",  299.0,   0.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
 
 	background_color_code = "bbbbbbbbrrrrbbbbrrrrbbbbrrrr##";
-	disabled_slots_for_end = 2;
+	disabled_bars_for_end = 2;
 	}
 	else if (strncmp(name,"city",4)==0 && variation==3){
 	create_samplebutton("city","90",  "car.png",         "city_90_bass_shaker_2.wav",  286.0, 183.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
@@ -581,7 +583,7 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	create_samplebutton("city","90",  "ufo.png",         "city_90_fx_2.wav",           264.0,  11.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
 
 	background_color_code = "ggggggggyyyyllllgggggggg##";
-	disabled_slots_for_end = 2;
+	disabled_bars_for_end = 2;
 	}
 
 	else if (strncmp(name,"animal",6)==0 && variation==1){
@@ -603,7 +605,7 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	create_samplebutton("animal","110",  "spider.png",      "animalw_110_pluck_2.wav",       617.0, 222.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
 
 	background_color_code = "ggggggggbbbbbbbbgggggggg#";
-	disabled_slots_for_end = 1;
+	disabled_bars_for_end = 1;
 	}
 	else if (strncmp(name,"animal",6)==0 && variation==3){
 	create_samplebutton("animal","90",  "bluebird.png",  "animalw_90_accordion2_2.wav",      533.0,  68.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
@@ -614,7 +616,7 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	create_samplebutton("animal","90",  "monkey.png"    ,"animalw_90_percussion_2.wav",      328.0,  30.0,theme, TANGLE_WIDGET(save_menu_container),TANGLE_WIDGET(view));
 
 	background_color_code = "yyyyyyyyggggggggoooooooo##";
-	disabled_slots_for_end = 2;
+	disabled_bars_for_end = 2;
 	}
 
 	} //easy game
@@ -673,7 +675,7 @@ else { //advanced
 		{
 		background_color_code = "vvvvbbbbvvvvbbbbvvvvbbbbllllvvvvvvvv####";  //'synth'
 		tempo_factory=3;
-		disabled_slots_for_end = 3;
+		disabled_bars_for_end = 3;
 		}
 	beats_per_minute = 90;  //All advanced fantasy variations use same set of samples, so they have same bpm
 	}
@@ -709,7 +711,8 @@ else { //advanced
 
 	if (variation==1)
 		{
-		background_color_code = "ggggyyyyvvvvyyyygggggggg#"; //'drumming/percussion'  //this is one slot shorter than another tracks!
+		//this is one bar shorter than another animal advanced tracks!
+		background_color_code = "ggggyyyyvvvvyyyygggggggg#"; //'drumming/percussion'
 		tempo_factory=5;
 		}
 	if (variation==2)
@@ -723,7 +726,7 @@ else { //advanced
 		tempo_factory=5;
 		}
 
-	disabled_slots_for_end = 2; //each variations has same
+	disabled_bars_for_end = 2; //each variations has same
 	beats_per_minute = 110;  //All advanced animal variations use same set of samples, so they have same bpm
 	}
 
@@ -773,7 +776,7 @@ else { //advanced
 		tempo_factory=4;
 		}
 
-	disabled_slots_for_end = 2; //each variations has same
+	disabled_bars_for_end = 2; //each variations has same
 	beats_per_minute = 140;  //All advanced city variations use same set of samples, so they have same bpm
 	}
 
@@ -797,15 +800,15 @@ if (use_two_tracks) y_offset=80;
 	//Container for tracks (one or two) and backing_track
 	ClutterActor* container_for_tracks = jammo_get_actor_by_id("composition_game_container_for_tracks");
 
-	theme->color_bar = create_backing_track_color_bar(background_color_code,WIDTH_OF_SLOT,y_offset);
+	theme->color_bar = create_backing_track_color_bar(background_color_code,WIDTH_OF_BEAT*4,y_offset);
 	clutter_actor_set_position(theme->color_bar, 0.0, 0.0);
 
-	int number_of_slots = strlen(background_color_code);
+	int number_of_bars = strlen(background_color_code);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), theme->color_bar, NULL);
 
 	//Tune width of containers
-	clutter_actor_set_size(theme->color_bar,number_of_slots*WIDTH_OF_SLOT, 38.0);
-	clutter_actor_set_size(container_for_tracks,number_of_slots*WIDTH_OF_SLOT, 120.0+y_offset); //track is 80 and backingtrack is 40
+	clutter_actor_set_size(theme->color_bar,number_of_bars*WIDTH_OF_BEAT*4, 38.0);
+	clutter_actor_set_size(container_for_tracks,number_of_bars*WIDTH_OF_BEAT*4, 120.0+y_offset); //height of track is 80 and backingtrack is 40
 
 	gchar* message = g_strdup_printf("tempo_factory (time_sig): %d, beats_per_minute: %d",tempo_factory,beats_per_minute);
 	cem_add_to_log(message,J_LOG_DEBUG);
@@ -815,7 +818,8 @@ if (use_two_tracks) y_offset=80;
 	guint64 temp=60*tempo_factory;
 	guint64 one_second = 1000000000L;
 	guint64 big = temp * one_second;
-	guint64 slot_duration = big / beats_per_minute;
+	guint64 bar_duration = big / beats_per_minute;
+	guint64 beat_duration = bar_duration / 4;
 
 	// sequencer needs to know time signature and tempo so they can be passed on to tracks
 	jammo_sequencer_set_time_signature(sequencer, tempo_factory, 4);
@@ -837,12 +841,12 @@ if (use_two_tracks) y_offset=80;
 
 
 	//Bottom track. Below of this there will be place for scrollbar.
-	JammoEditingTrack* editing_track_theme = jammo_editing_track_new_fixed_duration(number_of_slots*slot_duration);
+	JammoEditingTrack* editing_track_theme = jammo_editing_track_new_fixed_duration(4*number_of_bars*beat_duration);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme));
-	ClutterActor*	track_view = jammo_editing_track_view_new(editing_track_theme, number_of_slots,slot_duration, WIDTH_OF_SLOT, 80.0);
-	g_object_set(track_view, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
+	ClutterActor* track_view = jammo_editing_track_view_new(editing_track_theme, 4*number_of_bars,beat_duration, WIDTH_OF_BEAT, 80.0);
+	g_object_set(track_view, "disabled-slots-begin", disabled_bars_for_begin*4, "disabled-slots-end", disabled_bars_for_end*4,NULL);
 	clutter_actor_set_reactive(track_view, TRUE);
-	g_object_set(track_view, "line-every-nth-slot", 2, NULL);
+	g_object_set(track_view, "line-every-nth-slot", 8, NULL); //every other bar
 	clutter_actor_set_position(track_view, 0.0, 2.0+y_offset);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), track_view, NULL);
 
@@ -851,9 +855,9 @@ if (use_two_tracks) y_offset=80;
 
 	if (use_two_tracks){
 	//Upper track.
-	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new_fixed_duration(number_of_slots*slot_duration);
+	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new_fixed_duration(4*number_of_bars*beat_duration);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme2));
-	ClutterActor* track_view2 = jammo_editing_track_view_new(editing_track_theme2, number_of_slots,slot_duration, WIDTH_OF_SLOT, 80.0);
+	ClutterActor* track_view2 = jammo_editing_track_view_new(editing_track_theme2, 4*number_of_bars,beat_duration, WIDTH_OF_BEAT, 80.0);
 
 
 	//pair-game:
@@ -864,11 +868,11 @@ if (use_two_tracks) y_offset=80;
 	}
 	else {
 		cem_add_to_log("single player game", J_LOG_DEBUG);
-		g_object_set(track_view2, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
+		g_object_set(track_view2, "disabled-slots-begin", disabled_bars_for_begin*4, "disabled-slots-end", disabled_bars_for_end*4,NULL);
 		clutter_actor_set_reactive(track_view2, TRUE);
 	}
 
-	g_object_set(track_view2, "line-every-nth-slot", 2, NULL);
+	g_object_set(track_view2, "line-every-nth-slot", 8, NULL);  //every other bar
 	clutter_actor_set_position(track_view2, 0.0, 2.0);
 	tangle_widget_add(TANGLE_WIDGET(container_for_tracks), track_view2, NULL);
 
@@ -901,7 +905,7 @@ if (use_two_tracks) y_offset=80;
 	cursor = jammo_cursor_new(sequencer, texture);
 	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
 	clutter_actor_set_position(cursor, 0.0, 0.0);
-	clutter_actor_set_size(cursor, number_of_slots*WIDTH_OF_SLOT, 80.0);
+	clutter_actor_set_size(cursor, 4*number_of_bars*WIDTH_OF_BEAT, 80.0);
 	clutter_container_add_actor(CLUTTER_CONTAINER(container_for_tracks), cursor);
 
 	ClutterAction* scroll_action = tangle_actor_get_action_by_type(container_for_tracks,TANGLE_TYPE_SCROLL_ACTION);
