@@ -26,12 +26,33 @@
 This function is called when user chooses and clicks one theme in theme_selection (defined on themeselection-view.json).
 Selected theme is 'name'-property of clicked button.
 */
-gboolean themeselection_theme_clicked(TangleActor* actor, gpointer data){
+gboolean themeselection_theme_clicked(ClutterActor* actor,ClutterEvent* event, gpointer data) {
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(actor));
+	gfloat screen_x, screen_y,x,y;
+	ClutterModifierType state;
+
+	clutter_event_get_coords (event, &screen_x, &screen_y);
+	clutter_actor_transform_stage_point(CLUTTER_ACTOR(actor), screen_x, screen_y, &x, &y);
+
+	//Check if CTRL is pressed:
+	state = clutter_event_get_state (event);
 
 	//subthemes are 1,2,3.
-	int variation = (rand () % 3) + 1;
-	gchar* message = g_strdup_printf("Random variation is '%d' ",variation);
+	int variation;
+	if (state & CLUTTER_CONTROL_MASK) { //CTRL pressed
+		cem_add_to_log("Theme selected with 'CTRL-cheat' ",J_LOG_USER_ACTION);
+		if (y < clutter_actor_get_height(actor)/3) //upper part of the image
+			variation = 1;
+		else if (y < 2 *clutter_actor_get_height(actor)/3) //middle part of the image
+			variation = 2;
+		else   //bottom part of the image
+			variation = 3;
+	}
+	else {
+		variation = (rand () % 3) + 1;
+	}
+
+	gchar* message = g_strdup_printf("Theme-variation is %d",variation);
 	cem_add_to_log(message,J_LOG_INFO);
 	g_free(message);
 	
