@@ -17,8 +17,6 @@
 
 #include "../pen_gesture/login_screen.h"
 
-
-#define SKIP_LOGIN 1
 static void finalize_welcome(ClutterTimeline* timeline, gpointer none)  {
 	ClutterActor* actor;
 
@@ -26,9 +24,8 @@ static void finalize_welcome(ClutterTimeline* timeline, gpointer none)  {
 		tangle_actor_hide_animated(TANGLE_ACTOR(actor));
 	}
 
-	#if SKIP_LOGIN==0
 	login_screen();
-	#else
+	#if SKIP_LOGIN==1
 	if ((actor = jammo_get_actor_by_id("main-menu-view"))) {
 		clutter_actor_show(actor);
 		clutter_actor_queue_relayout(clutter_actor_get_parent(actor));
@@ -70,6 +67,7 @@ void welcome_door_clicked(TangleActor* tangle_actor, gpointer data){
 	if ((animation = clutter_actor_get_animation(actor))) {
 		clutter_animation_completed(animation);
 		jammo_sample_stop_all();
+		
 		finalize_welcome(NULL,NULL);
 	} else {
 		animation = clutter_actor_animate(actor, CLUTTER_LINEAR, 2750, "rotation-angle-y", -110.0, NULL);
