@@ -5,7 +5,7 @@
 #include "community_utilities.h"
 #include "string.h"
 #include "../../cem/cem.h"
-
+#include "avatar.h"
 
 typedef enum{BLACK, BLOND, BLUE, BROWN, DARKBROWN, GRAY, ORANGE, VIOLET, WHITE}HAIR_COLOR;
 typedef enum{BROWN_HEAD, DARK_HEAD, PINK_HEAD, YELLOW_HEAD}HEADS;
@@ -31,6 +31,7 @@ static void end_avatar_view();
 * Starts avatar editor.
 */
 void start_avatar_editor(){
+	cem_add_to_log("Starting avatar editor", J_LOG_DEBUG);
 
 	//Creating default user to test avatar saving!
 
@@ -43,30 +44,19 @@ void start_avatar_editor(){
 	}
 	//TODO: Get real userid
 
-	gboolean profileFound = FALSE;
-	guint32 avatar_id = 0;
-	gchar* profile_path = g_strdup_printf("%s/user_%d.csv", configure_get_jammo_directory(), /*avatar_id*/TEST_USERID);
-	char line[200];
-	int id = 0;
-	gchar* name = "";
-	gchar* hobbies = "";
-	gchar* gender = "";
-	
-	FILE *f;
-	if ((f = fopen(profile_path, "r")) == NULL){
-		profileFound = FALSE;
-		printf("Error happened while trying to read profile file.\n");	
-	}else{
-		profileFound = TRUE;
-		while(fgets(line, sizeof(line), f)){
-			id = atoi(strtok(line, ", "));  
-    	  	name = strtok(NULL, ", ");  
-	       	hobbies = strtok(NULL, ", "); 
-	       	gender = strtok(NULL, ", ");	
-		}
-	}
-	g_free(profile_path);
-	cem_add_to_log("Starting avatar editor", J_LOG_DEBUG);
+	guint32 avatar_id = TEST_USERID; //TODO
+	gchar* profile_path = g_strdup_printf("%s/user_%d.json", configure_get_temp_directory(), avatar_id);
+
+	//Default values
+	gchar* username = g_strdup_printf("<<YOUR NAME HERE>>");
+	gchar* hobbies = g_strdup_printf("<<YOUR HOBBIES HERE>>");
+	gchar* gender = g_strdup_printf("<<YOUR GENDER HERE>>");
+	guint32 serialized_image=0;
+	guint32 age=0; //not yet used on this view
+
+	avatar_parse_json(profile_path,&username,&hobbies,&gender,&serialized_image,&age);
+
+	printf("username '%s', hobbies '%s', gender '%s', serialized_image '%d'\n",username, hobbies, gender,  serialized_image);
 
 	ClutterActor* mainview;
 	
@@ -98,23 +88,23 @@ void start_avatar_editor(){
 		genderTextField.lineCount = 1;
 		genderTextField.max_characters = 500;
 		
-		if(profileFound){
 			clutter_text_set_text(CLUTTER_TEXT(hobbiesTextField.text), _(hobbies));
-			clutter_text_set_text(CLUTTER_TEXT(nameTextField.text), _(name));
+			clutter_text_set_text(CLUTTER_TEXT(nameTextField.text), _(username));
 			clutter_text_set_text(CLUTTER_TEXT(genderTextField.text), _(gender));
-		}else{
-			clutter_text_set_text(CLUTTER_TEXT(hobbiesTextField.text), _("<<YOUR HOBBIES HERE>>"));
-			clutter_text_set_text(CLUTTER_TEXT(nameTextField.text), _("<<YOUR NAME HERE>>"));
-			clutter_text_set_text(CLUTTER_TEXT(genderTextField.text), _("<<YOUR GENDER HERE>>"));
-		}		
-		hobbiesTextField.handler_id = g_signal_connect_swapped(hobbiesTextField.text, "text-changed", (GCallback)limit_line_count, &hobbiesTextField);
-		nameTextField.handler_id = g_signal_connect_swapped(nameTextField.text, "text-changed", (GCallback)limit_line_count, &nameTextField);
-		genderTextField.handler_id = g_signal_connect_swapped(genderTextField.text, "text-changed", (GCallback)limit_line_count, &genderTextField);					
+
+		g_free(username);
+		g_free(hobbies);
+		g_free(gender);
+
+		hobbiesTextField.handler_id = g_signal_connect_swapped(hobbiesTextField.text, "text-changed", (GCallback)community_utilities_limit_line_count, &hobbiesTextField);
+		nameTextField.handler_id = g_signal_connect_swapped(nameTextField.text, "text-changed", (GCallback)community_utilities_limit_line_count, &nameTextField);
+		genderTextField.handler_id = g_signal_connect_swapped(genderTextField.text, "text-changed", (GCallback)community_utilities_limit_line_count, &genderTextField);
 		avatar_id = /*gems_profile_manager_get_avatar_id(NULL)*/TEST_USERID;
 	
 		if(avatar_id != 0){
-			community_get_avatar(&avatar_static, avatar_id);
-			
+			avatar_unserialize_image(&avatar_static, serialized_image);
+
+			//FIXME: what workaround this is?
 			if(avatar_static.hair != 0){
 				char *temp = strstr(clutter_actor_get_name(avatar_static.hair), "hairs/");
 				temp = strpbrk(temp, "/");
@@ -297,12 +287,12 @@ gboolean change_body_color_clicked(TangleActor *actor, gpointer data){
 
 	cem_add_to_log("changing body color", J_LOG_DEBUG);
 	
-	clear_container(partsList);
+	community_utilities_clear_container_recursively(partsList);
 	
 	char path[100] = DATA_DIR;
 	strcat(path, "/communitymenu/AVATAR_PARTS/bodys/");
 	
-	if(!add_images_from_directory(path, partsList, (GCallback)pressed, 100, 100)){
+	if(!community_utilities_make_buttons_from_directory(path, partsList, (GCallback)pressed, 100, 100)){
 		cem_add_to_log("can't open directory containing avatar parts", J_LOG_ERROR);
 		
 	}
@@ -365,7 +355,7 @@ void change_hair_type() {
 	
 	hairsInList = TRUE;
 
-	clear_container(partsList);
+	community_utilities_clear_container_recursively(partsList);
 	
 	char path[100] = DATA_DIR;
 	
@@ -380,7 +370,7 @@ void change_hair_type() {
 	if(hairColor == WHITE) strcat(path,"/communitymenu/AVATAR_PARTS/hairs/white/");
 
 		
-	if(!add_images_from_directory(path, partsList, (GCallback)pressed, 100, 100))
+	if(!community_utilities_make_buttons_from_directory(path, partsList, (GCallback)pressed, 100, 100))
 		cem_add_to_log("can't open directory containing avatar parts", J_LOG_ERROR);
 }
 
@@ -396,7 +386,7 @@ gboolean change_head_clicked(TangleActor *actor, gpointer data){
 
 	cem_add_to_log("changing head", J_LOG_DEBUG);
 	
-	clear_container(partsList);
+	community_utilities_clear_container_recursively(partsList);
 	
 	heads = (heads+1)%NUMBEROFHEADS;	
 
@@ -422,9 +412,9 @@ gboolean change_instrument_clicked(TangleActor *actor, gpointer data){
 	cem_add_to_log("changing instrument", J_LOG_DEBUG);
 	gchar* instruments_path = g_strdup_printf("%s/communitymenu/INSTRUMENTS/", DATA_DIR);
 	
-	clear_container(partsList);
+	community_utilities_clear_container_recursively(partsList);
 
-	if(!add_images_from_directory(instruments_path, partsList, (GCallback)pressed, 100, 100))
+	if(!community_utilities_make_buttons_from_directory(instruments_path, partsList, (GCallback)pressed, 100, 100))
 		cem_add_to_log("can't open directory containing instruments", J_LOG_ERROR);
 
 	g_free(instruments_path);
@@ -433,46 +423,13 @@ gboolean change_instrument_clicked(TangleActor *actor, gpointer data){
 }
 
 
-//For cleanupping
-static void end_avatar_view() {
-
-	const char* hobbies = clutter_text_get_text(CLUTTER_TEXT(hobbiesTextField.text));
-	const char* username = clutter_text_get_text(CLUTTER_TEXT(nameTextField.text));
-	const char* gender = clutter_text_get_text(CLUTTER_TEXT(genderTextField.text));
-	
-	guint32 id = community_save_avatar(&avatar_static);
-	update_avatar(TEST_USERID/*id*/, username, hobbies, gender);
-	
-	clear_container(partsList);
-	
-	DESTROY_ACTOR(avatar_static.body);
-	DESTROY_ACTOR(avatar_static.hair);
-	DESTROY_ACTOR(avatar_static.head);
-	DESTROY_ACTOR(avatar_static.instrument);
-	DESTROY_ACTOR(instrumentBackground_static);
-	
-	partsList = 0;
-	//avatarImage = 0;	
-		
-}
 
 /*
 * Writes avatar info into file.
 */
-gboolean update_avatar(guint32 id, const char *username, const char *hobbies, const char *gender){
+static gboolean write_avatar_json(guint32 id, guint32 serialized_image, const char *username, const char *hobbies, const char *gender){
 
-	gchar* user_profile_for_user = g_strdup_printf("%s/user_%d.csv", configure_get_jammo_directory(), id); 
 	gchar* user_profile_for_others = g_strdup_printf("%s/user_%d.json", configure_get_temp_directory(), id);
-	
-	FILE *f;
-	if ((f = fopen(user_profile_for_user, "w")) == NULL) {
-		cem_add_to_log("Error happened while trying to write user .json file", J_LOG_ERROR);
-		printf("Error happened while trying to write a file\n");
-		return FALSE;
-	}else{
-		fprintf(f, "%d,%s,%s,%s", id, username, hobbies, gender);
-	}
-	fclose(f);
 
 	FILE *pFile;
 	if ((pFile = fopen(user_profile_for_others, "w")) == NULL) {
@@ -481,28 +438,49 @@ gboolean update_avatar(guint32 id, const char *username, const char *hobbies, co
 		return FALSE;
 	}else{
 		fprintf(pFile, "{\n"); 
-		fprintf(pFile, "\"user_properties\":\n");
-		fprintf(pFile, "{\n"); 
-		fprintf(pFile, "\"userid\": \"%d\",\n", id);
+		fprintf(pFile, "\"serialized_image\": %d,\n", serialized_image);
 		fprintf(pFile, "\"username\": \"%s\",\n", username);
 		fprintf(pFile, "\"hobbies\": \"%s\",\n", hobbies);
 		fprintf(pFile, "\"gender\": \"%s\"\n", gender);
-       		fprintf(pFile, "}\n"); 			
-		fprintf(pFile, "}"); 
+		fprintf(pFile, "}\n");
 	}
 	fclose(pFile);	
 
+
 	if(!sendJammoUserProfile(user_profile_for_others)){
 		printf("Failed to send user profile to server\n");
 		return FALSE;
 	} 
-	
-	g_free(user_profile_for_user);
+
 	g_free(user_profile_for_others);
 
 	return TRUE;
 }
 
+//For cleanupping
+static void end_avatar_view() {
+
+	const char* hobbies = clutter_text_get_text(CLUTTER_TEXT(hobbiesTextField.text));
+	const char* username = clutter_text_get_text(CLUTTER_TEXT(nameTextField.text));
+	const char* gender = clutter_text_get_text(CLUTTER_TEXT(genderTextField.text));
+
+	guint32 id;
+	id = TEST_USERID; //TODO
+	guint32 serialized_image = avatar_serialize_image(&avatar_static);
+	write_avatar_json(id, serialized_image, username, hobbies, gender);
+
+	community_utilities_clear_container_recursively(partsList);
+
+	DESTROY_ACTOR(avatar_static.body);
+	DESTROY_ACTOR(avatar_static.hair);
+	DESTROY_ACTOR(avatar_static.head);
+	DESTROY_ACTOR(avatar_static.instrument);
+	DESTROY_ACTOR(instrumentBackground_static);
+
+	partsList = 0;
+	//avatarImage = 0;
+}
+
 
 gboolean sendJammoUserProfile(gchar* user_profile)
 {
