@@ -28,10 +28,6 @@ void start_avatar_editor();
 */
 void set_avatar(Avatar*, ClutterActor*, ClutterActor*, char*);
 
-/*
-* Writes avatar info into file.
-*/
-gboolean update_avatar(guint32 id, const char *username, const char *hobbies, const char *gender);
 
 gboolean sendJammoUserProfile(gchar* user_profile);
 
