@@ -1,9 +1,8 @@
 #include <tangle.h>
 #include <glib-object.h>
-#include <sys/time.h>
 #include <sys/types.h>
 #include <dirent.h>
-#include "string.h"
+#include <string.h>
 #include <time.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -16,9 +15,12 @@
 #include "../file_helper.h"
 #include "sequencer.h"
 
-#define DURATION_OF_LONG_CLICK 1000 // milliseconds 1500
+
 static gboolean renaming_loop = FALSE;
 
+static void rename_loop(ClutterActor* loopName, int type);
+static void hide_song_label();
+static gboolean add_single_button(ClutterActor* button, ClutterContainer* list, char* path, int width,int height, GCallback function);
 
 //Long click:  rename the item
 void song_on_held_function(TangleButton* button, gpointer user_data) {
@@ -63,7 +65,7 @@ void song_on_clicked_function(TangleButton* button, gpointer user_data) {
 		if(type == 0){
 			start_sequencer_with_this_file(actor, NULL);
 		}else if(type == 1){
-			play_selected_loop(actor);
+			community_utilities_play_selected_loop(actor);
 		}else{
 			cem_add_to_log("Invalid loop name\n", J_LOG_ERROR);
 		}
@@ -78,7 +80,7 @@ void song_on_clicked_function(TangleButton* button, gpointer user_data) {
  * -loopName is clutter actor holding the filename
  * -type: 0=finished song, 1=project
 **/
-void rename_loop(ClutterActor *loopName, int type){
+static void rename_loop(ClutterActor *loopName, int type){
 
 	static gboolean firstCall = TRUE;
 
@@ -132,9 +134,9 @@ void rename_loop(ClutterActor *loopName, int type){
 			const char* projects = configure_get_projects_directory();
 			gchar* new_projects_name = g_strdup_printf("%s/%s_%d.json",projects,givenname,/*gems_profile_manager_get_userid(NULL)*/TEST_USERID);
 			
-			if(!file_exist(new_projects_name)){ //if file with same name exists we don't rename
+			if(!community_utilities_file_exist(new_projects_name)){ //if file with same name exists we don't rename
 
-				if(file_exist(path)){ //labelfile exists
+				if(community_utilities_file_exist(path)){ //labelfile exists
 					newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
 								/*gems_profile_manager_get_userid(NULL)*/TEST_USERID, givenname);
 					rename(path, newpath);
@@ -149,9 +151,9 @@ void rename_loop(ClutterActor *loopName, int type){
 			const char *finalized = configure_get_finalized_directory();
 			gchar* newname = g_strdup_printf("%s/%s_%d.ogg",finalized,givenname,/*gems_profile_manager_get_userid(NULL)*/TEST_USERID);
 
-			if(!file_exist(newname)){ //if file with same name exists we don't rename
+			if(!community_utilities_file_exist(newname)){ //if file with same name exists we don't rename
 
-				if(file_exist(path)){ //labelfile exists
+				if(community_utilities_file_exist(path)){ //labelfile exists
 					newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
 								/*gems_profile_manager_get_userid(NULL)*/TEST_USERID, givenname);
 					rename(path, newpath);
@@ -173,8 +175,7 @@ void rename_loop(ClutterActor *loopName, int type){
  * parameters:
  * -actor is clutter actor holding the filename
 **/
-void play_selected_loop(ClutterActor *actor){
-	
+void community_utilities_play_selected_loop(ClutterActor *actor){
 	static JammoSample *sample = NULL;
 	const char *filename = clutter_actor_get_name(actor);
 	printf("play loop %s\n", filename);
@@ -204,8 +205,7 @@ void play_selected_loop(ClutterActor *actor){
 /**
  * Reads label information from labelfile given as parameter, and shows the label viewer
 **/
-void show_song_label(show_label_params *params){
-
+void community_utilities_start_label_viewer(show_label_params* params){
 	cem_add_to_log("Starting record label view.", J_LOG_DEBUG);
 
 	FILE *file;
@@ -260,8 +260,7 @@ void show_song_label(show_label_params *params){
 /**
  * Changes view from label viewer to parent view
 **/
-void hide_song_label(gchar* parentview){
-	
+static void hide_song_label(gchar* parentview){
 	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("record-label-viewer")));
 	
 	if(strcmp(parentview, "jammosongs") == 0) 				 
@@ -272,25 +271,6 @@ void hide_song_label(gchar* parentview){
 		
 }
 
-/*
- * Function for getting current time.
- */
-time_type get_current_time(){
-
-	time_t now;
-	time_type current_time;
-	struct tm *ts;
-	gchar temp[80];
-
-	now = time(NULL); //to get current time and date
-
-	//to format the time, "dd.mm.yy hh:mm"
-	ts = localtime(&now);
-	strftime(temp, 18, "%d.%m.%Y %H:%M", ts);
-	strcpy(current_time.time, temp);
-
-	return current_time;
-}
 
 /*
  * Function for checking whether file exists or not.
@@ -298,82 +278,26 @@ time_type get_current_time(){
  * parameters:
  * -filename is the fullpath of the file
  */
-gboolean file_exist(gchar *filename) 
-{
-  	struct stat buffer;
+gboolean community_utilities_file_exist(const gchar* filename) {
+	struct stat buffer;
 
-  	if(stat(filename, &buffer) == 0){
-    		return TRUE;
-  	}else{
+	if(stat(filename, &buffer) == 0){
+		return TRUE;
+	}
+	else {
 		gchar * message = g_strdup_printf("Cannot find file: %s", filename);
-
 		cem_add_to_log(message, J_LOG_ERROR);
-		g_free(message);		
-
-    		return FALSE;
-  	}
-}
-
-/**
- * Builds filename from fullpath. Useful for parsing songname from filepath. Returns filename. 
- * 
- * parameters:
- * -filename is a char pointer where the resulting filename will be saved to
- * -folder_path is folderpath where the file resides 
- * -filepath is the fullpath where the filename is parsed from
-**/
-gchar* build_filename(gchar* filepath, gchar* folder_path, gchar* filename, int n)
-{
-	int i = 0, j = 0;
-	int folder_path_length = strlen(folder_path);
-	int filepath_length = strlen(filepath);
-	char temp[filepath_length];
-	char str[filepath_length];
-	
-	strcpy(temp, filepath);
-
-	for(i = folder_path_length; i < (filepath_length - n); i++)
-	{
-		str[j] = temp[i];
-		j++;
+		g_free(message);
+		return FALSE;
 	}
-	str[j] = '\0';
-	
-	filename = malloc(strlen((str)+1)* sizeof(gchar));
-	strcpy(filename, str);
-	
-	return filename;	
 }
 
-/**
- * Builds filepath for specific file. Returns full filepath. 
- * 
- * parameters:
- * -filename is the name of the file
- * -folder_path is folderpath where the file resides 
- * -filepath is a char pointer where the resulting fullpath will be saved to
-**/
-gchar* build_filepath(gchar* filename, gchar* folder_path, gchar* filepath)
-{
-	int folder_path_length = strlen(folder_path);
-	int filename_length = strlen(filename);
-	int filepath_length = (folder_path_length + filename_length + 1);
-	
-	char str[filepath_length];
-  	strcpy(str,folder_path);
-  	strcat(str,filename);
-
-	filepath = malloc(strlen((str)+1)*sizeof(char));
-	strcpy(filepath, str);
-		
-	return filepath;
-}
 
+#ifdef this_is_not_yet_used
 /**
  * Deletes all files inside jammo temp directory. This should be called before jammo is terminated.  
 **/
-gboolean clear_community_temp_directory(){
-
+static gboolean clear_community_temp_directory(){
 	//NOTE: This should be called before jammo is terminated so that temp files will be removed from hard-drive.
 	
 	gchar* command = g_strdup_printf("rm -f %s/*.*",configure_get_temp_directory());
@@ -390,7 +314,7 @@ gboolean clear_community_temp_directory(){
 	g_free(command);
 	return returnvalue;
 }
-
+#endif
 
 /**
  * Function clears container that may contain other containers.
@@ -398,7 +322,7 @@ gboolean clear_community_temp_directory(){
  * parameters:
  * -listToClear is the container to be cleared
 **/
-void clear_container(ClutterContainer *listToClear){
+void community_utilities_clear_container_recursively(ClutterContainer *listToClear){
 	
 	int i = 0;
 	GList *listItems;
@@ -437,14 +361,13 @@ void clear_container(ClutterContainer *listToClear){
  * -width is the width of the button
  * -height is the height of the button
 **/
-gboolean add_images_from_directory(const char* path, ClutterContainer *list, GCallback function, int width, int height){
-		
+gboolean community_utilities_make_buttons_from_directory(const char* path, ClutterContainer *list, GCallback function, int width, int height){
 	ClutterActor *button = 0;
 	char tempPath[150];
 	char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN];
 	int numberOfImages;
 	
-	numberOfImages = community_open_and_arrange_dir(path, ".png", result);	
+	numberOfImages = community_utilities_open_and_arrange_dir(path, ".png", result);
 	
 	for(int i = 0; i < numberOfImages; i++){
 		strcpy(tempPath, path);
@@ -467,8 +390,7 @@ gboolean add_images_from_directory(const char* path, ClutterContainer *list, GCa
  * -height is the height of the button
  * -funtion is a pointer to a function which handles button press events
 **/
-gboolean add_single_button(ClutterActor *button, ClutterContainer *list, char* path, int width,int height, GCallback function){
-
+static gboolean add_single_button(ClutterActor* button, ClutterContainer* list, char* path, int width, int height, GCallback function){
 	button = tangle_button_new_with_background_actor(tangle_texture_new(path));
 	clutter_actor_set_name(button, path);
 	clutter_container_add_actor(list, button);
@@ -484,7 +406,7 @@ gboolean add_single_button(ClutterActor *button, ClutterContainer *list, char* p
  * parameters:
  * -pointer to a textfield structure that contains info about how to limit line count etc.
 **/
-void limit_line_count(TextField *text){
+void community_utilities_limit_line_count(TextField *text){
 
 	gchar *textField = malloc((text->max_characters+1) * sizeof(gchar));
 	PangoLayout *layout;
@@ -509,7 +431,7 @@ void limit_line_count(TextField *text){
 			
 			g_signal_handler_disconnect(text->text, text->handler_id);
 			clutter_text_set_text(CLUTTER_TEXT(text->text), textField); 
-			text->handler_id = g_signal_connect_swapped(text->text, "text-changed", (GCallback)limit_line_count, text);
+			text->handler_id = g_signal_connect_swapped(text->text, "text-changed", (GCallback)community_utilities_limit_line_count, text);
 			layout = clutter_text_get_layout(CLUTTER_TEXT(text->text));
 	}
 	
@@ -520,7 +442,7 @@ void limit_line_count(TextField *text){
 /**
  * Frees dynamically allocated memory from GList that contains pointers to message structures.
 **/
-void clear_messagelist(GList* messages_){
+void community_utilities_clear_messagelist(GList* messages_){
 
 	messages_ = g_list_first(messages_);
 
@@ -565,8 +487,7 @@ void clear_messagelist(GList* messages_){
 /**
  * Frees dynamically allocated memory from GList that contains pointers to song_type structures.
 **/
-void clear_songlist(GList* songs){
-
+void community_utilities_clear_songlist(GList* songs){
 	songs = g_list_first(songs);
 
 	song_type *temp = 0;
@@ -617,205 +538,6 @@ void clear_songlist(GList* songs){
 }
 
 
-/**
- * Computes the avatar from guint32 type number.
- *
- * Avatar is serialized in 32 bits in the following way:
- * 		-head id is the 4 least significant bits (bits 0-3)
- *		-hair color is bits 4-7
- *		-body is bits 8-15
- *		-hair type is bits 16-23 
- *		-instrument is in bits 24-31
- *
- *	Note that ids are actually index numbers of avatar parts. Parts are arranged in alphabetical order.
- *
- * parameters:
- * -avatar is pointer to a Avatar struct, where the avatar will be created.
- * -avatar_id tells the avatar type.
-**/
-gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
-
-	int head, hair_color, hair_type, body, instrument;
-	char path[150];
-	char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN];
-	
-	head = (avatar_id & 0xF);
-	hair_color = (avatar_id & 0xF0) >> 4;
-	body = (avatar_id & 0xFF00) >> 8;
-	hair_type = (avatar_id & 0xFF0000) >> 16;
-	instrument = (avatar_id & 0xFF000000) >> 24;
-
-	gchar* heads_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/heads/", DATA_DIR);
-	gchar* bodys_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/bodys/", DATA_DIR);
-	gchar* hairs_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/hairs/", DATA_DIR);
-	gchar* instruments_path = g_strdup_printf("%s/communitymenu/INSTRUMENTS/", DATA_DIR);
-
-	if(head != 0){
-	
-		strcpy(path, heads_path);
-		
-		community_open_and_arrange_dir(path, ".png", result);
-		avatar->head = tangle_texture_new(strcat(path, result[head-1]));	
-		clutter_actor_set_name(avatar->head, path);
-	}
-
-	if(body != 0){
-	
-		strcpy(path, bodys_path);
-		
-		community_open_and_arrange_dir(path, ".png", result);
-		avatar->body = tangle_texture_new(strcat(path, result[body-1]));	
-		clutter_actor_set_name(avatar->body, path);
-	}
-	
-	if(hair_color != 0 && hair_type != 0){
-	
-		strcpy(path, hairs_path);
-
-		community_open_and_arrange_dir(path, "DIR", result);
-		
-		strcat(path, result[hair_color-1]);
-		strcat(path, "/");
-		
-		community_open_and_arrange_dir(path, ".png", result);
-		
-		strcat(path, result[hair_type-1]);
-		
-		avatar->hair = tangle_texture_new(path);
-		clutter_actor_set_name(avatar->hair, path);
-	}	
-	
-	if(instrument != 0){
-	
-		strcpy(path, instruments_path);
-		community_open_and_arrange_dir(path, ".png", result);
-		avatar->instrument = tangle_texture_new(strcat(path, result[instrument-1]));
-		clutter_actor_set_name(avatar->instrument, path);	
-	
-	}
-	g_free(heads_path);
-	g_free(bodys_path);
-	g_free(hairs_path);
-	g_free(instruments_path);
-
-	return TRUE;
-}
-
-/**
- * Computes and saves guint32 type number from user avatar.
- *
- * Avatar is serialized in 32 bits in the following way:
- * 		-head id is the 4 least significant bits (bits 0-3)
- *		-hair color is bits 4-7
- *		-body is bits 8-15
- *		-hair type is bits 16-23 
- *		-instrument is in bits 24-31
- *
- *	Note that ids are actually index numbers of avatar parts. Parts are arranged in alphabetical order.
- *
- * parameters:
- * -avatar is pointer to a Avatar struct, which contains user avatar
- * returns: avatar id in guint32
-**/
-guint32 community_save_avatar(Avatar* avatar){
-
-	guint32 head = 0, hair_color = 0, hair_type = 0, body = 0, instrument = 0;
-	char path[150];
-	char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN];
-	int i;
-	int numberOfImages = 0;
-
-	gchar* heads_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/heads/", DATA_DIR);
-	gchar* bodys_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/bodys/", DATA_DIR);
-	gchar* hairs_path = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/hairs/", DATA_DIR);
-	gchar* instruments_path = g_strdup_printf("%s/communitymenu/INSTRUMENTS/", DATA_DIR);
-	
-	if(avatar->head != 0){
-	
-		strcpy(path, heads_path);
-
-		numberOfImages = community_open_and_arrange_dir(path, ".png", result);
-		
-		for(i = 0; i < numberOfImages; i++)
-			if(strstr(clutter_actor_get_name(avatar->head), result[i]) != 0)
-				break;	
-				
-		head = i+1;		
-	}
-	
-	if(avatar->body != 0){
-	
-		strcpy(path, bodys_path);	
-	
-		numberOfImages = community_open_and_arrange_dir(path, ".png", result);
-		
-		for(i = 0; i < numberOfImages; i++)
-			if(strstr(clutter_actor_get_name(avatar->body), result[i]) != 0)
-				break;	
-				
-		body = i+1;		
-	
-	}	
-	
-	if(avatar->hair != 0){
-	
-		strcpy(path, hairs_path);
-		
-		numberOfImages = community_open_and_arrange_dir(path, "DIR", result);
-		
-		for(i = 0; i < numberOfImages; i++)
-			if(strstr(clutter_actor_get_name(avatar->hair), result[i]) != 0)
-				break;	
-				
-		hair_color = i+1;		
-					
-		strcpy(path, clutter_actor_get_name(avatar->hair));
-		
-		char *temp = strrchr(path, '/');
-		temp++;
-		*temp = 0;
-		numberOfImages = community_open_and_arrange_dir(path, ".png", result);
-		
-		for(i = 0; i < numberOfImages; i++)
-			if(strstr(clutter_actor_get_name(avatar->hair), result[i]) != 0)
-				break;	
-				
-		hair_type = i+1;		
-	}		
-	
-	if(avatar->instrument != 0){
-		
-		strcpy(path, instruments_path);
-		
-		numberOfImages = community_open_and_arrange_dir(path, ".png", result);
-		
-		for(i = 0; i < numberOfImages; i++)
-			if(strstr(clutter_actor_get_name(avatar->instrument), result[i]) != 0)
-				break;	
-				
-		instrument = i+1;
-	
-	}
-	
-	guint32 id = 0;
-	
-	id = head;
-	id += (hair_color << 4);
-	id += (body << 8);
-	id += (hair_type << 16);
-	id += (instrument << 24);
-
-	g_free(heads_path);
-	g_free(bodys_path);
-	g_free(hairs_path);
-	g_free(instruments_path);
-
-	gems_profile_manager_set_avatar_id(id);
-	
-	return id;
-
-}
-
 
 /**
  * This function opens directory, and sorts files in alphabetical order.
@@ -829,8 +551,7 @@ guint32 community_save_avatar(Avatar* avatar){
  *
  * returns number of files found
 **/
-int community_open_and_arrange_dir(const char* path, char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]){
-	
+int community_utilities_open_and_arrange_dir(const char* path, char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]){
 	DIR *dir;
 	struct dirent *dir_ent;
 	int numberOfFiles = 0;
@@ -867,86 +588,10 @@ int community_open_and_arrange_dir(const char* path, char* suffix, char result[M
 
 }
 
-/**
- * Transforms avatar into smaller scale, so it can be used in thread-views.
- *
- * parameters:
- * -avatar is the avatar to be scaled
- * -avatarBackground is container, where avatar will be set
-**/
-void community_shrink_and_set_avatar(Avatar* avatar, ClutterContainer *avatarBackground){
-
-	gfloat width, height;
-	
-	if(avatar->body != 0){
-		clutter_actor_get_size(avatar->body, &width, &height);
-		clutter_actor_set_size(avatar->body, width*0.3, height*0.3);
-		clutter_actor_set_position(avatar->body, 7, 35);
-	}
-
-	if(avatar->head != 0){
-		clutter_actor_get_size(avatar->head, &width, &height);
-		clutter_actor_set_size(avatar->head, width*0.3, height*0.3);
-		clutter_actor_set_position(avatar->head, 14, 10);
-	}
-	
-	if(avatar->hair != 0){
-	
-		clutter_actor_get_size(avatar->hair, &width, &height);
-		clutter_actor_set_size(avatar->hair, width*0.3, height*0.3);
-		clutter_actor_set_position(avatar->hair, 14, 10);
-	
-		//hard codin' man is back...
-	
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_bush.png"))
-			clutter_actor_set_position(avatar->hair, 12, 5);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread.png"))
-			clutter_actor_set_position(avatar->hair, 7, 6);		
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread2.png"))
-			clutter_actor_set_position(avatar->hair, 11, 5);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread3.png"))
-			clutter_actor_set_position(avatar->hair, 12, 5);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread4.png"))
-			clutter_actor_set_position(avatar->hair, 13, 6);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_centerspread5.png"))
-			clutter_actor_set_position(avatar->hair, 14, 6);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_emo.png"))
-			clutter_actor_set_position(avatar->hair, 14, 6);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_long.png"))
-			clutter_actor_set_position(avatar->hair, 11, 5);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_longcurly.png"))
-			clutter_actor_set_position(avatar->hair, 10, 6);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_longcurly2.png"))
-			clutter_actor_set_position(avatar->hair, 11, 6);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_mohawk.png"))
-			clutter_actor_set_position(avatar->hair, 18, 2);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_ponytails.png"))
-			clutter_actor_set_position(avatar->hair, 9, 6);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_punk.png"))
-			clutter_actor_set_position(avatar->hair, 10, 4);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_punk2.png"))	
-			clutter_actor_set_position(avatar->hair, 1, -3);
-		if(strstr(clutter_actor_get_name(avatar->hair), "hair_top.png"))	
-			clutter_actor_set_position(avatar->hair, 15, 8);		
-	
-	}
-	
-	if(avatar->head != 0)
-		clutter_container_add_actor(avatarBackground, avatar->head);	
-	
-	if(avatar->body != 0)
-		clutter_container_add_actor(avatarBackground,avatar->body);
-	
-	if(avatar->hair != 0)
-		clutter_container_add_actor(avatarBackground, avatar->hair);	
-
-}
-
 /**
  * Funtion frees GList that contains pointers to dynamically allocated profile_view_params structures
 **/
-void community_clear_paramslist(GList* paramsList){
-
+void community_utilities_clear_paramslist(GList* paramsList) {
 	paramsList = g_list_first(paramsList);
 	
 	if(paramsList != NULL){
@@ -970,7 +615,7 @@ void community_clear_paramslist(GList* paramsList){
 /**
  * Funtion frees GList that contains pointers to dynamically allocated show_label_params structures
 **/
-void community_clear_labelparamslist(GList* paramslist){
+void community_utilities_clear_labelparamslist(GList* paramslist){
 
 	paramslist = g_list_first(paramslist);
 	
@@ -991,8 +636,7 @@ void community_clear_labelparamslist(GList* paramslist){
 /**
  * Scrolls the list to correct position automatically
 **/
-void community_autoscroll_to_correct_pos(list_type *list)
-{
+void community_utilities_autoscroll_list(list_type* list) {
 	gint slot;
 	gfloat not_used, offset;
 
@@ -1010,8 +654,7 @@ void community_autoscroll_to_correct_pos(list_type *list)
 /**
  * Downloads a specific file from server
 **/
-gboolean load_file_from_server(gchar * filename) 
-{	
+gboolean community_utilities_load_file_from_server(const gchar* filename) {
 	gboolean returnvalue = TRUE;
 	
 	//TODO: download json from server and check that the file was received
@@ -1027,8 +670,7 @@ gboolean load_file_from_server(gchar * filename)
  * -list is a pointer pointing to GList where songs/loops will be saved to
  * -type: 0=loop, 1=song
 **/
-gboolean parse_songs_from_file(gchar* filename, GList** list, int type) 
-{	
+gboolean community_utilities_parse_songs_from_file(const gchar* filename, GList** list, int type) {
 	int j;
 	JsonParser *parser;
 	JsonNode *root;
@@ -1088,14 +730,14 @@ gboolean parse_songs_from_file(gchar* filename, GList** list, int type)
 			JsonObject* sub_object = json_node_get_object(track_node);
 			JsonNode *sub_node;
 			
-			gchar* id = "";
-			gchar* name=  "";
+			const gchar* id = "";
+			const gchar* name = "";
 			guint32 userid = 0; 
-			gchar* track_filename =  "";
+			const gchar* track_filename =  "";
 			//gchar* info_filename = "";
-			gchar* label =  "";
+			const gchar* label =  "";
 			gchar* comments =  "";
-			gchar* date =  "";
+			const gchar* date =  "";
 
 			printf("\nFound track!\n");
 
@@ -1103,7 +745,7 @@ gboolean parse_songs_from_file(gchar* filename, GList** list, int type)
 			
 				sub_node = json_object_get_member(sub_object, "songid"); 
 				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
-					id = (gchar*)json_node_get_string(sub_node);
+					id = json_node_get_string(sub_node);
 					printf("songid: '%s'\n", id);
 				}		
 				sub_node = json_object_get_member(sub_object, "songname");
