@@ -15,6 +15,10 @@ This file contains the functionality of discuss menu.
 #include "community_utilities.h"
 #include "profile_viewer.h"
 #include "../../cem/cem.h"
+#include "avatar.h"
+
+//File containing topic names (etc)
+#define FORUM_TOPICS_FILE "forum_topics.json"
 
 static void autoscroll_to_correct_pos(ClutterActor *list_);
 
@@ -23,8 +27,7 @@ static ClutterColor text_color = { 237, 28, 36, 255 };
 static ClutterColor text_color2 = { 0, 0, 0, 255 };
 static ClutterContainer *list = 0;
 static ClutterContainer *threadslist = 0;
-static GList* messages = 0;
-static GList* discussionthreads = 0;
+static GList* static_discussionthreads = 0;
 static GList* threads = 0;
 extern GList* paramsList;
 static gint item_height = 0;
@@ -32,17 +35,31 @@ static gchar * currentThread = NULL;
 static TextField titleTextField;
 static TextField descriptionTextField;
 
+static gchar* getAllDiscussionThreads();
+
+static void start_addthread_view();
+static gboolean addDiscussion(gpointer data, int num);
+static gboolean addThread(gpointer data, int number);
+static void end_discuss();
+static void clear_discussions(GList* list_);
+static void getThread(ClutterActor *element);
+static gboolean load_threads_from_server(gchar* currentThread);
+static gboolean sendJammoThread(gchar* thread_path, gchar* messages_path);
+static gboolean discuss_change_to_threads_view(ClutterActor * element);
+static gboolean parse_discussions_from_file(gchar* filename, int type);
+static gboolean discuss_send_thread(gint index, guint32 userid, gchar* sender, const gchar* title, const gchar* msg, gchar* filepath, gchar* time, int msgtype);
+static ClutterActor *create_line(int y, int length, int size, ClutterContainer *cont);
+
 /**
- * Starts discussionthread view
+ * Starts discuss-view
 **/
 void start_discuss(){
-	
-	cem_add_to_log("Starting Discuss", J_LOG_DEBUG);	
+	cem_add_to_log("Starting Discussusion Forum", J_LOG_DEBUG);
 
 	GList* l = NULL; //Iterator
 	int entries_size = 0;
 	int number = 0;
-	discussionthreads = 0;
+	static_discussionthreads = 0;
 
 	ClutterActor* mainview;
 	mainview = jammo_get_actor_by_id("main-views-widget");
@@ -51,32 +68,40 @@ void start_discuss(){
 
 	ClutterActor* discuss_view = jammo_get_actor_by_id("discuss-view");
 
-	if(discuss_view){
-
-		//NOTE: all_discussionthreads.json must exist or list will be empty. See end of this file for example.
-		
-		getAllDiscussionThreads(); //Get discussionthreads
-
-		entries_size = g_list_length(discussionthreads);
-
-		clutter_actor_show(CLUTTER_ACTOR(discuss_view));
-		
-		if(entries_size > 5){
-			list = CLUTTER_CONTAINER(jammo_get_actor_by_id("discuss-view-container"));	
-		}else{
-			list = CLUTTER_CONTAINER(jammo_get_actor_by_id("discuss-view-container-unscrollable"));
-		}
-		for(l = discussionthreads; l; l = l->next){
-			addDiscussion(l->data, number);
-			number++;
-		}
-
-		ClutterAction* action = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list), TANGLE_TYPE_SCROLL_ACTION);
-		g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(autoscroll_to_correct_pos), list);
-
-	}else{
-		cem_add_to_log("can't find 'discuss-view' ", J_LOG_ERROR);
+	if(!discuss_view){
+		cem_add_to_log("can't find 'discuss-view' ", J_LOG_FATAL);
 	}
+
+	//NOTE: FORUM_TOPICS_FILE must exist or list will be empty. See end of this file for example.
+	gchar* all_discussionthreads_filepath = getAllDiscussionThreads();
+	//printf("filepath is '%s'\n",all_discussionthreads_filepath);
+
+	if (all_discussionthreads_filepath) {
+		int type = 0; //List of topics
+		if(parse_discussions_from_file(all_discussionthreads_filepath, type))
+			cem_add_to_log("parsing all_discussionthreads success", J_LOG_DEBUG);
+		else
+			cem_add_to_log("parsing all_discussionthreads fails", J_LOG_ERROR);
+		g_free(all_discussionthreads_filepath);
+	}
+
+	entries_size = g_list_length(static_discussionthreads);
+
+	clutter_actor_show(CLUTTER_ACTOR(discuss_view));
+
+	if(entries_size > 5){
+		list = CLUTTER_CONTAINER(jammo_get_actor_by_id("discuss-view-container"));
+	}else{
+		list = CLUTTER_CONTAINER(jammo_get_actor_by_id("discuss-view-container-unscrollable"));
+	}
+	for(l = static_discussionthreads; l; l = l->next){
+		addDiscussion(l->data, number);
+		number++;
+	}
+
+	ClutterAction* action = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list), TANGLE_TYPE_SCROLL_ACTION);
+	if (action)
+		g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(autoscroll_to_correct_pos), list);
 }
 
 /**
@@ -114,8 +139,8 @@ void start_discussionthreads()
 		}
 
 		ClutterAction* action = tangle_actor_get_action_by_type(CLUTTER_ACTOR(threadslist), TANGLE_TYPE_SCROLL_ACTION);
-		g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(autoscroll_to_correct_pos), CLUTTER_ACTOR(threadslist));
-
+		if (action)
+			g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(autoscroll_to_correct_pos), CLUTTER_ACTOR(threadslist));
 
 	}else{
 		cem_add_to_log("can't find 'discuss-container-for-discussion-threads' ", J_LOG_ERROR);
@@ -126,9 +151,7 @@ void start_discussionthreads()
 /**
  * Shows add thread view used for adding new threads
 **/
-void start_addthread_view()
-{
-
+static void start_addthread_view() {
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 	
@@ -141,13 +164,13 @@ void start_addthread_view()
 		titleTextField.lineCount = 1;
 		titleTextField.max_characters = 50;
 		titleTextField.handler_id = g_signal_connect_swapped(titleTextField.text,
-							"text-changed", (GCallback)limit_line_count, &titleTextField);		
+                "text-changed", (GCallback)community_utilities_limit_line_count, &titleTextField);
 
 		descriptionTextField.text = jammo_get_actor_by_id("description");
 		descriptionTextField.lineCount = 5;
 		descriptionTextField.max_characters = 300;
 		descriptionTextField.handler_id = g_signal_connect_swapped(descriptionTextField.text,
-							"text-changed", (GCallback)limit_line_count, &descriptionTextField);
+                "text-changed", (GCallback)community_utilities_limit_line_count, &descriptionTextField);
 	}else {	
 		cem_add_to_log("can't find 'addthread-view' ", J_LOG_ERROR);
 	}
@@ -162,7 +185,7 @@ Functions to fill lists
 /**
  * Adds discussionthread to list
 **/
-gboolean addDiscussion(gpointer data, int number){
+static gboolean addDiscussion(gpointer data, int number){
 
 	discussion_type *dthread = data;
 
@@ -215,7 +238,7 @@ gboolean addDiscussion(gpointer data, int number){
 /**
  * Adds thread to list
 **/
-gboolean addThread(gpointer data, int number){
+static gboolean addThread(gpointer data, int number){
 	
 	discussion_type *thread = data;
 	
@@ -224,8 +247,10 @@ gboolean addThread(gpointer data, int number){
 	params->user_id = thread->user_id;
 	strcpy(params->parent_view, "discuss");
 	
-	guint32 avatar_id = 0;
 	Avatar avatar = {0,0,0,0};
+	guint32 serialized_avatar_image = avatar_give_serialized_image_for_this_id(thread->user_id);
+	avatar_unserialize_image(&avatar, serialized_avatar_image);
+
 
 	gchar* avatarbg_image_filename = g_strdup_printf("%s/communitymenu/community_avatarbackground_small.png", DATA_DIR);
 	gchar* comment_image_filename = g_strdup_printf("%s/communitymenu/community_comment_icon.png", DATA_DIR);
@@ -246,15 +271,8 @@ gboolean addThread(gpointer data, int number){
 	ClutterActor *text = clutter_text_new_full(TEXT_LARGE, thread->title, &text_color2);
     	clutter_actor_set_size(text, ((35*12)+30), 51);
 	clutter_text_set_max_length(CLUTTER_TEXT(text), 35);
-	
-	/*avatar_id = gems_profile_manager_get_avatar_id(gems_profile_manager_get_profile_of_user(user_id));*/
-	avatar_id = thread->user_id;
-	if (avatar_id == 0)
-		avatar_id = 260; //default avatar
-		
-	community_get_avatar(&avatar, avatar_id);
-	community_shrink_and_set_avatar(&avatar, CLUTTER_CONTAINER(avatarbg));	
-	
+
+	avatar_shrink(&avatar, CLUTTER_CONTAINER(avatarbg));
 	ClutterActor *title = tangle_button_new_with_background_actor(text);
 	clutter_actor_set_name(title, thread->json);
 
@@ -291,11 +309,7 @@ gboolean addThread(gpointer data, int number){
 }
 
 
-/***************************
-Clear functions
-**************************/
-
-void clear_discussions(GList* list_){
+static void clear_discussions(GList* list_){
 
 	list_ = g_list_first(list_);
 
@@ -335,33 +349,25 @@ void clear_discussions(GList* list_){
 	} //if
 }
 
-
-/***************************
-Drawing functions
-**************************/
-
 /**
  * Used to create line that separates list elements
 **/
-ClutterActor *create_line(int y, int length, int size, ClutterContainer *cont) {
+static ClutterActor *create_line(int y, int length, int size, ClutterContainer *cont) {
+	ClutterActor *line = clutter_rectangle_new_with_color(&line_color);
+	clutter_actor_set_size(line, length, size);
+	clutter_actor_set_position(line, 0, y);
 
-        ClutterActor *line = clutter_rectangle_new_with_color(&line_color);
-        clutter_actor_set_size(line, length, size);
-        clutter_actor_set_position(line, 0, y);
+	clutter_container_add_actor(CLUTTER_CONTAINER(cont), line);
+	clutter_actor_show(line);
 
-        clutter_container_add_actor(CLUTTER_CONTAINER(cont), line);
-        clutter_actor_show(line);
-
-        return line;
+	return line;
 }
 
 
 /***************************
 Functions for json
 **************************/
-
 gboolean discuss_community_clicked (TangleButton* tanglebutton, gpointer none){
-
 	end_discuss();
 
 	startmenu_goto_communitymenu(NULL,NULL);
@@ -369,7 +375,6 @@ gboolean discuss_community_clicked (TangleButton* tanglebutton, gpointer none){
 }
 
 gboolean discuss_home_clicked (TangleButton* tanglebutton, gpointer none){
-	
 	end_discuss();
 
 	startmenu_goto_startmenu(NULL,NULL);
@@ -383,35 +388,30 @@ gboolean discuss_mentor_clicked (TangleButton *tanglebutton, gpointer data)   {
 	return TRUE;
 }
 
-gboolean discuss_writenew_clicked (TangleButton *tanglebutton, gpointer data)   {
+/* //Maybe never used by user?
+gboolean discuss_create_new_topic (TangleButton *tanglebutton, gpointer data)   {
 	cem_add_to_log("Making new thread...", J_LOG_DEBUG);
 
 	return TRUE;
 }
-
+*/
 /**
  * Ends discussview and clears all containers
 **/
-void end_discuss(){
-
-	community_clear_paramslist(paramsList);
+static void end_discuss(){
+	community_utilities_clear_paramslist(paramsList);
 	paramsList = 0;
 
-	if(g_list_length(discussionthreads) != 0)
-		clear_discussions(discussionthreads); 	
+	if(g_list_length(static_discussionthreads) != 0)
+		clear_discussions(static_discussionthreads);
 	if(g_list_length(threads) != 0)
 		clear_discussions(threads);
-	
-	/*if(currentThread != NULL){
-		free(currentThread);
-		currentThread = NULL;
-	}*/
+
 	g_free(currentThread);
 
-	clear_container(CLUTTER_CONTAINER(threadslist));
-	clear_container(CLUTTER_CONTAINER(list));
+	community_utilities_clear_container_recursively(CLUTTER_CONTAINER(threadslist));
+	community_utilities_clear_container_recursively(CLUTTER_CONTAINER(list));
 	cem_add_to_log("Clear_containered containers", J_LOG_DEBUG);
-
 }
 
 
@@ -421,9 +421,10 @@ Callback functions
 
 /**
  * Checks that all fields of add thread view have enough text and then calls discuss_send_thread to send the thread to server
+ *
+ * JSON callback
 **/
-void add_new_thread(){
-
+gboolean add_new_thread(TangleButton* tanglebutton, gpointer none){
 	static gboolean is_title_ok = FALSE;
 	static gboolean is_msg_ok = FALSE;
 
@@ -454,36 +455,25 @@ void add_new_thread(){
 	}
 
 	if(is_title_ok == TRUE && is_msg_ok == TRUE){	
-		
-		time_type now;
-		now = get_current_time();
-		
-		gchar* profile_path = g_strdup_printf("%s/user_%d.csv", configure_get_jammo_directory(), /*avatar_id*/TEST_USERID);
-		char line[200];
-		gchar *sender = "Anonymous";
+		guint32 user_id = TEST_USERID; //TODO: user_id =gems_profile_manager_get_userid(NULL)
+		gchar* sender = avatar_give_username_for_this_id(user_id);
+
+
 		gint thread_index = 0;
-		guint32 user_id = /*gems_profile_manager_get_userid(NULL)*/TEST_USERID;
-		gchar *title = clutter_text_get_text(CLUTTER_TEXT(titleTextField.text));
-		gchar* date = now.time;
-		gchar *msg = clutter_text_get_text(CLUTTER_TEXT(descriptionTextField.text));
+		const gchar* title = clutter_text_get_text(CLUTTER_TEXT(titleTextField.text));
+		const gchar* msg = clutter_text_get_text(CLUTTER_TEXT(descriptionTextField.text));
 		gchar *filepath = "";
 		int type = TEXT_COMMENT;
-		
-		FILE *f;
-		if ((f = fopen(profile_path, "r")) != NULL){
-			while(fgets(line, sizeof(line), f)){
-				strtok(line, ", ");  
-    	  		sender = strtok(NULL, ", ");	
-			}
-		}
-		g_free(profile_path);
-		
+		char date [80];
+		cem_get_time(date);
+
 		if(!discuss_send_thread(thread_index, user_id, sender, title, msg, filepath, date, type)){
 			cem_add_to_log("Failed to add new thread: error happened while trying to send file.", J_LOG_DEBUG);
 			clutter_text_set_text(CLUTTER_TEXT(error_msg), "Failed to add new thread. Please try again.");
 		}else{
 			cem_add_to_log("Added thread.", J_LOG_DEBUG);
 		}
+		g_free(sender);
 		//clutter_text_set_text (CLUTTER_TEXT(jammo_get_actor_by_id("title")),"");
 		//clutter_text_set_text (CLUTTER_TEXT(jammo_get_actor_by_id("description")),"");
 		//clutter_text_set_text(CLUTTER_TEXT(error_msg), "");
@@ -492,20 +482,20 @@ void add_new_thread(){
 	}else{
 		cem_add_to_log("Cannot add thread.", J_LOG_DEBUG);
 	}
+	return TRUE;
 }
 
 /**
  * Shows the messages of selected thread
 **/
-void getThread(ClutterActor *element){
-
+static void getThread(ClutterActor *element){
 	const char* json_path = clutter_actor_get_name(element);
 	
-	cem_add_to_log("changing view to discussion threads", J_LOG_DEBUG);
+	cem_add_to_log("getThread", J_LOG_DEBUG);
 
 	clear_discussions(threads); // <---ok?
 	//threads = 0;
-	clear_container(threadslist);
+	community_utilities_clear_container_recursively(threadslist);
 
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
@@ -517,12 +507,13 @@ void getThread(ClutterActor *element){
 
 /**
  * Changes the view to add thread view used for adding a new thread
+ *
+ * JSON callback
 **/
-gboolean discuss_change_to_add_thread_view(TangleActor *actor, gpointer data) {
-
+gboolean discuss_change_to_add_thread_view(TangleButton* tangle_button, gpointer data) {
 	cem_add_to_log("changing view to add thread view", J_LOG_DEBUG);
 
-	clear_container(threadslist);
+	community_utilities_clear_container_recursively(threadslist);
 	clear_discussions(threads);
 	//threads = 0;
 	
@@ -534,19 +525,18 @@ gboolean discuss_change_to_add_thread_view(TangleActor *actor, gpointer data) {
 /**
  * Changes the view from discussionthread view to thread view
 **/
-gboolean discuss_change_to_threads_view(ClutterActor *element){
-
+static gboolean discuss_change_to_threads_view(ClutterActor *element){
 	const char* json_path = clutter_actor_get_name(element);
 	
-	cem_add_to_log("changing view to discussion threads", J_LOG_DEBUG);
+	cem_add_to_log("discuss_change_to_threads_view", J_LOG_DEBUG);
 
-	clear_discussions(discussionthreads);
-	discussionthreads = 0;
-	clear_container(list);
+	clear_discussions(static_discussionthreads);
+	static_discussionthreads = 0;
+	community_utilities_clear_container_recursively(list);
 	
 	//currentThread = malloc((strlen(json_path)+1)*sizeof(gchar));
 	//strcpy(currentThread, json_path);	
-	currentThread = g_strdup_printf(json_path);
+	currentThread = g_strdup_printf("%s",json_path);
 	
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
@@ -558,12 +548,13 @@ gboolean discuss_change_to_threads_view(ClutterActor *element){
 
 /**
  * Changes the view from thread view to discussionthread view
+ *
+ * JSON callback
 **/
-gboolean discuss_change_to_discussion_view(TangleActor *actor, gpointer data) {
-
+gboolean discuss_change_to_discussion_view(TangleButton* tangle_button, gpointer data) {
 	cem_add_to_log("changing view to discussion view", J_LOG_DEBUG);
 
-	clear_container(threadslist);
+	community_utilities_clear_container_recursively(threadslist);
 	clear_discussions(threads);
 	//threads = 0;
 	
@@ -581,7 +572,6 @@ gboolean discuss_change_to_discussion_view(TangleActor *actor, gpointer data) {
  * Scrolls the list to correct position automatically
 **/
 static void autoscroll_to_correct_pos(ClutterActor *list_){
-
 	gint slot;
 	gfloat not_used, offset;
 	
@@ -602,41 +592,38 @@ Server functions
 
 /**
  * Downloads discussionthread json files from server
+ *
+ * In error cases returns NULL.
+ * If success, returns filepath to the just downloaded file
 **/
-gboolean getAllDiscussionThreads(){
-	
-	gboolean returnvalue = FALSE;
-	int type = 0; //discussionthread
-	
+static gchar* getAllDiscussionThreads(){
 	//TODO: get alldiscussionthreads.json from server and check that the file was received
-	if(!load_file_from_server("all_discussionthreads.json")){
-		printf("Load discussionthreads from server error: Couldn't download alldiscussionthreads.json from server!\n");
-		return FALSE;
+	if(!community_utilities_load_file_from_server(FORUM_TOPICS_FILE)){
+		gchar* msg = g_strdup_printf("Couldn't download topics ('%s') from server",FORUM_TOPICS_FILE);
+		cem_add_to_log(msg, J_LOG_ERROR);
+		g_free(msg);
+		return NULL;
 	}
-	
-	//Only for testing!
-	char * all_discussionthreads_filepath = g_strdup_printf("%s/all_discussionthreads.json", configure_get_temp_directory()); 
-	
-	if(parse_discussions_from_file(all_discussionthreads_filepath, type))
-		returnvalue = TRUE;
-	else
-		returnvalue = FALSE;
+	//Now file is on local disk and we can use it.
 
-	g_free(all_discussionthreads_filepath);
-		
-	return returnvalue;
+	//Only for testing! Use file from installation directory
+	char* all_discussionthreads_filepath = g_strdup_printf("%s/%s",DATA_DIR,FORUM_TOPICS_FILE);
+	//TODO: use this folder: configure_get_temp_directory());
+
+	return all_discussionthreads_filepath;
 }
 
 /**
  * Downloads all json files needed by threads from server
 **/
-gboolean load_threads_from_server(gchar* thread){
-
+static gboolean load_threads_from_server(gchar* thread){
 	gboolean returnvalue = FALSE;
 
 	//TODO: download json file from server and check that file was received
-	if(!load_file_from_server(thread)){
-		printf("Load threads from server error: Couldn't download %s from server!\n", thread);
+	if(!community_utilities_load_file_from_server(thread)){
+		gchar* msg = g_strdup_printf("Load threads from server error: Couldn't download %s from server!", thread);
+		cem_add_to_log(msg, J_LOG_ERROR);
+		g_free(msg);
 		return FALSE;
 	}	
 	int type = 1; //thread
@@ -662,8 +649,8 @@ gboolean load_threads_from_server(gchar* thread){
 				//TODO: build user profile filename!
 				gchar* user_profile = g_strdup_printf("user_%d.json", temp->user_id);
 				
-				if(!load_file_from_server(user_profile)){
-					printf("Load threads from server error: Couldn't download user profiles from server!\n");
+				if(!community_utilities_load_file_from_server(user_profile)){
+					cem_add_to_log("Load threads from server error: Couldn't download user profiles from server!", J_LOG_ERROR);
 					returnvalue = FALSE;
 				}
 				g_free(user_profile);
@@ -678,8 +665,7 @@ gboolean load_threads_from_server(gchar* thread){
 /**
  * Sends a thread to server
 **/
-gboolean sendJammoThread(gchar* thread_path, gchar* messages_path)
-{
+static gboolean sendJammoThread(gchar* thread_path, gchar* messages_path) {
 	gboolean returnvalue = TRUE;
 		
 	//TODO: Send messages.json and threads.json to server 
@@ -695,14 +681,11 @@ JSON Parsers & Builders
 **************************/
 
 /**
- * Type:
- * 0=discussionthread
- * 1=thread
- * 
- * Loads discussions from json file given as parameter
+ * This parser can read
+ *    list of topics  (type=0)
+ *    list of threads (type=1)
 **/
-gboolean parse_discussions_from_file(gchar* filename, int type) 
-{	
+static gboolean parse_discussions_from_file(gchar* filename, int type) {
 	int j;
 	JsonParser *parser;
 	JsonNode *root;
@@ -743,9 +726,13 @@ gboolean parse_discussions_from_file(gchar* filename, int type)
 	if (node != NULL && JSON_NODE_TYPE (node) == JSON_NODE_ARRAY){
 		discussion_array =  json_node_get_array(node);
 		length = json_array_get_length(discussion_array);
-		printf("Found %d discussions\n", length);
+		gchar* msg = g_strdup_printf("Found %d %s", length, type==0?"topics":"threads");
+		cem_add_to_log(msg, J_LOG_DEBUG);
+		g_free(msg);
 	}else {
-		printf("No discussions found\n"); 
+		gchar* msg = g_strdup_printf("No %s found",type==0?"topics":"threads");
+		cem_add_to_log(msg, J_LOG_DEBUG);
+		g_free(msg);
 		return TRUE;
 	}
 	
@@ -763,12 +750,14 @@ gboolean parse_discussions_from_file(gchar* filename, int type)
 			gchar *id = "";	
 			gint  thread_index = 0;
 			guint32 user_id = 0;
-			gchar *title = "";	
-			gchar *json = "";
-			gchar *date = "";
+			const gchar* title = "";
+			const gchar* date = "";
+			gchar* json = g_strdup_printf(" ");
+
+			gchar* msg = g_strdup_printf("%s found", type==0?"Topic":"Thread");
+			cem_add_to_log(msg, J_LOG_DEBUG);
+			g_free(msg);
 
-			printf("\nFound discussion!\n");
-			
 			sub_node = json_object_get_member(sub_object, "id"); 
 			if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
 				id = (gchar*)json_node_get_string(sub_node);
@@ -795,9 +784,22 @@ gboolean parse_discussions_from_file(gchar* filename, int type)
 			sub_node = json_object_get_member(sub_object, "json"); 
 			
 			if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
-				json = json_node_get_string(sub_node);			
+				const gchar* temp_string;
+				temp_string = json_node_get_string(sub_node);
+				json = g_strdup_printf("%s/%s", configure_get_temp_directory(), temp_string);
+
+				if (type==0) { //In case of list of TOPICs, we want that file exists
+					FILE* file;
+					if ((file = fopen(json, "a")) == NULL) {
+						cem_add_to_log("Error happened while trying to touch file", J_LOG_ERROR);
+						return FALSE;
+					} else {
+						fclose(file);
+					}
+				}
+
 				printf("json: '%s'\n", json);
-			}		
+			}
 			sub_node = json_object_get_member(sub_object, "date");
 			
 			if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
@@ -818,12 +820,13 @@ gboolean parse_discussions_from_file(gchar* filename, int type)
 			discussion->id = malloc((strlen(id)+1)*sizeof(gchar));
 			strcpy(discussion->id, id);
 			
+			g_free(json);
 		} //Discussion is ready
 		
 		//Save struct into global array
 
-		if(type == 0){ //discussionthreads
-			discussionthreads = g_list_append(discussionthreads, (gpointer)discussion);
+		if(type == 0){ //Topics
+			static_discussionthreads = g_list_append(static_discussionthreads, (gpointer)discussion);
 		}else if(type == 1){ //threads
 			threads = g_list_append(threads, (gpointer)discussion);
 		}
@@ -838,18 +841,18 @@ gboolean parse_discussions_from_file(gchar* filename, int type)
 /**
  * Builds json files needed to send a new thread to server
 **/
-gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar* title, gchar* msg, gchar* filepath, gchar* time_, int msgtype)
-{
-	printf("discuss_send_thread\n");
+static gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, const gchar* title, const gchar* msg, gchar* filepath, gchar* time_, int msgtype) {
+	cem_add_to_log("discuss_send_thread",J_LOG_DEBUG);
 	
 	//TODO: re-download current thread file because it might have changed meanwhile
-	if(!load_file_from_server(currentThread)){
-		printf("Couldn't download current thread -file from server for writing!\n");
+	if(!community_utilities_load_file_from_server(currentThread)){
+		cem_add_to_log("Couldn't download current thread -file from server for writing!",J_LOG_DEBUG);
 		return FALSE;
 	}
 
-	FILE *messageFile;
-	gchar *messagesFilepath = g_strdup_printf("%s/messages_%s_%d.json", configure_get_temp_directory(), title, userid);
+	FILE* messageFile;
+	gchar* messagesFilepath = g_strdup_printf("%s/messages_%s_%d.json", configure_get_temp_directory(), title, userid);
+	gchar* messagesFileWithoutPath = g_strdup_printf("messages_%s_%d.json", title, userid);
 	gboolean returnvalue = FALSE;
 	
 	int i = 0;
@@ -876,7 +879,6 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 	//write comments file
 	if ((messageFile = fopen(messagesFilepath, "w")) == NULL) {
 			cem_add_to_log("Error happened while trying to write messages file", J_LOG_ERROR);
-			printf("Error happened while trying to write messages file\n"); 
 			return FALSE;
 	}else{
 		fprintf(messageFile, "{\n"); 
@@ -902,7 +904,6 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 	//check whether json file is empty
 	if ((pFile = fopen(currentThread, "r")) == NULL) {
 		gchar * error_msg = g_strdup_printf("Error happened while trying to read %s", currentThread);
-		printf("%s\n", error_msg);
 		cem_add_to_log(error_msg, J_LOG_ERROR);
 		g_free(error_msg);
 		
@@ -920,7 +921,6 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 		//write a new json file
 		if ((pFile = fopen(currentThread, "w")) == NULL) {
 			gchar * error_msg = g_strdup_printf("Error happened while trying to write %s", currentThread);
-			printf("%s\n", error_msg);			
 			cem_add_to_log(error_msg, J_LOG_ERROR);
 			g_free(error_msg);
 			
@@ -933,7 +933,7 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 			fprintf(pFile, "\"userid\": \"%d\",\n", userid);
 			fprintf(pFile, "\"index\": \"%d\",\n", 0);
 			fprintf(pFile, "\"title\": \"%s\",\n", title);
-			fprintf(pFile, "\"json\": \"%s\",\n", messagesFilepath);
+			fprintf(pFile, "\"json\": \"%s\",\n", messagesFileWithoutPath);
 			fprintf(pFile, "\"date\": \"%s\"\n", time_);
 			fprintf(pFile, "}\n"); 
 			fprintf(pFile, "]\n"); 	
@@ -948,12 +948,12 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 		
 		//open source file
 		if((pFile = fopen(currentThread, "r")) == NULL){
-			printf("Error happened while trying to open source file\n");
+			cem_add_to_log("Error happened while trying to open source file", J_LOG_ERROR);
 			return FALSE;
 		}
 		//open destination file
 		if((destFile = fopen(dest_filepath, "w")) == NULL){
-			printf("Error happened while trying to open destination file\n");
+			cem_add_to_log("Error happened while trying to open destination file", J_LOG_ERROR);
 			return FALSE;
 		}	
 		//copy the file
@@ -963,17 +963,17 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 		do{
 			c = fgetc(pFile);
 			if(ferror(pFile)) {
-      				printf("Error reading source file\n");
-      				return FALSE;
-    			}
+			cem_add_to_log("Error reading source file", J_LOG_ERROR);
+			return FALSE;
+			}
 			if(c == '[')
 				position_found = 1;
 			
 			if(position_found == 1 && c != '[' && c != ']'){
 				if(c != ']') fputc(c, destFile);
 				if(ferror(destFile)) {
-      					printf("Error writing destination file\n");
-      					return FALSE;
+					cem_add_to_log("Error writing destination file", J_LOG_ERROR);
+					return FALSE;
 				}
 			}
 		}while(c != ']');	
@@ -986,7 +986,7 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 		fprintf(destFile, "\"userid\": \"%d\",\n", userid);
 		fprintf(destFile, "\"index\": \"%d\",\n", 0);
 		fprintf(destFile, "\"title\": \"%s\",\n", title);
-		fprintf(destFile, "\"json\": \"%s\",\n", messagesFilepath);
+		fprintf(destFile, "\"json\": \"%s\",\n", messagesFileWithoutPath);
 		fprintf(destFile, "\"date\": \"%s\"\n", time_);
        		fprintf(destFile, "}\n");	      	 	
 		fprintf(destFile, "]\n"); 	
@@ -994,7 +994,7 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 		fclose(destFile);
 		
 		if(remove(currentThread) != 0){ //We remove the original json
-			printf("Error removing original thread json\n");
+			cem_add_to_log("Error removing original thread json", J_LOG_ERROR);
 			return FALSE;
 		}			
 		rename(dest_filepath, currentThread); //And rename temp file with the name of the original
@@ -1007,31 +1007,36 @@ gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, gchar*
 	
 	if(!sendJammoThread(dest_filepath, messagesFilepath)){
 		returnvalue = FALSE;
-		printf("Error happened when trying to send thread to server\n");
+		cem_add_to_log("Error happened when trying to send thread to server", J_LOG_ERROR);
 	}else{
 		returnvalue = TRUE;
-		printf("Thread was successfully sended\n");
+		cem_add_to_log("Thread was successfully sended", J_LOG_ERROR);
 	}
 	g_free(dest_filepath);
 	g_free(messagesFilepath);
+	g_free(messagesFileWithoutPath);
 	g_free(threadid);
 
 	return returnvalue;
 }
 
+#ifdef not_used_yed
 /**
  * Builds json files needed to send discussionthread to server
+ *
+ * not used yet
 **/
-gboolean send_discussthread(gint dthread_index, guint32 userid, gchar* dthread_title, gchar* json_path, gchar* date){
-	
+static gboolean send_discussthread(gint dthread_index, guint32 userid, gchar* dthread_title, gchar* json_path, gchar* date){
 	//NOTE: Only admins should have access to this function!
 	
-	//TODO: Get all_discussionthreads.json from the server
-	if(!load_file_from_server("all_discussionthreads.json")){
-		printf("Couldn't download all_discussionthreads.json from server for writing!\n");
+	//TODO: Get FORUM_TOPICS_FILE from the server
+	if(!community_utilities_load_file_from_server(FORUM_TOPICS_FILE)){
+		gchar* msg = g_strdup_printf("Couldn't download topics ('%s') from server for writing",FORUM_TOPICS_FILE);
+		cem_add_to_log(msg, J_LOG_ERROR);
+		g_free(msg);
 		return FALSE;
 	}	
-	char *all_discussionthreads_filepath = g_strdup_printf("%s/all_discussionthreads.json", configure_get_temp_directory()); //Only for testing!
+	char *all_discussionthreads_filepath = g_strdup_printf("%s/%s", configure_get_temp_directory(), FORUM_TOPICS_FILE); //Only for testing!
 
 	FILE *jsonFile;
 	gchar *jsonFilepath = g_strdup_printf("%s/threads_%s_%d.json", configure_get_temp_directory(), dthread_title, userid);
@@ -1053,7 +1058,6 @@ gboolean send_discussthread(gint dthread_index, guint32 userid, gchar* dthread_t
 	//check whether json file is empty
 	if ((pFile = fopen(all_discussionthreads_filepath, "r")) == NULL) {
 		gchar * error_msg = g_strdup_printf("Error happened while trying to read %s", all_discussionthreads_filepath);
-		printf("%s\n", error_msg);
 		cem_add_to_log(error_msg, J_LOG_ERROR);
 		g_free(error_msg);
 		
@@ -1071,7 +1075,6 @@ gboolean send_discussthread(gint dthread_index, guint32 userid, gchar* dthread_t
 		//write a new json file
 		if ((pFile = fopen(all_discussionthreads_filepath, "w")) == NULL) {
 			gchar * error_msg = g_strdup_printf("Error happened while trying to write %s", all_discussionthreads_filepath);
-			printf("%s\n", error_msg);			
 			cem_add_to_log(error_msg, J_LOG_ERROR);
 			g_free(error_msg);
 			
@@ -1170,10 +1173,18 @@ gboolean send_discussthread(gint dthread_index, guint32 userid, gchar* dthread_t
 
 	return TRUE;
 }
-
+#endif
 
 /**
-Example of all_discussionthreads.json (Note that required json files must also exists thought they can be empty)
+Example of FORUM_TOPICS_FILE
+ (threads uses same fields, so there are some useless)
+Fields:
+id: just for internal use, must be unique
+index: not used with topics
+userid: not visible. creator of topic (Note: it is not meant that normal users create topics)
+title: shown on menu
+json: without path.  if file doesn't exist, it is created
+date: not visible for user.
 
 {
 "discussions": [
@@ -1182,7 +1193,7 @@ Example of all_discussionthreads.json (Note that required json files must also e
 "index": "0",
 "userid": "18039856",
 "title": "MUSIC MAKING",
-"json": "/home/teppo/.jammo/community_temp/threads_MUSIC MAKING_18039856.json",
+"json": "MUSIC MAKING.json",
 "date": "01.04.2011 15:55"
 }
 ,
@@ -1191,7 +1202,7 @@ Example of all_discussionthreads.json (Note that required json files must also e
 "index": "1",
 "userid": "18039856",
 "title": "HOBBIES",
-"json": "/home/teppo/.jammo/community_temp/threads_HOBBIES_18039856.json",
+"json": "HOBBIES.json",
 "date": "01.04.2011 15:55"
 }
 ]
