@@ -148,6 +148,13 @@ gboolean start_level(TangleButton* button, gpointer data) {
 	return TRUE;
 }
 
+gboolean start_instrument_game(TangleButton* button, gpointer data) {
+	instructions_interrupted=TRUE;
+	jammo_mentor_shut_up(jammo_mentor_get_default());
+
+	clutter_actor_show (jammo_get_actor_by_id("instrumentmenu-view"));
+	return TRUE;
+}
 
 void all_levels_completed(JammoGameLevel* game_level) {
 	g_print("MENTOR: Now you have gone through all game levels! Feel free to do whatever you want now on...\n");
