@@ -65,7 +65,7 @@ void start_jammosongs(){
 
 		ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list.list), TANGLE_TYPE_SCROLL_ACTION);
 	
-		g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_autoscroll_to_correct_pos), &list);
+		g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_utilities_autoscroll_list), &list);
 
 	}else
 		cem_add_to_log("can't find 'jammosongs-view' ", J_LOG_ERROR);
@@ -87,7 +87,6 @@ gboolean add_song_to_list(gpointer data, guint32 user_id){
 	Avatar avatar = {0,0,0,0};
 	profile_view_params *params = malloc(sizeof(profile_view_params));
 	show_label_params *labelParams = malloc(sizeof(show_label_params));
-	//gchar *command;
 
 	song_type *song = data;
 
@@ -133,8 +132,8 @@ gboolean add_song_to_list(gpointer data, guint32 user_id){
 	if (avatar_id == 0)
 		avatar_id = 260; //default avatar
 		
-	community_get_avatar(&avatar, avatar_id);
-	community_shrink_and_set_avatar(&avatar, CLUTTER_CONTAINER(avatarBackground));	
+	avatar_unserialize_image(&avatar, avatar_id);
+	avatar_shrink(&avatar, CLUTTER_CONTAINER(avatarBackground));
 	
 	clutter_container_add_actor(listContainer, composer);
 	
@@ -142,10 +141,9 @@ gboolean add_song_to_list(gpointer data, guint32 user_id){
 
 	labelParams->path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), user_id, song->songname); //<--- folder?
 	
-	//command = g_strdup_printf("ls %s 1> /dev/null 2> /dev/null", labelParams->path); 
 	gchar* label_filename = g_strdup_printf("%s/communitymenu/community_cdlabel_small.png", DATA_DIR);
 	
-	if(file_exist(labelParams->path)/*system(command) == 0*/){
+	if(community_utilities_file_exist(labelParams->path)){
 		
 		label =  clutter_group_new();
 		
@@ -182,8 +180,7 @@ gboolean add_song_to_list(gpointer data, guint32 user_id){
 		clutter_container_add_actor(listContainer, labelButton);
 	}
 
-	//g_free(command);
-	g_free(label_filename);	
+	g_free(label_filename);
 
 	clutter_actor_set_position(CLUTTER_ACTOR(reviewButton), 700, 15);
 
@@ -196,11 +193,10 @@ gboolean add_song_to_list(gpointer data, guint32 user_id){
 	g_object_set(songName, "hold-timeout", 1500, NULL);
 	g_signal_connect(songName, "held", G_CALLBACK(song_on_held_function), NULL);
 
-	//g_signal_connect_swapped(songName, "clicked", G_CALLBACK(load_song_from_server), songName);
 		
 	if(label != 0){	
 		strcpy(labelParams->parentview, "jammosongs");
-		g_signal_connect_swapped(labelButton, "clicked", G_CALLBACK(show_song_label), (gpointer)labelParams); 
+		g_signal_connect_swapped(labelButton, "clicked", G_CALLBACK(community_utilities_start_label_viewer), (gpointer)labelParams);
 
 		clutter_container_add_actor(listContainer, CLUTTER_ACTOR(labelButton));
 		//clutter_actor_raise(labelButton, colorbar);
@@ -223,14 +219,14 @@ void review_selected_song(ClutterActor *song){
 	//GList *list = NULL;
 	const char* comments_filepath = clutter_actor_get_name(song);
 
-	community_clear_labelparamslist(labelParamsList);
+	community_utilities_clear_labelparamslist(labelParamsList);
 	labelParamsList = 0;
 
-	community_clear_paramslist(paramsList);
+	community_utilities_clear_paramslist(paramsList);
 	paramsList = 0;
 
-	clear_songlist(songs);
-	clear_container(list.list);
+	community_utilities_clear_songlist(songs);
+	community_utilities_clear_container_recursively(list.list);
 
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
@@ -239,24 +235,12 @@ void review_selected_song(ClutterActor *song){
 }
 
 
-void load_song_from_server(ClutterActor * song) 
-{	
-	//TODO: check if songs exists already in hd
-
-	//TODO: load song.ogg from server
-	
-	//clutter_actor_set_name(song, save_path);
-	
-	play_selected_loop(song);
-}
-
-
 gboolean load_songs_from_server() 
 {	
 	gboolean returnvalue = FALSE;
 	
 	//TODO: load all_songs.json from server and check that the file was received
-	if(!load_file_from_server("all_songs.json")){
+	if(!community_utilities_load_file_from_server("all_songs.json")){
 		printf("Load songs from server error: Couldn't download all_songs.json from server!\n");
 		return FALSE;
 	}	
@@ -266,7 +250,7 @@ gboolean load_songs_from_server()
 	GList* l = NULL; //Iterator
 	int numberOfFoundSongs = 0;
 	
-	if(parse_songs_from_file(all_songs_filepath, &songs, type)){
+	if(community_utilities_parse_songs_from_file(all_songs_filepath, &songs, type)){
 		returnvalue = TRUE;
 		numberOfFoundSongs = g_list_length(songs);
 	}else{
@@ -284,7 +268,7 @@ gboolean load_songs_from_server()
 				song_type* temp = songs->data;
 					
 				//TODO: build cover filename!
-				if(!load_file_from_server(temp->cover)){
+				if(!community_utilities_load_file_from_server(temp->cover)){
 					printf("Load songs from server error: Couldn't download label files from server!\n");
 					returnvalue = FALSE;
 				}
@@ -304,7 +288,7 @@ gboolean load_songs_from_server()
 				//TODO: build user profile filename!
 				gchar* user_profile = g_strdup_printf("user_%d.json", temp->user_id);
 				
-				if(!load_file_from_server(user_profile)){
+				if(!community_utilities_load_file_from_server(user_profile)){
 					printf("Load songs from server error: Couldn't download user profiles from server!\n");
 					returnvalue = FALSE;
 				}
@@ -319,14 +303,14 @@ gboolean load_songs_from_server()
 
 gboolean end_jammosongs(TangleButton *tanglebutton, gpointer none){
 
-	community_clear_labelparamslist(labelParamsList);
+	community_utilities_clear_labelparamslist(labelParamsList);
 	labelParamsList = 0;
 
-	community_clear_paramslist(paramsList);
+	community_utilities_clear_paramslist(paramsList);
 	paramsList = 0;
 
-	clear_songlist(songs);
-	clear_container(list.list);
+	community_utilities_clear_songlist(songs);
+	community_utilities_clear_container_recursively(list.list);
    
 	if(strcmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)), "gotocommunity") == 0)
 		startmenu_goto_communitymenu(tanglebutton, none);
