@@ -485,9 +485,9 @@ void level1_task5_completed(JammoGameTask* task) {
 //Task5 over
 
 
-//Task6 - -drop four melodic loops to melodic track
+//Task6 - listen backing track and thne drop four melodic loops to melodic track
 //rhythmic loops do not count
-
+//This should be separated two different tasks. TODO
 
 /* Sample must be dropped correct track*/
 static gboolean on_dropping_incompatible_sample(JammoEditingTrackView* track_view, JammoSampleButton* sample_button, gpointer user_data) {
@@ -505,14 +505,26 @@ static gboolean on_dropping_incompatible_sample(JammoEditingTrackView* track_vie
 
 
 
-void level1_task6_started(JammoGameTask* task) {
-	//enable track2
+
+static void task6_on_sequencer_stopped(JammoSequencer* sequencer, gpointer task){
+	g_signal_handlers_disconnect_by_func(sequencer, task6_on_sequencer_stopped, task);
+		//enable track2
 	ClutterActor* track_view2 = jammo_get_actor_by_id("track-view2");
 	g_object_set(track_view2,"disabled-slots-begin",0,NULL);
 
 	//And assign acts for this task
 	clutter_container_foreach(CLUTTER_CONTAINER(sequencer_loop_get_nth_sample_looper(2)), add_dropping_act_to_this_task, task);
 
+	sequencer_change_to_loop_view(NULL,NULL);
+}
+
+
+void level1_task6_started(JammoGameTask* task) {
+	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	g_signal_connect(sequencer, "stopped", G_CALLBACK(task6_on_sequencer_stopped),task);
+
+	sequencer_change_to_sequencer_view(NULL,NULL);
+	//First listen backing track and then drag four melody loops to the track
 	jammo_mentor_speak(jammo_mentor_get_default(), "t1_6_instruction.spx");
 }
 
