@@ -59,13 +59,13 @@ void start_mysongs()
 **/
 void mysongs_end_mysongs(){
 
-	clear_container(songlist.list);
+	community_utilities_clear_container_recursively(songlist.list);
 
-	clear_songlist(all_songs);
+	community_utilities_clear_songlist(all_songs);
 	all_songs = NULL;
 
 	if(removing_song){
-		clear_container(remove_view);
+		community_utilities_clear_container_recursively(remove_view);
 		removing_song = FALSE;
 	}		
 
@@ -189,7 +189,7 @@ gboolean mysongs_add_loop_to_list(char* filename, int type, gchar* json_param)
 
 	gchar* labelButton_filename = g_strdup_printf("%s/communitymenu/community_cdlabel_small.png", DATA_DIR);
 
-	if(file_exist(path)/*system(command) == 0*/){ // labelfile already exists
+	if(community_utilities_file_exist(path)/*system(command) == 0*/){ // labelfile already exists
 		
 		label =  clutter_group_new();
 		
@@ -217,12 +217,12 @@ gboolean mysongs_add_loop_to_list(char* filename, int type, gchar* json_param)
 		labelButton = tangle_button_new_with_background_actor(label);
 		
 		clutter_actor_set_size(labelButton, 50, 50);
-		clutter_actor_set_position(labelButton, 500, 15);
 
 	}else{
 		labelButton = tangle_button_new_with_background_actor(tangle_texture_new(labelButton_filename));
-		clutter_actor_set_position(labelButton, 500, 15);
 	}
+
+	clutter_actor_set_position(labelButton, 500, 15);
 	g_free(command);
 	g_free(labelButton_filename);
 
@@ -315,7 +315,10 @@ gboolean mysongs_add_loop_to_list(char* filename, int type, gchar* json_param)
 
 
 	g_signal_connect_swapped(CLUTTER_ACTOR(remove_button), "clicked", G_CALLBACK(mysongs_remove_song_view), CLUTTER_ACTOR(textButton));
-	g_signal_connect_swapped(CLUTTER_ACTOR(label), "clicked", G_CALLBACK(show_song_label), filename);	
+
+	//FIXME: label is container used in label-button.
+	//No point to connect clicked signal.
+	//g_signal_connect_swapped(CLUTTER_ACTOR(label), "clicked", G_CALLBACK(show_song_label), filename);	
 
 	clutter_container_add_actor(songlist.list, CLUTTER_ACTOR(listContainer));
 	
@@ -357,7 +360,7 @@ void mysongs_send_song(ClutterActor *actor)
 	//TODO: filenames for jsons!
 	
 	//TODO: Get all_songs.json from the server
-	if(!load_file_from_server("all_songs.json")){
+	if(!community_utilities_load_file_from_server("all_songs.json")){
 		printf("Couldn't download all_songs.json from server for writing!\n");
 		return;
 	}
@@ -367,20 +370,20 @@ void mysongs_send_song(ClutterActor *actor)
 	gboolean coverFound = FALSE;
 	ClutterActor *text = tangle_button_get_normal_background_actor(TANGLE_BUTTON(actor));
 	const gchar * songname = clutter_text_get_text(CLUTTER_TEXT(text));
-	time_type now;
-	now = get_current_time();
 	
 	char * cover = "";
 	char * songid = "";
 	const char * filename = clutter_actor_get_name(actor); 
 	guint32 userid = /*gems_profile_manager_get_userid(NULL)*/TEST_USERID;
-	char * date = now.time;
+
+	char date [80];
+	cem_get_time(date);
 	
 	songid = g_strdup_printf("%d_%s", userid, songname); 	
 	char * comments = g_strdup_printf("%s/messages_%s.json", configure_get_temp_directory(), songid); 
 	char * label_path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), userid, songname);
 	
-	if(file_exist(label_path)){ // check whether labelfile exists	
+	if(community_utilities_file_exist(label_path)){
 		coverFound = TRUE;
 		
 		if(mysongs_copy_label(label_path, userid, songname)) //we copy the labelfile to temp directory for sending
@@ -535,7 +538,7 @@ gboolean sendJammoSong(const char *song_filename, const char *song_cover, const
 	//TODO: Remove jsons from hd
 
 	if(returnvalue == TRUE){
-		clear_container(songlist.list);
+		community_utilities_clear_container_recursively(songlist.list);
 		mysongs_refresh_list();
 	}		
 
@@ -626,8 +629,8 @@ void mysongs_delete_song(ClutterActor *actor)
     		
 	g_free(label);
 
-	clear_container(songlist.list);
-	clear_container(remove_view);
+	community_utilities_clear_container_recursively(songlist.list);
+	community_utilities_clear_container_recursively(remove_view);
 	removing_song = FALSE;
 	mysongs_refresh_list();
 }
@@ -639,7 +642,7 @@ void mysongs_delete_song(ClutterActor *actor)
 void mysongs_cancel_song_delete(ClutterActor *actor)
 {
 	removing_song = FALSE;
-	clear_container(remove_view);
+	community_utilities_clear_container_recursively(remove_view);
 }
 
 
@@ -713,11 +716,11 @@ void mysongs_refresh_list()
 
 	cem_add_to_log("Refreshing list...", J_LOG_DEBUG);
 	
-	clear_container(songlist.list);
+	community_utilities_clear_container_recursively(songlist.list);
 	
 	//TODO: download all_songs.json from server
 	gchar* all_songs_path = g_strdup_printf("%s/all_songs.json", configure_get_temp_directory()); //Only for testing!
-	parse_songs_from_file(all_songs_path, &all_songs, 1);
+	community_utilities_parse_songs_from_file(all_songs_path, &all_songs, 1);
 
 	projects = file_helper_get_all_files(configure_get_projects_directory()); //Project-files
 	finalized = file_helper_get_all_files(configure_get_finalized_directory()); //Audio-files
@@ -750,9 +753,12 @@ void mysongs_refresh_list()
 	
 	ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(songlist.list), TANGLE_TYPE_SCROLL_ACTION);
 
-	g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_autoscroll_to_correct_pos), songlist.list); // 2 warnings happens here
-	
-	clear_songlist(all_songs);
+	if (listAction)
+		g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_utilities_autoscroll_list), songlist.list);
+	else
+		printf("listAction is NULL\n");
+
+	community_utilities_clear_songlist(all_songs);
 	all_songs = NULL;
 	g_free(all_songs_path);
 
