@@ -56,8 +56,8 @@ void start_record_cover_tool(const gchar* filepath){
 		composerNameTextField.lineCount = 1;
 		
 	
-		recordNameTextField.handler_id = g_signal_connect_swapped(recordNameTextField.text, "text-changed", G_CALLBACK(limit_line_count), &recordNameTextField);
-		composerNameTextField.handler_id = g_signal_connect_swapped(composerNameTextField.text, "text-changed", G_CALLBACK(limit_line_count), &composerNameTextField);		
+		recordNameTextField.handler_id = g_signal_connect_swapped(recordNameTextField.text, "text-changed", G_CALLBACK(community_utilities_limit_line_count), &recordNameTextField);
+		composerNameTextField.handler_id = g_signal_connect_swapped(composerNameTextField.text, "text-changed", G_CALLBACK(community_utilities_limit_line_count), &composerNameTextField);
 	
 		g_signal_connect(recordNameTextField.text, "text-changed", G_CALLBACK(change_record_name), NULL);
 		g_signal_connect(composerNameTextField.text, "text-changed", G_CALLBACK(change_composer_name), NULL);		
@@ -89,7 +89,7 @@ void start_record_cover_tool(const gchar* filepath){
 			fclose(file);
 		}
 			
-		add_images_from_directory(instruments_path, imageList, G_CALLBACK(record_cover_change_image), 100, 100);
+		community_utilities_make_buttons_from_directory(instruments_path, imageList, G_CALLBACK(record_cover_change_image), 100, 100);
 	}
 }
 
