@@ -616,7 +616,9 @@ gboolean sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer n
 	char timestamp [80];
 	cem_get_time(timestamp);
 
-	gchar* outputFilename = g_strdup_printf("%s/%s.ogg",configure_get_finalized_directory(),timestamp);
+	//gchar* outputFilename = g_strdup_printf("%s/%s.ogg",configure_get_finalized_directory(),timestamp);
+	gchar* outputFilename = g_strdup_printf("%s/%s_%d.ogg",configure_get_finalized_directory(), timestamp, 
+												/*gems_profile_manager_get_userid(NULL)*/ 202179860);
 
 	gchar* message = g_strdup_printf("Rendering file named '%s'",outputFilename);
 	cem_add_to_log(message,J_LOG_INFO);
