@@ -13,17 +13,17 @@
 #include "../../cem/cem.h"
 #include "community_utilities.h"
 #include "jammosongs.h"
-#include "help.h"
 #include "jammosounds.h"
 #include "discuss.h"
 #include "mysongs.h"
 #include "profile_viewer.h"
+#include "avatar.h"
 
 static ClutterContainer *messageList = 0;
 static int selected_index = 0;
 GList* st_messages = 0;
 extern GList* paramsList;
-static gchar *id;
+static gchar* static_id;
 static TextField text;
 gchar filepath[250];
 gchar* json;
@@ -34,14 +34,23 @@ gchar* recording_filename;
 JammoSequencer* sequencer;
 static JammoSequencer* static_sequencer;
 
+
 static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data); 
+static void add_message_to_list(gpointer data, int i);
+static gboolean load_messages_from_server(const gchar* filename);
+static gboolean parse_messages_from_file(const gchar* filename);
+static gboolean single_thread_send_message(int type_);
+static gboolean sendJammoMessage(const gchar* msg_filename);
+static void load_voice_comment_from_server(ClutterActor* comment);
+static void record_voice_comment();
+static void stop_recording();
 
 
-void start_thread_view(/*GList* listOfMessages, */gchar *id_, gchar *params, int index_)
+void start_thread_view(gchar *id_, const gchar *params, int index_)
 {
 	GList *l = 0; //Iterator
 	selected_index 	= index_;
-	id 	= id_;
+	static_id = id_;
 	int numberOfMessages = 0;
 	st_messages = 0;
 
@@ -62,22 +71,22 @@ void start_thread_view(/*GList* listOfMessages, */gchar *id_, gchar *params, int
 
 		clutter_actor_show(thread_view);
 
-		if(strcmp(id, "jammosongs") == 0){
+		if(strcmp(id_, "jammosongs") == 0){
 			clutter_actor_hide(jammo_get_actor_by_id("text-answer-widgets"));
 			clutter_actor_show(jammo_get_actor_by_id("select-comment-type"));
 
-		}else if((strcmp(id, "discuss") == 0) || (strcmp(id, "mysongs") == 0)){
+		}else if((strcmp(id_, "discuss") == 0) || (strcmp(id_, "mysongs") == 0)){
 			text.text = jammo_get_actor_by_id("answer-field");
 			text.lineCount = 6;
 			text.max_characters = 500;
-			text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
+			text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)community_utilities_limit_line_count, &text);
 			clutter_text_set_text(CLUTTER_TEXT(text.text), "");
 
-		}else if(strcmp(id, "helpdesk") == 0){
+		}else if(strcmp(id_, "helpdesk") == 0){
 			text.text = jammo_get_actor_by_id("answer-field");
 			text.lineCount = 6;
 			text.max_characters = 500;
-			text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
+			text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)community_utilities_limit_line_count, &text);
 			clutter_text_set_text(CLUTTER_TEXT(text.text), "");
 		}
 		numberOfMessages = g_list_length(st_messages);
@@ -94,8 +103,9 @@ void start_thread_view(/*GList* listOfMessages, */gchar *id_, gchar *params, int
 		}	
 
 		//This is just a temporary fix for scrolling problem
-		ClutterAction *action = tangle_actor_get_action_by_type(messageList, TANGLE_TYPE_SCROLL_ACTION);
-		tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", 0, NULL);
+		ClutterAction *action = tangle_actor_get_action_by_type(CLUTTER_ACTOR(messageList), TANGLE_TYPE_SCROLL_ACTION);
+		if (action)
+			tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", 0, NULL);
 	}
 	else
 	cem_add_to_log("can't find single-thread-view", J_LOG_ERROR);
@@ -104,10 +114,10 @@ void start_thread_view(/*GList* listOfMessages, */gchar *id_, gchar *params, int
 
 /*********************************
 List filling functions
-**********************************/
 
-void add_message_to_list(gpointer data, int i) 
-{
+Used when all messages of one thread are shown
+**********************************/
+static void add_message_to_list(gpointer data, int i)  {
 	message_type *msg = data;
 
 		//int index = 0;
@@ -121,13 +131,9 @@ void add_message_to_list(gpointer data, int i)
 		strcpy(params->parent_view, "single-thread");
 		
 		Avatar avatar = {0,0,0,0};
-		guint32 avatar_id;
-		avatar_id = msg->user_id/*gems_profile_manager_get_avatar_id(gems_profile_manager_get_profile_of_user(msg->user_id))*/;
-		
-		if(avatar_id == 0)
-			avatar_id = 260; //default avatar
-		
-		community_get_avatar(&avatar, avatar_id);
+		guint32 serialized_avatar_image = avatar_give_serialized_image_for_this_id(msg->user_id);
+
+		avatar_unserialize_image(&avatar, serialized_avatar_image);
 		
 		ClutterActor* messageBackground = 0;
 		ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
@@ -145,7 +151,7 @@ void add_message_to_list(gpointer data, int i)
 		ClutterActor* date = clutter_text_new_full(TEXT_NORMAL, msg->time, &text_color);
 		//ClutterActor* avatar_ = clutter_text_new_full(TEXT_SMALL, msg->avatar, &text_color);
 
-		community_shrink_and_set_avatar(&avatar, CLUTTER_CONTAINER(avatarBackground));
+		avatar_shrink(&avatar, CLUTTER_CONTAINER(avatarBackground));
 		clutter_container_add_actor(CLUTTER_CONTAINER(listContainer), writer);
 		
 		//index = (index+1) % 3;
@@ -226,11 +232,11 @@ gboolean add_comment(TangleActor* actor, gpointer data) {
 		return FALSE;
 	}
 
-	clear_messagelist(st_messages);
+	community_utilities_clear_messagelist(st_messages);
 	
-	clear_container(messageList);
+	community_utilities_clear_container_recursively(messageList);
 	
-	start_thread_view(id, json, 0);
+	start_thread_view(static_id, json, 0);
 
 	return TRUE;
 }
@@ -249,10 +255,10 @@ gboolean add_voice_comment (TangleActor* actor, gpointer data) {
 				printf("Failed adding new message: error happened while sending message\n");
 				return FALSE;
 			}else{
-				clear_messagelist(st_messages);
-				clear_container(messageList);
+				community_utilities_clear_messagelist(st_messages);
+				community_utilities_clear_container_recursively(messageList);
 	
-				start_thread_view(id, json, 0);
+				start_thread_view(static_id, json, 0);
 			}
 		}
 	}
@@ -266,7 +272,7 @@ gboolean text_comment_view(TangleActor* actor, gpointer data) {
 	text.text = jammo_get_actor_by_id("answer-field");
 	text.lineCount = 6;
 	text.max_characters = 500;
-	text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)limit_line_count, &text);
+	text.handler_id = g_signal_connect_swapped(text.text, "text-changed", (GCallback)community_utilities_limit_line_count, &text);
 	clutter_text_set_text(CLUTTER_TEXT(text.text), "");
 
 	return TRUE;
@@ -274,11 +280,11 @@ gboolean text_comment_view(TangleActor* actor, gpointer data) {
 
 gboolean end_single_thread(TangleActor* actor, gpointer data){
 	
-	community_clear_paramslist(paramsList);
+	community_utilities_clear_paramslist(paramsList);
 	paramsList = 0;
 
-	clear_messagelist(st_messages);
-	clear_container(messageList);
+	community_utilities_clear_messagelist(st_messages);
+	community_utilities_clear_container_recursively(messageList);
 
 	if(isrecording_voice_comment)
 		stop_recording();
@@ -292,19 +298,16 @@ gboolean end_single_thread(TangleActor* actor, gpointer data){
 	g_free(recording_filename);
 	firstLaunch = TRUE;
 
-	if(strcmp(id, "helpdesk") == 0 )
-	start_helpdesk();
-
-	else if (strcmp(id, "jammosongs") == 0)
+	if (strcmp(static_id, "jammosongs") == 0)
 	start_jammosongs();
 
-	else if (strcmp(id, "jammosounds") == 0)
+	else if (strcmp(static_id, "jammosounds") == 0)
 	start_jammosounds();
 
-	else if (strcmp(id, "discuss") == 0)
+	else if (strcmp(static_id, "discuss") == 0)
 	start_discussionthreads();
 	
-	else if(strcmp(id, "mysongs") == 0)
+	else if(strcmp(static_id, "mysongs") == 0)
 	start_mysongs();
 
 	else {} //do nothing
@@ -317,8 +320,7 @@ gboolean end_single_thread(TangleActor* actor, gpointer data){
 Voice comment recording functions
 **********************************/
 
-void record_voice_comment(){
-
+static void record_voice_comment(){
 	JammoBackingTrack* backing_track;
 	JammoRecordingTrack* recording_track;
 
@@ -345,8 +347,7 @@ void record_voice_comment(){
 	g_free(backing_track_filename);
 }
 
-void stop_recording()
-{
+static void stop_recording() {
 	isrecording_voice_comment = FALSE;
 	voice_comment_ready = TRUE;
 	jammo_sequencer_stop(JAMMO_SEQUENCER(static_sequencer));
@@ -364,26 +365,24 @@ static void on_recording_stopped(JammoSequencer* sequencer_, gpointer user_data)
 Server functions
 **********************************/
 
-void load_voice_comment_from_server(ClutterActor* comment) 
-{	
-	const char *voice_comment_filename = clutter_actor_get_name(comment);
+static void load_voice_comment_from_server(ClutterActor* comment_) {
+	const char *voice_comment_filename = clutter_actor_get_name(comment_);
 
-	if(!file_exist(voice_comment_filename)){ //check if voice comment exists already in hd
+	if(!community_utilities_file_exist(voice_comment_filename)){
 		//TODO: load voice_comment.ogg from server
 		printf("Downloading file from server...\n");
 	}else{
 		//clutter_actor_set_name(song, save_path);
-		play_selected_loop(comment);
+		community_utilities_play_selected_loop(comment_);
 	}
 }
 
 
-gboolean load_messages_from_server(gchar * filename) 
-{	
+static gboolean load_messages_from_server(const gchar* filename) {
 	gboolean returnvalue = FALSE;
 	
 	//TODO: json from server and check that the file was received
-	if(!load_file_from_server(filename)){
+	if(!community_utilities_load_file_from_server(filename)){
 		printf("Load messages from server error: Couldn't download %s from server!\n", filename);
 		return FALSE;
 	}	
@@ -409,7 +408,7 @@ gboolean load_messages_from_server(gchar * filename)
 				//TODO: build user profile filename!
 				gchar* user_profile = g_strdup_printf("user_%d.json", temp->user_id);
 				
-				if(!load_file_from_server(user_profile)){
+				if(!community_utilities_load_file_from_server(user_profile)){
 					printf("Load messages from server error: Couldn't download user profiles from server!\n");
 					returnvalue = FALSE;
 				}
@@ -422,8 +421,7 @@ gboolean load_messages_from_server(gchar * filename)
 }
 
 
-gboolean sendJammoMessage(gchar* msg_filename)
-{
+static gboolean sendJammoMessage(const gchar* msg_filename) {
 	gboolean returnvalue = TRUE;
 	
 	//TODO: Check that files where successfully sended
@@ -436,8 +434,7 @@ gboolean sendJammoMessage(gchar* msg_filename)
 JSON Parsers and builders
 **********************************/
 
-gboolean parse_messages_from_file(gchar* filename) 
-{	
+static gboolean parse_messages_from_file(const gchar* filename) {
 	int j;
 	message_type *msg = 0;
 	JsonParser *parser;
@@ -497,11 +494,11 @@ gboolean parse_messages_from_file(gchar* filename)
 
 			gint msg_index = j;
 			guint32 userid = 0;
-			gchar* sender = "";	
-			gchar* title = "";
-			gchar* date = "";
-			gchar* msg_msg = "";
-			gchar* msg_filepath = "";
+			const gchar* sender = "";
+			const gchar* title = "";
+			const gchar* date = "";
+			const gchar* msg_msg = "";
+			const gchar* msg_filepath = "";
 			int type = 0;
 
 			printf("Found message!\n");
@@ -579,18 +576,15 @@ gboolean parse_messages_from_file(gchar* filename)
 }
 
 
-gboolean single_thread_send_message(int type_)
-{	
+static gboolean single_thread_send_message(int type_) {
 	printf("Single thread send message\n");
 	
 	//TODO: re-download messages json because it might have changed in meanwhile
-	if(!load_file_from_server(json)){
+	if(!community_utilities_load_file_from_server(json)){
 		printf("Single_thread_send_message error: Couldn't download json file from server for writing!\n");
 		return FALSE;
 	}
 
-	time_type now;
-	now = get_current_time();
 	gboolean returnvalue = FALSE;
 	gchar *msg = "";
 	gchar* comment_filepath = "";
@@ -601,8 +595,11 @@ gboolean single_thread_send_message(int type_)
 		msg = g_strdup_printf("%s", (gchar*)clutter_text_get_text(CLUTTER_TEXT(text.text))); 
 
 	gint indexOfMessage = 0;
-	gchar *date = now.time;
-	guint32 user_id = /*gems_profile_manager_get_userid(NULL)*/TEST_USERID;
+
+	char date [80];
+	cem_get_time(date);
+	guint32 user_id = TEST_USERID; //TODO: user_id =gems_profile_manager_get_userid(NULL)
+	gchar* sender = avatar_give_username_for_this_id(user_id);
 	int type = type_;
 	gchar *title;
 	
@@ -613,23 +610,11 @@ gboolean single_thread_send_message(int type_)
 		title = g_strdup_printf("New comment");
 	}
 
-	gchar* profile_path = g_strdup_printf("%s/user_%d.csv", configure_get_jammo_directory(), /*avatar_id*/TEST_USERID);
-	gchar *sender = "Anonymous"; 
-	char line[200];
-		
-	FILE *f;
-	if ((f = fopen(profile_path, "r")) != NULL){
-		while(fgets(line, sizeof(line), f)){
-			strtok(line, ", ");  
-    	  	sender = strtok(NULL, ", ");	
-		}
-	}
-	g_free(profile_path);
+	guint32 id = TEST_USERID; // TODO: use gems_profile_manager_get_userid(NULL)
 
 	if(type_ == VOICE_COMMENT){	
 		comment_filepath = g_strdup_printf("%s/last_recorded.ogg", configure_get_temp_directory());
-		newname = g_strdup_printf("%s/voice_comment_%d_%s.ogg", configure_get_temp_directory(), /*gems_profile_manager_get_userid(NULL)*/
-													TEST_USERID, now.time);
+		newname = g_strdup_printf("%s/voice_comment_%d_%s.ogg", configure_get_temp_directory(),id, date);
 		rename(comment_filepath, newname);
 	}
 
@@ -757,9 +742,12 @@ gboolean single_thread_send_message(int type_)
 	if(strcmp(msg, "") != 0)
 		g_free(msg);
 
-	g_free(newname);
+	if((type == VOICE_COMMENT)){
+		g_free(newname);
+	}
 	g_free(dest_filepath);
 	g_free(title);
+	g_free(sender);
 
 	printf("End of single thread send message\n");
 	return returnvalue;
