@@ -19,8 +19,9 @@ enum {
 	PROP_SPEAK_ONCE,
 	PROP_IDLE_SPEECH,
 	PROP_DURATION,
-	PROP_OFFSET_X,
-	PROP_OFFSET_Y
+	PROP_HIGHLIGHT_X,
+	PROP_HIGHLIGHT_Y,
+	PROP_HIGHLIGHT_SET
 };
 
 enum {
@@ -34,9 +35,10 @@ struct _JammoMentorActivityPrivate {
 	gchar* speech;
 	gchar* idle_speech;
 	guint duration;
-	gfloat offset_x;
-	gfloat offset_y;
+	gfloat highlight_x;
+	gfloat highlight_y;
 	guint speak_once : 1;
+	guint highlight : 1;
 };
 
 static void on_mentor_spoken(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer user_data);
@@ -133,33 +135,48 @@ void jammo_mentor_activity_set_duration(JammoMentorActivity* mentor_activity, gu
 	}
 }
 
-gfloat jammo_mentor_activity_get_offset_x(JammoMentorActivity* mentor_activity) {
-	g_return_val_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity), 0.0);
-
-	return mentor_activity->priv->offset_x;
-}
-
-void jammo_mentor_activity_set_offset_x(JammoMentorActivity* mentor_activity, gfloat offset_x) {
+void jammo_mentor_activity_get_highlight(JammoMentorActivity* mentor_activity, gfloat* highlight_x_return, gfloat* highlight_y_return) {
 	g_return_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity));
 
-	if (mentor_activity->priv->offset_x != offset_x) {
-		mentor_activity->priv->offset_x = offset_x;
-		g_object_notify(G_OBJECT(mentor_activity), "offset-x");
+	if (highlight_x_return) {
+		*highlight_x_return = mentor_activity->priv->highlight_x;
+	}
+	if (highlight_y_return) {
+		*highlight_y_return = mentor_activity->priv->highlight_y;
 	}
 }
 
-gfloat jammo_mentor_activity_get_offset_y(JammoMentorActivity* mentor_activity) {
-	g_return_val_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity), 0.0);
-
-	return mentor_activity->priv->offset_y;
-}
-
-void jammo_mentor_activity_set_offset_y(JammoMentorActivity* mentor_activity, gfloat offset_y) {
+void jammo_mentor_activity_set_highlight(JammoMentorActivity* mentor_activity, gfloat highlight_x, gfloat highlight_y) {
 	g_return_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity));
 
-	if (mentor_activity->priv->offset_y != offset_y) {
-		mentor_activity->priv->offset_y = offset_y;
-		g_object_notify(G_OBJECT(mentor_activity), "offset-y");
+	g_object_freeze_notify(G_OBJECT(mentor_activity));
+
+	if (mentor_activity->priv->highlight_x != highlight_x) {
+		mentor_activity->priv->highlight_x = highlight_x;
+		g_object_notify(G_OBJECT(mentor_activity), "highlight-x");
+	}
+	if (mentor_activity->priv->highlight_y != highlight_y) {
+		mentor_activity->priv->highlight_y = highlight_y;
+		g_object_notify(G_OBJECT(mentor_activity), "highlight-y");
+	}
+	
+	jammo_mentor_activity_set_highlight_set(mentor_activity, TRUE);
+	
+	g_object_thaw_notify(G_OBJECT(mentor_activity));
+}
+
+gboolean jammo_mentor_activity_get_highlight_set(JammoMentorActivity* mentor_activity) {
+	g_return_val_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity), FALSE);
+
+	return mentor_activity->priv->highlight;
+}
+
+void jammo_mentor_activity_set_highlight_set(JammoMentorActivity* mentor_activity, gboolean is_set) {
+	g_return_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity));
+
+	if (mentor_activity->priv->highlight != is_set) {
+		mentor_activity->priv->highlight = is_set;
+		g_object_notify(G_OBJECT(mentor_activity), "highlight-set");	
 	}
 }
 
@@ -194,14 +211,22 @@ static void jammo_mentor_activity_activate(TangleActivity* activity) {
 			 mentor_activity->priv->duration > 0);
 	
 	jammo_mentor_shut_up(mentor);
-	if (mentor_activity->priv->speech) {
+	if (mentor_activity->priv->highlight) {
+		if (mentor_activity->priv->speech) {
+			if (mentor_activity->priv->speak_once) {
+				jammo_mentor_speak_and_highlight_once_with_callback(mentor, mentor_activity->priv->speech, mentor_activity->priv->highlight_x, mentor_activity->priv->highlight_y, on_mentor_spoken, mentor_activity);
+			} else {
+				jammo_mentor_speak_and_highlight_with_callback(mentor, mentor_activity->priv->speech, mentor_activity->priv->highlight_x, mentor_activity->priv->highlight_y, on_mentor_spoken, mentor_activity);
+			}
+		} else if (mentor_activity->priv->duration > 0) {
+			jammo_mentor_highlight_with_callback(mentor, mentor_activity->priv->highlight_x, mentor_activity->priv->highlight_y, mentor_activity->priv->duration, on_mentor_spoken, mentor_activity);
+		}
+	} else if (mentor_activity->priv->speech) {
 		if (mentor_activity->priv->speak_once) {
-			jammo_mentor_speak_and_highlight_once_with_callback(mentor, mentor_activity->priv->speech, mentor_activity->priv->offset_x, mentor_activity->priv->offset_y, on_mentor_spoken, mentor_activity);
+			jammo_mentor_speak_once_with_callback(mentor, mentor_activity->priv->speech, on_mentor_spoken, mentor_activity);
 		} else {
-			jammo_mentor_speak_and_highlight_with_callback(mentor, mentor_activity->priv->speech, mentor_activity->priv->offset_x, mentor_activity->priv->offset_y, on_mentor_spoken, mentor_activity);
+			jammo_mentor_speak_with_callback(mentor, mentor_activity->priv->speech, on_mentor_spoken, mentor_activity);
 		}
-	} else if (mentor_activity->priv->duration > 0) {
-		jammo_mentor_highlight_with_callback(mentor, mentor_activity->priv->offset_x, mentor_activity->priv->offset_y, mentor_activity->priv->duration, on_mentor_spoken, mentor_activity);
 	}
 	
 	if (mentor_activity->priv->idle_speech) {
@@ -230,11 +255,14 @@ static void jammo_mentor_activity_set_property(GObject* object, guint prop_id, c
 		case PROP_DURATION:
 			jammo_mentor_activity_set_duration(mentor_activity, g_value_get_uint(value));
 			break;
-		case PROP_OFFSET_X:
-			jammo_mentor_activity_set_offset_x(mentor_activity, g_value_get_float(value));
+		case PROP_HIGHLIGHT_X:
+			jammo_mentor_activity_set_highlight(mentor_activity, g_value_get_float(value), mentor_activity->priv->highlight_y);
 			break;
-		case PROP_OFFSET_Y:
-			jammo_mentor_activity_set_offset_y(mentor_activity, g_value_get_float(value));
+		case PROP_HIGHLIGHT_Y:
+			jammo_mentor_activity_set_highlight(mentor_activity, mentor_activity->priv->highlight_x, g_value_get_float(value));
+			break;
+		case PROP_HIGHLIGHT_SET:
+			jammo_mentor_activity_set_highlight_set(mentor_activity, g_value_get_boolean(value));
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -263,11 +291,14 @@ static void jammo_mentor_activity_get_property(GObject* object, guint prop_id, G
 		case PROP_DURATION:
 			g_value_set_uint(value, mentor_activity->priv->duration);
 			break;
-		case PROP_OFFSET_X:
-			g_value_set_float(value, mentor_activity->priv->offset_x);
+		case PROP_HIGHLIGHT_X:
+			g_value_set_float(value, mentor_activity->priv->highlight_x);
 			break;
-		case PROP_OFFSET_Y:
-			g_value_set_float(value, mentor_activity->priv->offset_y);
+		case PROP_HIGHLIGHT_Y:
+			g_value_set_float(value, mentor_activity->priv->highlight_y);
+			break;
+		case PROP_HIGHLIGHT_SET:
+			g_value_set_boolean(value, mentor_activity->priv->highlight);
 			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -355,31 +386,41 @@ static void jammo_mentor_activity_class_init(JammoMentorActivityClass* mentor_ac
 	                                                  0, G_MAXUINT, 0,
 	                                                  G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	/**
-	 * JammoMentorActivity:offset-x:
+	 * JammoMentorActivity:highlight-x:
 	 *
-	 * The horizontal offset of a movement related to highlighting.
-	 * Leave both horizontal and vertivcal offset to zero, if you do not want to move a
-	 * mentor when the mentor_activity is executed.
+	 * The horizontal coordinate of the highlight position.
+	 * Setting this property sets also a :highlight-set property TRUE as a side effect.
 	 */
-	g_object_class_install_property(gobject_class, PROP_OFFSET_X,
-	                                g_param_spec_float("offset-x",
-	                                                   "Offset X",
-	                                                   "The horizontal offset of a movement related to highlighting",
+	g_object_class_install_property(gobject_class, PROP_HIGHLIGHT_X,
+	                                g_param_spec_float("highlight-x",
+	                                                   "Highlight X",
+	                                                   "The horizontal coordinate of the highlight position",
 	                                                   -G_MAXFLOAT, G_MAXFLOAT, 0.0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	/**
-	 * JammoMentorActivity:offset-y:
+	 * JammoMentorActivity:highlight-y:
 	 *
-	 * The vertical offset of a movement related to highlighting.
-	 * Leave both horizontal and vertivcal offset to zero, if you do not want to move a
-	 * mentor when the mentor_activity is executed.
+	 * The vertical coordinate of the highlight position.
+	 * Setting this property sets also a :highlight-set property TRUE as a side effect.
 	 */
-	g_object_class_install_property(gobject_class, PROP_OFFSET_Y,
-	                                g_param_spec_float("offset-y",
-	                                                   "Offset Y",
-	                                                   "The vertical offset of a movement related to highlighting",
+	g_object_class_install_property(gobject_class, PROP_HIGHLIGHT_Y,
+	                                g_param_spec_float("highlight-y",
+	                                                   "Highlight Y",
+	                                                   "The vertical coordinate of the highlight position",
 	                                                   -G_MAXFLOAT, G_MAXFLOAT, 0.0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoMentorActivity:highlight-set:
+	 *
+	 * Whether the mentor highlights the given position.
+	 * See :highlight-x and :highlight-y.
+	 */
+	g_object_class_install_property(gobject_class, PROP_HIGHLIGHT_SET,
+	                                g_param_spec_boolean("highlight-set",
+	                                                     "Highlight Set",
+	                                                     "Whether the mentor highlights the given position",
+	                                                     FALSE,
+	                                                     G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoMentorActivity::spoken:
