@@ -34,6 +34,8 @@ enum {
 	PROP_0,
 	PROP_STANDBY_SCALE,
 	PROP_ACTIVE_SCALE,
+	PROP_HOTSPOT_X,
+	PROP_HOTSPOT_Y,
 	PROP_IDLE_SPEECH,
 	PROP_IDLE_TIMEOUT,
 	PROP_PASSIVE,
@@ -43,6 +45,8 @@ enum {
 struct _JammoMentorPrivate {
 	gfloat standby_scale;
 	gfloat active_scale;
+	gfloat hotspot_x;
+	gfloat hotspot_y;
 	gchar* idle_speech;
 	JammoMentorSpokenCallback idle_speech_spoken_callback;
 	gpointer idle_speech_spoken_user_data;
@@ -65,7 +69,7 @@ struct _JammoMentorPrivate {
 	guint passive : 1;
 };
 
-static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data);
+static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat highlight_x, gfloat highlight_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data);
 static void set_idle_timeout(JammoMentor* mentor, gboolean activate);
 static void on_mce_tklock_mode_sig(DBusGProxy* proxy, const gchar* mode, gpointer user_data);
 
@@ -112,6 +116,34 @@ void jammo_mentor_set_active_scale(JammoMentor* mentor, gfloat scale) {
 	}
 }
 
+void jammo_mentor_get_hotspot(JammoMentor* mentor, gfloat* hotspot_x_return, gfloat* hotspot_y_return) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
+	if (hotspot_x_return) {
+		*hotspot_x_return = mentor->priv->hotspot_x;
+	}
+	if (hotspot_y_return) {
+		*hotspot_y_return = mentor->priv->hotspot_y;
+	}
+}
+
+void jammo_mentor_set_hotspot(JammoMentor* mentor, gfloat hotspot_x, gfloat hotspot_y) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
+	g_object_freeze_notify(G_OBJECT(mentor));
+
+	if (mentor->priv->hotspot_x != hotspot_x) {
+		mentor->priv->hotspot_x = hotspot_x;
+		g_object_notify(G_OBJECT(mentor), "hotspot-x");
+	}
+	if (mentor->priv->hotspot_y != hotspot_y) {
+		mentor->priv->hotspot_y = hotspot_y;
+		g_object_notify(G_OBJECT(mentor), "hotspot-y");
+	}
+	
+	g_object_thaw_notify(G_OBJECT(mentor));
+}
+
 void jammo_mentor_speak(JammoMentor* mentor, const gchar* speech) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
@@ -124,28 +156,28 @@ void jammo_mentor_speak_with_callback(JammoMentor* mentor, const gchar* speech,
 	speak(mentor, speech, FALSE, 0.0, 0.0, DEFAULT_DURATION, callback, user_data);
 }
 
-void jammo_mentor_speak_and_highlight(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y) {
+void jammo_mentor_speak_and_highlight(JammoMentor* mentor, const gchar* speech, gfloat highlight_x, gfloat highlight_y) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	speak(mentor, speech, TRUE, offset_x, offset_y, DEFAULT_DURATION, NULL, NULL);
+	speak(mentor, speech, TRUE, highlight_x, highlight_y, DEFAULT_DURATION, NULL, NULL);
 }
 
-void jammo_mentor_speak_and_highlight_with_callback(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {
+void jammo_mentor_speak_and_highlight_with_callback(JammoMentor* mentor, const gchar* speech, gfloat highlight_x, gfloat highlight_y, JammoMentorSpokenCallback callback, gpointer user_data) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	speak(mentor, speech, TRUE, offset_x, offset_y, DEFAULT_DURATION, callback, user_data);
+	speak(mentor, speech, TRUE, highlight_x, highlight_y, DEFAULT_DURATION, callback, user_data);
 }
 
-void jammo_mentor_highlight(JammoMentor* mentor, gfloat offset_x, gfloat offset_y, guint duration) {
+void jammo_mentor_highlight(JammoMentor* mentor, gfloat highlight_x, gfloat highlight_y, guint duration) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	speak(mentor, NULL, TRUE, offset_x, offset_y, duration, NULL, NULL);
+	speak(mentor, NULL, TRUE, highlight_x, highlight_y, duration, NULL, NULL);
 }
 
-void jammo_mentor_highlight_with_callback(JammoMentor* mentor, gfloat offset_x, gfloat offset_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data) {
+void jammo_mentor_highlight_with_callback(JammoMentor* mentor, gfloat highlight_x, gfloat highlight_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	speak(mentor, NULL, TRUE, offset_x, offset_y, duration, callback, user_data);
+	speak(mentor, NULL, TRUE, highlight_x, highlight_y, duration, callback, user_data);
 }
 
 void jammo_mentor_speak_once(JammoMentor* mentor, const gchar* speech) {
@@ -166,21 +198,21 @@ void jammo_mentor_speak_once_with_callback(JammoMentor* mentor, const gchar* spe
 	}
 }
 
-void jammo_mentor_speak_and_highlight_once(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y) {
+void jammo_mentor_speak_and_highlight_once(JammoMentor* mentor, const gchar* speech, gfloat highlight_x, gfloat highlight_y) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
-		speak(mentor, speech, TRUE, offset_x, offset_y, DEFAULT_DURATION, NULL, NULL);
+		speak(mentor, speech, TRUE, highlight_x, highlight_y, DEFAULT_DURATION, NULL, NULL);
 	}
 }
 
-void jammo_mentor_speak_and_highlight_once_with_callback(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {
+void jammo_mentor_speak_and_highlight_once_with_callback(JammoMentor* mentor, const gchar* speech, gfloat highlight_x, gfloat highlight_y, JammoMentorSpokenCallback callback, gpointer user_data) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
-		speak(mentor, speech, TRUE, offset_x, offset_y, DEFAULT_DURATION, callback, user_data);
+		speak(mentor, speech, TRUE, highlight_x, highlight_y, DEFAULT_DURATION, callback, user_data);
 	}
 }
 
@@ -327,6 +359,12 @@ static void jammo_mentor_set_property(GObject* object, guint prop_id, const GVal
 		case PROP_ACTIVE_SCALE:
 			jammo_mentor_set_active_scale(mentor, g_value_get_float(value));
 			break;
+		case PROP_HOTSPOT_X:
+			jammo_mentor_set_hotspot(mentor, g_value_get_float(value), mentor->priv->hotspot_y);
+			break;
+		case PROP_HOTSPOT_Y:
+			jammo_mentor_set_hotspot(mentor, mentor->priv->hotspot_x, g_value_get_float(value));
+			break;
 		case PROP_IDLE_SPEECH:
 			jammo_mentor_set_idle_speech(mentor, g_value_get_string(value));
 			break;
@@ -354,6 +392,12 @@ static void jammo_mentor_get_property(GObject* object, guint prop_id, GValue* va
 		case PROP_ACTIVE_SCALE:
 			g_value_set_float(value, mentor->priv->active_scale);
 			break;
+		case PROP_HOTSPOT_X:
+			g_value_set_float(value, mentor->priv->hotspot_x);
+			break;
+		case PROP_HOTSPOT_Y:
+			g_value_set_float(value, mentor->priv->hotspot_y);
+			break;
 		case PROP_IDLE_SPEECH:
 			g_value_set_string(value, mentor->priv->idle_speech);
 			break;
@@ -441,6 +485,28 @@ static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	                                                   "The scaling that is efective when the mentor is active",
 	                                                   0.0, G_MAXFLOAT, 0.0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	/**
+	 * JammoMentor:hotspot-x:
+	 *
+	 * The horizontal offset of the point within the mentor to be used when highlighting.
+	 */
+	g_object_class_install_property(gobject_class, PROP_HOTSPOT_X,
+	                                g_param_spec_float("hotspot-x",
+	                                                   "Hotspot X",
+	                                                   "The horizontal offset of the point within the mentor to be used when highlighting",
+	                                                   -G_MAXFLOAT, G_MAXFLOAT, 0.0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoMentor:hotspoty:
+	 *
+	 * The vertical offset of the point within the mentor to be used when highlighting.
+	 */
+	g_object_class_install_property(gobject_class, PROP_HOTSPOT_Y,
+	                                g_param_spec_float("hotspot-y",
+	                                                   "Hotspot Y",
+	                                                   "The vertical offset of the point within the mentor to be used when highlighting",
+	                                                   -G_MAXFLOAT, G_MAXFLOAT, 0.0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	/**
 	 * JammoMentor:idle-speech:
 	 *
@@ -567,7 +633,14 @@ static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
 	if (next_speech && !mentor->priv->interrupted) {
 		real_speak(mentor, next_speech, callback, speech, data);
 	} else {
-		tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, DEFAULT_DURATION, "squint-x", 0.0, "squint-y", 0.0, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
+		tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, DEFAULT_DURATION,
+	                	     "squint-x", 0.0,
+				     "squint-y", 0.0,
+	                	     "rotation-angle-x", 0.0,
+	                	     "rotation-angle-y", 0.0,
+				     "scale-x", mentor->priv->standby_scale,
+				     "scale-y", mentor->priv->standby_scale,
+				     NULL);
 
 		set_idle_timeout(mentor, TRUE);
 
@@ -590,7 +663,14 @@ static void on_animation_completed(ClutterAnimation* animation, gpointer user_da
 	vault = TANGLE_VAULT(user_data);
 	tangle_vault_get(vault, 3, JAMMO_TYPE_MENTOR, &mentor, G_TYPE_POINTER, &callback, G_TYPE_POINTER, &data);
 
-	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, DEFAULT_DURATION, "squint-x", 0.0, "squint-y", 0.0, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
+	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, DEFAULT_DURATION,
+	                     "squint-x", 0.0,
+			     "squint-y", 0.0,
+	                     "rotation-angle-x", 0.0,
+	                     "rotation-angle-y", 0.0,
+			     "scale-x", mentor->priv->standby_scale,
+			     "scale-y", mentor->priv->standby_scale,
+			     NULL);
 
 	set_idle_timeout(mentor, TRUE);
 
@@ -644,8 +724,12 @@ static void real_speak(JammoMentor* mentor, const gchar* next_speech, JammoMento
 	jammo_sample_play(mentor->priv->active_sample);
 }
 
-static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data) {
-	ClutterAnimation* animation;
+static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat highlight_x, gfloat highlight_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data) {
+	ClutterAnimation* animation = NULL;
+	gfloat x, y, width, height, squint_x, squint_y;
+	ClutterVertex rotation_center_x = { 0 };
+	ClutterVertex rotation_center_y = { 0 };
+	gdouble rotation_angle_x, rotation_angle_y;
 	TangleVault* vault;
 
 	if (mentor->priv->passive) {
@@ -662,11 +746,48 @@ static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight,
 			jammo_sample_stop(mentor->priv->active_sample);
 		}
 
-		animation = tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, duration, "squint-x", offset_x, "squint-y", offset_y, "scale-x", mentor->priv->active_scale, "scale-y", mentor->priv->active_scale, NULL);
+		if (highlight) {
+			clutter_actor_get_position(CLUTTER_ACTOR(mentor), &x, &y);
+			clutter_actor_get_size(CLUTTER_ACTOR(mentor), &width, &height);
+			
+			squint_x = highlight_x - x - (mentor->priv->hotspot_x * mentor->priv->active_scale);
+			squint_y = highlight_y - y - (mentor->priv->hotspot_y * mentor->priv->active_scale);
+			
+			rotation_center_x.y = height / 2.0;
+			rotation_center_y.x = width / 2.0;
+			g_object_set(CLUTTER_ACTOR(mentor), "rotation-center-x", &rotation_center_x, "rotation-center-y", &rotation_center_y, NULL);
+
+			if (squint_x < 0.0) {
+				rotation_angle_y = 180.0;
+				squint_x = -squint_x - width * mentor->priv->active_scale;
+			} else {
+				rotation_angle_y = 0.0;
+			}
+			if (squint_y < 0.0) {
+				rotation_angle_x = 180.0;
+				squint_y = -squint_y - height * mentor->priv->active_scale;
+			} else {
+				rotation_angle_x = 0.0;
+			}
+
+			animation = tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, duration,
+			                                 "squint-x", squint_x,
+							 "squint-y", squint_y,
+							 "rotation-angle-x", rotation_angle_x,
+							 "rotation-angle-y", rotation_angle_y,
+							 "scale-x", mentor->priv->active_scale,
+							 "scale-y", mentor->priv->active_scale,
+							 NULL);
+		} else {
+			animation = tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, duration,
+			                                 "scale-x", mentor->priv->active_scale,
+							 "scale-y", mentor->priv->active_scale,
+							 NULL);		
+		}
 
 		if (speech) {
 			real_speak(mentor, speech, callback, speech, user_data);
-		} else {
+		} else if (animation) {
 			vault = tangle_vault_new(3, JAMMO_TYPE_MENTOR, mentor, G_TYPE_POINTER, callback, G_TYPE_POINTER, user_data);
 			tangle_signal_connect_vault(animation, "completed", G_CALLBACK(on_animation_completed), vault);
 
