@@ -2,6 +2,7 @@
 #include "config.h"
 #include "../jammo.h"
 #include "../7-12gui/community_utilities.h"
+#include "../7-12gui/avatar.h"
 #include "../7-12gui/avatar_editor.h"
 #include "../../gems/gems_utils.h"
 #include "../../gems/gems.h"
@@ -330,7 +331,7 @@ pg_set_select_option_screen(ClutterActor *stage)
 	change_username((ClutterText*)text);
 	
 	// Use the default avatar and add it to avatar container
-	community_get_avatar(&avtr,260);
+	avatar_unserialize_image(&avtr,260);
 	set_avatar(&avtr,avatar_container,NULL,NULL);
 	
 #else
