@@ -503,7 +503,7 @@ void StorageAgent::clearEncryptedData()
 /* Read encrypted profile - raw
 *  parameters: username, password hash, salt, profile data hash, encrypted profile data, profile length
 */
-gint StorageAgent::readProfile(const gchar* username)
+GemsProfileLoadAction StorageAgent::readProfile(const gchar* username)
 {
 	gchar* profilefile = g_strjoin(NULL,username,PROFILE_FILE_EXT,NULL);
 	gchar* filename = g_build_filename(configure_get_jammo_directory(),JAMMOPROFILE,profilefile,NULL);
