@@ -3,7 +3,7 @@
  *
  * This file is part of JamMo.
  *
- * (c) 2009-2010 University of Oulu, Lappeenranta University of Technology
+ * (c) 2009-2011 University of Oulu, Lappeenranta University of Technology
  *
  * Authors: Jussi Laakkonen <jussi.laakkonen@lut.fi>
  *	    Tommi Kallonen  <tommi.kallonen@lut.fi>
@@ -13,13 +13,30 @@
 #ifndef __GEMS_DEFINITIONS_
 #define __GEMS_DEFINITIONS_
 
-// Event list operation types for CHUM
-// with these CHUM can specify what to do with a midi or slider event list
+/**
+ * GemsEventListOperation:
+ * @GEMS_EVENTLIST_REPLACE:
+ *
+ * Event list operation types for CHUM, with these CHUM can specify what to do
+ * with a midi or slider event list
+ */
 typedef enum
 {
 	GEMS_EVENTLIST_REPLACE
 } GemsEventListOperation;
 
+/**
+ * GemsGroupControlCallbackType:
+ * @GEMS_GROUP_CONTROL_NOT_IN_GROUP:
+ * @GEMS_GROUP_CONTROL_GROUP_NOT_ACTIVE:
+ * @GEMS_GROUP_CONTROL_GROUP_FULL:
+ * @GEMS_GROUP_CONTROL_ALREADY_IN_GROUP:
+ * @GEMS_GROUP_CONTROL_GROUP_LOCKED:
+ * @GEMS_GROUP_CONTROL_GROUP_ADD_ERROR:
+ * @GEMS_GROUP_CONTROL_NOT_GROUP_OWNER:
+ *
+ * Group control types
+ */
 typedef enum
 {
 	GEMS_GROUP_CONTROL_NOT_IN_GROUP,
@@ -31,19 +48,17 @@ typedef enum
 	GEMS_GROUP_CONTROL_NOT_GROUP_OWNER
 } GemsGroupControlCallbackType;
 
+/**
+ * GemsGameCallbackType
+ * @GEMS_GAME_JOINED_PAIR_COMPOSITION:
+ *
+ * Types for game callback
+ */
 typedef enum
 {
 	GEMS_GAME_JOINED_PAIR_COMPOSITION
 } GemsGameCallbackType;
 
-#define ERROR_GROUP_NOT_ACTIVE_TYPE 10008
-#define ERROR_INVALID_GROUP_ID_TYPE 10009
-#define ERROR_GROUP_FULL_TYPE 10010
-#define ERROR_ALREADY_IN_GROUP_TYPE 10011
-#define ERROR_GROUP_LOCKED_TYPE 10012
-#define ERROR_GROUP_ADD_ERROR_TYPE 10013
-#define ERROR_NOT_GROUP_OWNER_TYPE 10014
-
 #define JAMMO_NETWORK_BUFFER_MAX_SIZE 2048
 // TODO change to use sha256 -> 32 bytes
 #define JAMMO_MESSAGE_DIGEST_SIZE 20 // 160 bit SHA1
@@ -76,38 +91,91 @@ typedef enum
 #define TEACHER_PROFILE_REQUEST_LIMIT 2.00
 #define TEACHER_PROFILE_REQUEST_MAX_COUNT 2
 
-// Used as return values when searching connections from various lists
-#define NOT_IN_LIST 0
-#define IN_INITIALIZED_LIST 1
-#define IN_JAMMO_SERVICE_LIST 2
-#define IN_CONNECTING_LIST 3
-#define IN_CONNECTED_LIST 4
-#define IN_REJECTED_LIST 5
+/**
+ * connection_search:
+ * @NOT_IN_LIST: Not found from any of the lists
+ * @IN_INITIALIZED_LIST: In accepted connections list
+ * @IN_JAMMO_SERVICE_LIST: In the JamMo service handshake process
+ * @IN_CONNECTING_LIST: In connections initialized to other devices
+ * @IN_CONNECTED_LIST: In connected list
+ * @IN_REJECTED_LIST: In rejected list
+ *
+ * Used as return values when searching connections from various lists
+ */
+typedef enum {
+	NOT_IN_LIST = 0,
+	IN_INITIALIZED_LIST,
+	IN_JAMMO_SERVICE_LIST,
+	IN_CONNECTING_LIST,
+	IN_CONNECTED_LIST,
+	IN_REJECTED_LIST,
+} connection_search;
 
-// Group return velues
-#define ADDED_TO_GROUP 0
-#define REQUEST_SENT 1
-#define ALREADY_IN_GROUP 2
-#define CANNOT_ADD 3
-#define REMOVED_OK 4
-#define NOT_IN_GROUP 5
-#define GROUP_LOCKED 6
-#define CANNOT_CONNECT_TO_OWNER 7
-#define NO_OWNER 8
-#define NO_MATCHING_GROUP 9
-#define GROUP_FULL 10
-#define REQUEST_NOT_SENT 11
+/**
+ * GemsGroupAction:
+ * @ERROR_CANNOT_EXEC: Error, cannot execute the requested action
+ * @ADDED_TO_GROUP: User was added to group
+ * @REQUEST_SENT: Request was sent to recipient
+ * @ALREADY_IN_GROUP: User already in the group
+ * @CANNOT_ADD: It is not possible to add user
+ * @REMOVED_OK: User succesfully removed from group
+ * @NOT_IN_GROUP: User is not in group
+ * @GROUP_LOCKED: Group is locked, it is not adverted nor it can be joined
+ * @CANNOT_CONNECT_TO_OWNER: Cannot connect to owner or no such connection 
+ * exists
+ * @NO_OWNER: There is no owner set for group
+ * @NO_MATCHING_GROUP: No group with given id is found
+ * @GROUP_FULL: Group is full
+ * @REQUEST_NOT_SENT: The request was not sent
+ *
+ * Group action return values. Tells the result of action.
+ */
+typedef enum {
+	ERROR_CANNOT_EXEC = -1,
+	ADDED_TO_GROUP = 0,
+	REQUEST_SENT,
+	ALREADY_IN_GROUP,
+	CANNOT_ADD,
+	REMOVED_OK,
+	NOT_IN_GROUP,
+	GROUP_LOCKED,
+	CANNOT_CONNECT_TO_OWNER,
+	NO_OWNER,
+	NO_MATCHING_GROUP,
+	GROUP_FULL,
+	REQUEST_NOT_SENT,
+} GemsGroupAction;
 
-// Group status
-#define IN_GROUP 111
-#define JOINING 112
-#define LEAVING 113
-// NOT_ACTIVE in group = not in group
+/**
+ * GemsGroupStatus:
+ * @IN_GROUP: User is in the group
+ * @JOINING: User is joining to group, request is sent.
+ * @LEAVING: User is leaving from group, request is sent.
+ * @NONE: equals to #NOT_ACTIVE
+ *
+ * Group status
+ */
+typedef enum {
+	IN_GROUP = 111,
+	JOINING = 112,
+	LEAVING = 113,
+	NONE = NOT_ACTIVE, // NOT_ACTIVE in group = not in group
+} GemsGroupStatus;
 
-// Error type
-#define ERROR_CONNECTION 21
-#define ERROR_REJECTED 22
-#define ERROR_ALREADY_CONNECTED 23
+/**
+ * GemsConnErrType:
+ * @ERROR_CONNECTION: Connection error, connection could not be established
+ * @ERROR_REJECTED: Connection was rejected because of version mismatch
+ * @ERROR_ALREADY_CONNECTED: Connection rejected since a connection already
+ * exists
+ *
+ * Error types.
+ */
+typedef enum {
+	ERROR_CONNECTION = 21,
+	ERROR_REJECTED,
+	ERROR_ALREADY_CONNECTED,
+} GemsConnErrType;
 
 /* NETWORK DEFINITIONS */
 
@@ -229,8 +297,6 @@ typedef enum
 #define GROUP_TYPE_WS_NET 10315
 
 
-
-
 // Group themes
 // TODO define group themes
 
@@ -302,35 +368,90 @@ typedef enum
 
 #define PROF_DEFAULT_AVATARID 260
 
-// Security - extraction of envelope return values
-#define SECURITY_OK 10190
-#define SECURITY_CORRUPT_MESSAGE 10191 // hash value in envelope doesn't match the content
-#define SECURITY_VERIFY_FAILED 10192 // cannot verify the signature of hash
+/**
+ * GemsEnvelopeCheck:
+ * @SECURITY_OK: Envelope is valid
+ * @SECURITY_CORRUPT_MESSAGE: hash value in envelope doesn't match the content
+ * @SECURITY_VERIFY_FAILED: cannot verify the signature of hash
+ *
+ * Security - extraction of envelope return values
+ */
+typedef enum {
+	SECURITY_OK = 10190,
+	SECURITY_CORRUPT_MESSAGE = 10191, // hash value in envelope doesn't match the content
+	SECURITY_VERIFY_FAILED = 10192, // cannot verify the signature of hash
+} GemsEnvelopeCheck;
 
-// authentication returnvalues
-#define LOGIN_PROFILE_READ_ERROR -3
-#define LOGIN_INVALID_PROFILE -2
-#define LOGIN_NO_PROFILE -1
-#define LOGIN_OK 0
-#define LOGIN_INVALID_PARAMS 1
-#define LOGIN_CANNOT_INIT_PASSWD 2
-#define LOGIN_CANNOT_INIT_SECURITY 3
-#define LOGIN_INVALID_PASSWORD 4
-#define LOGIN_PROFILE_HASH_FAIL 5
-#define LOGIN_PROFILE_CORRUPT 6
-#define CHANGE_USER_OK 0
-#define CHANGE_USER_WAITING_PROFILE 1
-#define CHANGE_USER_LOGOUT_REQUIRED 2
-#define CHANGE_USER_NO_PROFILE -1
-#define CHANGE_USER_NO_USERNAME 3
+/**
+ * GemsLoginAction:
+ * @LOGIN_PROFILE_READ_ERROR: Cannot login, profile file cannot be read
+ * @LOGIN_INVALID_PROFILE: Cannot login, profile for user is invalid
+ * @LOGIN_NO_PROFILE: Cannot login, no such profile exists
+ * @LOGIN_OK: Login success
+ * @LOGIN_INVALID_PARAMS: Cannot login, given parameters are invalid
+ * @LOGIN_CANNOT_INIT_PASSWD: Cannot login, password cannot be created
+ * @LOGIN_CANNOT_INIT_SECURITY: Cannot login, security contexts cannot be 
+ * initilialized
+ * @LOGIN_INVALID_PASSWORD: Cannot login, password is invalid
+ * @LOGIN_PROFILE_HASH_FAIL: Cannot login, hashing of content failed
+ * @LOGIN_PROFILE_CORRUPT: Cannot login, the profile file is corrupt/unreadable
+ *
+ * authentication returnvalues
+ */
+typedef enum {
+	LOGIN_PROFILE_READ_ERROR = -3,
+	LOGIN_INVALID_PROFILE = -2,
+	LOGIN_NO_PROFILE = -1,
+	LOGIN_OK = 0,
+	LOGIN_INVALID_PARAMS,
+	LOGIN_CANNOT_INIT_PASSWD,
+	LOGIN_CANNOT_INIT_SECURITY,
+	LOGIN_INVALID_PASSWORD,
+	LOGIN_PROFILE_HASH_FAIL,
+	LOGIN_PROFILE_CORRUPT,
+} GemsLoginAction;
 
-// Profile loading returnvalues
-#define PROFILE_LOADED 0
-#define PROFILE_READ_FAILURE 1
-#define PROFILE_NOT_FOUND 2
-#define PROFILE_VERSION_MISMATCH 3
-#define PROFILE_RELOAD_FAILED 4
-#define PROFILE_RELOAD_FAILED_NOT_AUTHENTICATED 5
+/**
+ * GemsChangeUserAction:
+ * @CHANGE_USER_NO_PROFILE: Cannot change user, no such profile exists
+ * @CHANGE_USER_OK: User changed
+ * @CHANGE_USER_WAITING_PROFILE: Changing user, waiting the profile from the
+   teacher, user is changed after profile is retrieved
+ * @CHANGE_USER_LOGOUT_REQUIRED: Cannot change user, previous user is already
+ * logged in
+ * @CHANGE_USER_NO_USERNAME: Cannot change user, no username set
+ *
+ * Return values for user change action.
+ */
+typedef enum {
+	CHANGE_USER_NO_PROFILE = -1,
+	CHANGE_USER_OK = 0,
+	CHANGE_USER_WAITING_PROFILE,
+	CHANGE_USER_LOGOUT_REQUIRED,
+	CHANGE_USER_NO_USERNAME,
+} GemsChangeUserAction;
+
+/**
+ * GemsProfileLoadAction:
+ * @PROFILE_LOADED: Profile was loaded.
+ * @PROFILE_READ_FAILURE: Profile cannot be loaded, file cannot be read.
+ * @PROFILE_NOT_FOUND: Profile file was not found.
+ * @PROFILE_VERSION_MISMATCH: Profile version is not compatible with the
+ * application
+ * @PROFILE_REOAD_FAILED: Cannot reload profile with same name
+ * @PROFILE_RELOAD_FAILED_NOT_AUTHENTICATED: Profile reload failed because
+ * user was not authenticated.
+ *
+ * Return values of profile loading.
+ */
+typedef enum {
+	PROFILE_LOADED = 0,
+	PROFILE_READ_FAILURE,
+	PROFILE_NOT_FOUND,
+	PROFILE_VERSION_MISMATCH,
+	PROFILE_RELOAD_FAILED,
+	PROFILE_RELOAD_FAILED_NOT_AUTHENTICATED,
+} GemsProfileLoadAction;
 
 
 // Security vars
