@@ -22,6 +22,15 @@
 #include "../meam/jammo-slider-event.h"
 #include "../meam/jammo-loop.h"
 
+/**
+ * gems_create_error_message:
+ * @errortype: Error message type
+ * @serviceid: Target/Sender service
+ *
+ * Create new error message with the given @errortype
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_error_message(guint16 errortype, guint16 serviceid)
 {	
 	// allocate struct
@@ -52,6 +61,15 @@ gems_message* gems_create_error_message(guint16 errortype, guint16 serviceid)
 	return errormsg;
 }
 
+/**
+ * gems_clear_message:
+ * @message: Message to be cleared
+ *
+ * Clear the given @message, free the allocated data portion and free the
+ * structure.
+ * 
+ * Returns: void
+ */
 void gems_clear_message(gems_message* message)
 {
 	if(message != NULL)
@@ -63,6 +81,14 @@ void gems_clear_message(gems_message* message)
 	}
 }
 
+/**
+ * get_errormessage:
+ * @errortype: Error type to get
+ *
+ * Gets the error message charstring of the given @errortype.
+ *
+ * Returns: Charstring representation of the @errortype.
+ */
 const gchar* get_errormessage(guint16 errortype)
 {
 	switch(errortype)
@@ -121,6 +147,15 @@ const gchar* get_errormessage(guint16 errortype)
 }
 
 
+/**
+ * gems_create_message_service_jammo:
+ * @type: Message type for JamMo service
+ *
+ * Create new message to be sent to "JamMo" service. With type %VERSION_REPLY
+ * the version of the application is added to message.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_service_jammo(guint16 type)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -151,6 +186,18 @@ gems_message* gems_create_message_service_jammo(guint16 type)
 	return msg;
 }
 
+/**
+ * gems_create_message_service_profile:
+ * @type: Profile service message type
+ *
+ * Create new message to be sent to Profile service. Usually a message for
+ * replying either public (%PROFILE_PUB) or full (%PROFILE_FULL) profile is
+ * created. Can be used create reply for teacher request by giving the 
+ * %CONTROL_LOGIN_REPLY as type.
+ *
+ * Returns: new #gems_message or NULL if the message cannot be created or the
+ * parameters are incorrect.
+ */
 gems_message* gems_create_message_service_profile(guint16 type)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -253,6 +300,14 @@ gems_message* gems_create_message_service_profile(guint16 type)
 	}
 }
 
+/**
+ * gems_create_message_profile_request:
+ * @type: Type of the profile request
+ *
+ * Create new profile request message to be sent to Profile service.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_profile_request(guint16 type)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -280,6 +335,14 @@ gems_message* gems_create_message_profile_request(guint16 type)
 	return msg;
 }
 
+/**
+ * gems_create_message_teacher_service_profile_request:
+ * @username: Username of the profile to request
+ *
+ * Creates new profile request message to be sent to teacher.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_teacher_service_profile_request(gchar* username)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -308,6 +371,18 @@ gems_message* gems_create_message_teacher_service_profile_request(gchar* usernam
 	return msg;
 }
 
+/**
+ * gems_create_message_teacher_service_profile_reply:
+ * @data: Encrypted profile data
+ * @length: Amount of bytes in the encrypted @data
+ * @username: Username whose profile is in encrypted @data
+ *
+ * Create a profile reply to be sent to device who has requested this profile.
+ * The profile is in encrypted format in @data which is sent in the message.
+ * Usually the receiver saves the @data to disk with @username.jpf.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, guint length, gchar* username)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -345,6 +420,22 @@ gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, gui
 	return msg;
 }
 
+/**
+ * gems_create_message_password_changed:
+ * @newpasshash: SHA256 hash of the new password
+ * @encnewpass: New password encrypted with the old password (password without
+ * salt)
+ * @encpasslen: Length of the encrypted new password
+ * @pwlen: The length of the new password
+ *
+ * Create password change message to be sent to teacher. The hash and the 
+ * password in encrypted form are added to message. Create the encrypted 
+ * password with gems_security_encrypt_data() from saltless password. The
+ * teacher server uses the decrypted password for re-encrypting the profile
+ * on the teacher server.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_password_changed(guchar* newpasshash, guchar* encnewpass, guint encpasslen, guint8 pwlen)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -385,15 +476,22 @@ gems_message* gems_create_message_password_changed(guchar* newpasshash, guchar*
 	return msg;
 }
 
-/* Use with notify messages which do not need the group information, for sending:
-		- REQUEST_GROUP_INFO
-		- REQUEST_MEMBERS
-		- JOIN_GROUP
-		- MEMBER_DROPPED
-		- NEW_MEMBER
-		- GROUP_UNLOCKED
-		- GROUP_LOCKED
-*/
+/**
+ * gems_create_message_group_management_notify:
+ * @type: Type of the group management message, use types %REQUEST_GROUP_INFO,
+ * %REQUEST_MEMBERS, %JOIN_GROUP, %MEMBER_DROPPED, %NEW_MEMBER, %GROUP_UNLOCKED
+ * or %GROUP_LOCKED.
+ * @groupid: Id of the group this message is targetted to. This isn't necessary
+ * when requesting information (%REQUEST_GROUP_INFO) or group members 
+ * (%REQUEST_MEMBERS).
+ * @member: Id of the member, will be used only in messages of type %NEW_MEMBER
+ * or %MEMBER_DROPPED.
+ *
+ * Create group notify message for requesting information or delivering info.
+ * Use with notify messages which do not need the group information.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_group_management_notify(guint16 type, guint32 groupid, guint32 member)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -435,11 +533,15 @@ gems_message* gems_create_message_group_management_notify(guint16 type, guint32
 }
 
 
-/* Use with info messages which include the group information, for sending:
-		- OFFER_GROUP
-		- CURREPT_GROUP
-		- MEMBER_LIST
-*/
+/**
+ * gems_create_message_group_info:
+ * @type: Group information type: %OFFER_GROUP, %CURREPT_GROUP or %MEMBER_LIST
+ *
+ * Create group information message with given @type. Use with info messages
+ * which include the group information.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_group_management_group_info(guint16 type)
 {
 	gems_group_info* info = gems_get_data()->service_group->group_info;
@@ -553,6 +655,18 @@ gems_message* gems_create_message_group_management_group_info(guint16 type)
 	return msg;
 }
 
+/**
+ * gems_create_message_group_info_teacher:
+ * @type: Type of the group information
+ * @groupinfo: Group info structure
+ * @track_id: Track id to send
+ *
+ * Create a force group message to be sent by teacher. With the information
+ * provided in this message the selected devices form a group with group
+ * details provided.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_group_management_group_info_teacher(guint16 type, gems_group_info* groupinfo, guint16 track_id)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -628,6 +742,13 @@ gems_message* gems_create_message_group_management_group_info_teacher(guint16 ty
 
 }
 
+/**
+ * gems_create_message_collaboration_action_confirmed:
+ *
+ * Create action confirmed message for collaboration service.
+ *
+ * Returns: new #gems_message 
+ */
 gems_message* gems_create_message_collaboration_action_confirmed()
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -654,7 +775,18 @@ gems_message* gems_create_message_collaboration_action_confirmed()
 
 }
 
-//Message for adding or removing a loop - Note - currently using paths of image and wav files!
+/**
+ * gems_create_message_collaboration_action_vi_single:
+ * @type: Type of the action
+ * @png_name: Name of the png file
+ * @wav_name: Name of the wav file
+ * @slot: Id of the slot
+ *
+ * Message for adding or removing a loop - Note - currently using paths of
+ * image and wav files!
+ *
+ * Returns: new #gems_message 
+ */
 gems_message* gems_create_message_collaboration_action_vi_single(guint16 type, const gchar png_name[], const gchar wav_name[], guint16 slot)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -697,7 +829,16 @@ gems_message* gems_create_message_collaboration_action_vi_single(guint16 type, c
 	return msg;
 }
 
-//Message for transferring the song file - used when starting a game (or synchronizing after disconnection?) 
+/**
+ * gems_create_message_collaboration_action_song_info: 
+ * @type: Not used
+ * @song_info: Song file data
+ *
+ * Message for transferring the song file - used when starting a game (or
+ * synchronizing after disconnection?) 
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_collaboration_action_song_info(guint16 type, const gchar song_info[])
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -729,7 +870,17 @@ gems_message* gems_create_message_collaboration_action_song_info(guint16 type, c
 	return msg;
 }
 
-//Message for adding or removing a loop - Note - currently using paths of image and wav files!
+/**
+ * gems_create_message_collaboration_action_loop:
+ * @type: Type of the loop action
+ * @loop_id: Loop id to add or remove
+ * @slot: The position
+ *
+ * Message for adding or removing a loop in a game. Message to be sent to
+ * collaboration service.
+ *
+ * Returns: new #gems_message 
+ */
 gems_message* gems_create_message_collaboration_action_loop(guint16 type, guint loop_id, guint slot)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -771,6 +922,16 @@ gems_message* gems_create_message_collaboration_action_loop(guint16 type, guint
 	return msg;
 }
 
+/**
+ * gems_create_message_collaboration_action_loop_sync:
+ * @list: List of #JammoLoop:s
+ *
+ * Create a message for collaboration service for synchronizing the song
+ * contents. The @list will iterated and each loop id and slot number is
+ * added to message.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_collaboration_action_loop_sync(GList * list)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -812,6 +973,17 @@ gems_message* gems_create_message_collaboration_action_loop_sync(GList * list)
 	return msg;
 }
 
+/**
+ * gems_create_message_collaboration_action_midi_series:
+ * @type: Type of the midi action
+ * @instrument_id: Id of the midi instrument that was used
+ * @list: List of #JammoMidiEvent events 
+ *
+ * Creates a midi series message to be sent to collaboration service. Adds
+ * every element data in the @list into message.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_collaboration_action_midi_series(guint16 type, guint16 instrument_id, GList * list)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -864,6 +1036,18 @@ gems_message* gems_create_message_collaboration_action_midi_series(guint16 type,
 	
 	return msg;
 }
+
+/**
+ * gems_create_message_collaboration_action_slider_series:
+ * @type: Type of the action
+ * @instrument_id: Id if the slider instrument used
+ * @list: List of #JammoSliderEvent:s
+ *
+ * Create a slider event series message to be sent to collaboration service.
+ * Every provided #JammoSliderEvent is added into the message.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_collaboration_action_slider_series(guint16 type, guint16 instrument_id, GList * list)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -917,6 +1101,16 @@ gems_message* gems_create_message_collaboration_action_slider_series(guint16 typ
 	return msg;
 }
 
+/**
+ * gems_create_message_control_mode:
+ * @type: Control mode type
+ * @cntrl_type: Lock type
+ * @lock_mode: Lock mode
+ *
+ * Create new mode control message.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_control_mode(guint16 type, guint16 cntrl_type, guint16 lock_mode)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -949,6 +1143,14 @@ gems_message* gems_create_message_control_mode(guint16 type, guint16 cntrl_type,
 	return msg;
 }
 
+/**
+ * gems_create_message_control_ok:
+ * @type: Reply type
+ *
+ * Create a reply to %CONTROL_MODE message.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_control_ok(guint16 type)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
@@ -973,6 +1175,14 @@ gems_message* gems_create_message_control_ok(guint16 type)
 	return msg;
 }
 
+/**
+ * gems_create_message_control_set_login_name:
+ * @username: Username to set
+ *
+ * Create control message for setting the login username on receiver.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_control_set_login_name(gchar* username)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -1001,6 +1211,16 @@ gems_message* gems_create_message_control_set_login_name(gchar* username)
 	return msg;
 }
 
+/**
+ * gems_create_message_control_force_login:
+ * @password: PLAIN password
+ * @passlen: Length of the password
+ *
+ * Create a force login message with PLAIN password to be used for logging the
+ * user in on the receiver device.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_control_force_login(gchar* password, guint8 passlen)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -1032,6 +1252,15 @@ gems_message* gems_create_message_control_force_login(gchar* password, guint8 pa
 	return msg;
 }
 
+/**
+ * gems_create_message_control_get_login:
+ *
+ * Create message for requesting the login username from the device. Used by
+ * the teacher server.
+ *
+ * Returns: new #gems_message or NULL if the message cannot be created or the
+ * parameters are incorrect.
+ */
 gems_message* gems_create_message_control_get_login()
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -1056,6 +1285,15 @@ gems_message* gems_create_message_control_get_login()
 	return msg;
 }
 
+/**
+ * gems_create_message_mentor_log_message:
+ * @type: Type of the logging message
+ * @message: The log message
+ *
+ * Create a logging message to be sent to the mentor service on teacher server.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_message_mentor_log_message(guint16 type, char *message)
 {
 	gems_message* msg = g_new(gems_message,sizeof(gems_message));
@@ -1085,6 +1323,20 @@ gems_message* gems_create_message_mentor_log_message(guint16 type, char *message
 
 }
 
+/**
+ * gems_create_general_message:
+ * @msg: Already allocated message or NULL when new #gems_message will be
+ * allocated
+ * @serviceid: Service id where the message is targetted to (2 first bytes)
+ * @length: Length of the whole message to be initialized (4 next bytes)
+ * @type: Command type of the message to be initialized (2 next bytes)
+ *
+ * Creates the basic #gems_message with given @serviceid and @type, allocated
+ * to withold @length amount of bytes. Sets the 8 first bytes of the message
+ * according to protocol.
+ *
+ * Returns: new #gems_message
+ */
 gems_message* gems_create_general_message(gems_message* msg, guint16 serviceid, guint32 length, guint16 type)
 {
 	if(msg == NULL) msg = g_new(gems_message,sizeof(gems_message));
