@@ -17,10 +17,22 @@
 #include "../cem/cem.h"
 #include "collaboration.h"
 
+/**
+ * gems_service_group_process_request:
+ * @element: Connection to process
+ *
+ * Process incoming messages sent to group management service. Calls handler
+ * functions to react to the message based on the command in the message.
+ *
+ * Returns: TRUE when connection to teacher did exist and the message was
+ * processed, FALSE otherwise.
+ */
 gboolean gems_service_group_process_request(gems_connection* element)
 {
 	gems_components* data = gems_get_data();
 	
+	if(!data || !element) return FALSE;
+	
 	switch(gems_connection_get_16(element,6)) // command
 	{
 		case OFFER_GROUP:
@@ -76,12 +88,26 @@ gboolean gems_service_group_process_request(gems_connection* element)
 	return TRUE;
 }
 
+/**
+ * gems_service_group_handle_offer_group:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process group offer messages. Update the list of group advertisements or add
+ * a new group into list. If the group id is the same as our current groups id
+ * update own group information with the received information only if the
+ * sender of the information is the group owner.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_offer_group(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If same group as ours & we're accepted to group and sender is the owner
 	if((gems_connection_get_32(element,8) == data->service_group->group_info->id) && 
 		(data->service_group->group_info->own_state == IN_GROUP) && 
@@ -133,12 +159,30 @@ void gems_service_group_handle_offer_group(gems_components* data, gems_connectio
 	}
 }
 
+/**
+ * gems_service_group_handle_current_group:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process current group messages. These messages are replies to group info
+ * requests sent to peers. If the group is not the same as the user is in and
+ * if the sender is non-owner just update the list of groups. Otherwise if the
+ * group id is the same as the current users group id update the information of
+ * the current group. If the message contains different owner id, change the
+ * owner of the group. If the user has been selected to be the new owner and is
+ * not yet approved to the group the status is changed to #GemsGroupStatus 
+ * %IN_GROUP.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_current_group(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If same group as ours
 	if(gems_connection_get_32(element,8) == data->service_group->group_info->id)
 	{
@@ -230,12 +274,26 @@ void gems_service_group_handle_current_group(gems_components* data, gems_connect
 	}
 }
 
+/**
+ * gems_service_group_handle_request_members:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process member request from a group member. If the message is from some
+ * other user than from a member of the current group it is ignored. If the
+ * receiver is not the owner it will send an error, otherwise a updated list
+ * of group members is sent back.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_request_members(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If we are not in a active group
 	if(data->service_group->group_info->id == NOT_ACTIVE)
 	{
@@ -311,12 +369,25 @@ void gems_service_group_handle_request_members(gems_components* data, gems_conne
 	}
 }
 
+/**
+ * gems_service_group_handle_request_group_info:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process group info request. Send the current group info (%CURRENT_GROUP) if
+ * the user is in a some group. Otherwise send %ERROR_GROUP_NOT_ACTIVE_TYPE
+ * message.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_request_group_info(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	if(data->service_group->group_info->id == NOT_ACTIVE)
 	{
 		msg = gems_create_error_message(ERROR_GROUP_NOT_ACTIVE_TYPE,GROUP_SERVICE_ID);
@@ -356,12 +427,28 @@ void gems_service_group_handle_request_group_info(gems_components* data, gems_co
 	}
 }
 
+/**
+ * gems_service_group_handle_join_group:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process join to group message. Add the user to group if there is space left
+ * in the current group and report back with %MEMBER_LIST and %OFFER_GROUP 
+ * messages. When new user is added other members of the group are informed
+ * about the arrival of new user with a group notify. If the group id is
+ * invalid, user is not owner, group is full, user is already in the group, 
+ * group is locked an error message is sent back.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_join_group(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If we are not in a active group
 	if(data->service_group->group_info->id == NOT_ACTIVE)
 	{
@@ -578,12 +665,26 @@ void gems_service_group_handle_join_group(gems_components* data, gems_connection
 	}
 }
 
+/**
+ * gems_service_group_handle_leave_group:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process leave group request. If the user is in the group and the receiver is
+ * the owner (and group ids match) a %REMOVED_FROM_GROUP is sent back and other
+ * group members are notified with %MEMBER_DROPPED message. Otherwise an error
+ * message is sent back.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_leave_group(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If we are not in a active group
 	if(data->service_group->group_info->id == NOT_ACTIVE)
 	{
@@ -680,13 +781,27 @@ void gems_service_group_handle_leave_group(gems_components* data, gems_connectio
 	}
 }
 
-
+/**
+ * gems_service_group_handle_removed_from_group:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process the removed from group message (%REMOVED_FROM_GROUP). A member can
+ * be removed from the group only by the group owner, these messages from
+ * others are ignored. If the user is in %LEAVING #GemsGroupState user received
+ * a confirmation to leave request, otherwise user was kicked from the group. 
+ * When user is removed from the group the group information will be reset.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_removed_from_group(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If we are not in a active group
 	if(data->service_group->group_info->id == NOT_ACTIVE)
 	{
@@ -736,13 +851,26 @@ void gems_service_group_handle_removed_from_group(gems_components* data, gems_co
 	}
 }
 
-
+/**
+ * gems_service_group_handle_member_dropped:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process a message containing member dropped information. Update own group
+ * member information by removing the dropped user from the group. If this user
+ * is removed reset the group information. Messages are allowed from owner only
+ * and these messages from others are ignored.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_member_dropped(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If we are not in a active group
 	if(data->service_group->group_info->id == NOT_ACTIVE)
 	{
@@ -820,12 +948,27 @@ void gems_service_group_handle_member_dropped(gems_components* data, gems_connec
 	}
 }
 
+/**
+ * gems_service_group_handle_new_member:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process new member notification. Add the new user into group information if
+ * the sender is the group owner and group ids match. If the group member list
+ * on this device is full updated member list is requested from the group 
+ * owner. If the message is incoming when group is locked an error is sent 
+ * back.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_new_member(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If we are not in a active group
 	if(data->service_group->group_info->id == NOT_ACTIVE)
 	{
@@ -927,13 +1070,28 @@ void gems_service_group_handle_new_member(gems_components* data, gems_connection
 	}
 }
 
-
+/**
+ * gems_service_group_handle_member_list:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process the member list message. Update own member list with the information
+ * in the message only if the sender is the owner, group ids match and group is
+ * not locked. If user receives this message in %JOINING #GemsGroupState it is
+ * accepted to group and state changed accordingly. If the id of this user is
+ * not found from the message group information will be reset (removed for some
+ * reason).
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_member_list(gems_components* data, gems_connection* element)
 {
 	gems_message* msg = NULL;
 	gchar* logmsg = NULL;
 	gchar* logerror = NULL;
 	
+	if(!data || !element) return;
+	
 	// If we are not in a active group
 	if(data->service_group->group_info->id == NOT_ACTIVE)
 	{
@@ -1041,8 +1199,14 @@ void gems_service_group_handle_member_list(gems_components* data, gems_connectio
 	}
 }
 
-
-
+/**
+ * gems_service_group_init:
+ *
+ * Initialize group service data structures. Initialize an empty group
+ * information for this user with #GemsGroupStatus %NONE.
+ * 
+ * Returns: a pointer to created #gems_service_group struct
+ */
 gems_service_group* gems_service_group_init()
 {
 	gems_service_group* data = g_new(gems_service_group,sizeof(gems_service_group));
@@ -1058,6 +1222,13 @@ gems_service_group* gems_service_group_init()
 	return data;
 }
 
+/**
+ * gems_service_group_cleanup:
+ *
+ * Clean the group service data structure.
+ *
+ * Returns: void
+ */
 void gems_service_group_cleanup()
 {
 	gems_service_group* data = gems_get_data()->service_group;
@@ -1073,6 +1244,13 @@ void gems_service_group_cleanup()
 	}
 }
 
+/**
+ * gems_service_group_cleanup_lists:
+ *
+ * Empty and free the group list.
+ *
+ * Returns: void
+ */
 void gems_service_group_cleanup_lists()
 {
 	gems_service_group* data = gems_get_data()->service_group;
@@ -1085,21 +1263,46 @@ void gems_service_group_cleanup_lists()
 	}
 }
 
-
+/**
+ * gems_service_group_handle_unlocked:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process the group unlocked message. Unlock the group if the sender is the
+ * group owner.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_unlocked(gems_components* data, gems_connection* element)
 {
+	gchar* logmsg = NULL;
+	
+	if(!data || !element) return;
+	
 	if(gems_group_active(NULL)) // group is active and we're in it
 	{
-		// sender is the owner
-		if(element->profile->id == gems_group_get_owner(NULL))
+		// Group id is correct
+		if(gems_connection_get_32(element,8) == gems_group_get_gid(NULL))
 		{
-			gems_get_data()->service_group->group_info->is_locked = FALSE;
-			cem_add_to_log("gems_service_group_handle_unlocked : group unlocked",J_LOG_INFO);
+			// sender is the owner
+			if(element->profile->id == gems_group_get_owner(NULL))
+			{
+				gems_get_data()->service_group->group_info->is_locked = FALSE;
+				cem_add_to_log("gems_service_group_handle_unlocked : group unlocked",J_LOG_INFO);
+			}
+			else
+			{
+				logmsg = g_strdup_printf("gems_service_group_handle_unlocked : Got unlock message from other (%u) than group owner %u, sender device %s/%u",
+					element->profile->id, gems_group_get_owner(NULL), ph_c_connection_get_remote_address(element->connection),
+					ph_c_connection_get_device_checksum(element->connection));
+				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+				g_free(logmsg);
+			}
 		}
 		else
 		{
-			gchar* logmsg = g_strdup_printf("gems_service_group_handle_unlocked : Got unlock message from other (%u) than group owner %u, sender device %s/%u",
-				element->profile->id, gems_group_get_owner(NULL), ph_c_connection_get_remote_address(element->connection),
+			logmsg = g_strdup_printf("gems_service_group_handle_unlocked : Got unlock message for other group (%u) than ours %u, sender device %s/%u",
+				gems_connection_get_32(element,8), gems_group_get_gid(NULL), ph_c_connection_get_remote_address(element->connection),
 				ph_c_connection_get_device_checksum(element->connection));
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
@@ -1107,20 +1310,46 @@ void gems_service_group_handle_unlocked(gems_components* data, gems_connection*
 	}
 }
 
+/**
+ * gems_service_group_handle_locked:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process the group locked message. Lock the group if the sender is the group
+ * owner.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_locked(gems_components* data, gems_connection* element)
 {
+	gchar* logmsg = NULL;
+	
+	if(!data || !element) return;
+	
 	if(gems_group_active(NULL)) // group is active and we're in it
 	{
-		// sender is the owner
-		if(element->profile->id == gems_group_get_owner(NULL))
+		// Group id is correct
+		if(gems_connection_get_32(element,8) == gems_group_get_gid(NULL))
 		{
-			gems_get_data()->service_group->group_info->is_locked = TRUE;
-			cem_add_to_log("gems_service_group_handle_locked : group locked",J_LOG_INFO);
+			// sender is the owner
+			if(element->profile->id == gems_group_get_owner(NULL))
+			{
+				gems_get_data()->service_group->group_info->is_locked = TRUE;
+				cem_add_to_log("gems_service_group_handle_locked : group locked",J_LOG_INFO);
+			}
+			else
+			{
+				logmsg = g_strdup_printf("gems_service_group_handle_locked : Got lock message from other (%u) than group owner %u, sender device %s/%u",
+					element->profile->id, gems_group_get_owner(NULL), ph_c_connection_get_remote_address(element->connection),
+					ph_c_connection_get_device_checksum(element->connection));
+				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+				g_free(logmsg);
+			}
 		}
 		else
 		{
-			gchar* logmsg = g_strdup_printf("gems_service_group_handle_locked : Got lock message from other (%u) than group owner %u, sender device %s/%u",
-				element->profile->id, gems_group_get_owner(NULL), ph_c_connection_get_remote_address(element->connection),
+			logmsg = g_strdup_printf("gems_service_group_handle_locked : Got lock message for other group (%u) than ours %u, sender device %s/%u",
+				gems_connection_get_32(element,8), gems_group_get_gid(NULL), ph_c_connection_get_remote_address(element->connection),
 				ph_c_connection_get_device_checksum(element->connection));
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
@@ -1128,10 +1357,24 @@ void gems_service_group_handle_locked(gems_components* data, gems_connection* el
 	}
 }
 
+/**
+ * gems_service_group_handle_force_group:
+ * @data: pointer to the main data structure
+ * @element: Connection which has the message in network buffer
+ *
+ * Process the force group message. This message is sent only by the teacher,
+ * set the group information to correspond the content of the message if the
+ * user is not in any group. Informs CHUM about the new group information by
+ * starting the game with the parameters.
+ *
+ * Returns: void
+ */
 void gems_service_group_handle_force_group(gems_components* data, gems_connection* element)
 {
 	gchar* logmsg = NULL;
 	guint16 track_id;
+	
+	if(!data || !element) return;
 
 	//Only force group if we are not in one already(?)
 	if(data->service_group->group_info->id == NOT_ACTIVE)
