@@ -3,7 +3,7 @@
  *
  * This file is part of JamMo.
  *
- * (c) 2009-2010 University of Oulu, Lappeenranta University of Technology
+ * (c) 2009-2011 University of Oulu, Lappeenranta University of Technology
  *
  * Authors: Jussi Laakkonen <jussi.laakkonen@lut.fi>
  */
@@ -18,7 +18,15 @@
 #include "gems_profile_manager.h"
 #include "../cem/cem.h"
 
-// host float to guint32 for sending over network
+/**
+ * htonf:
+ * @value: float value to pack into 32bit integer
+ * 
+ * Pack host float to guint32 for sending over network. Performs host to
+ * network type operation for given float.
+ *
+ * Returns: a #guint32 holding the float @value.
+ */
 guint32 htonf(gfloat value)
 {
 	guint32 packed;
@@ -39,7 +47,15 @@ guint32 htonf(gfloat value)
 	return packed;
 }
 
-// network guint32 to host float for receiving from network
+/**
+ * htonf:
+ * @value: float value to pack into 32bit integer
+ * 
+ * Unpack the float from the network order integer @value witholding the float
+ * value. Performs network to host type operation for given integer.
+ *
+ * Returns: a #gfloat in the @value.
+ */
 gfloat ntohf(guint32 value)
 {
 	gfloat ret;
@@ -51,6 +67,17 @@ gfloat ntohf(guint32 value)
   return ret;
 }
 
+/**
+ * gems_clear_gems_connection:
+ * @element: Connection element to clear and free
+ *
+ * Disconnect, clear and free the given connection @element. If the user in a 
+ * group as reqular member and the user on this device is the owner of the
+ * group inform other members about a disconnected member. Disconnect all 
+ * connections (data and game connections) and destroy all data in the struct.
+ *
+ * Returns: void
+ */
 void gems_clear_gems_connection(gems_connection* element)
 {
 	gchar* logmsg = NULL;
@@ -103,6 +130,20 @@ void gems_clear_gems_connection(gems_connection* element)
 	element = NULL;
 }
 
+/**
+ * gems_new_gems_connection:
+ * @newconn: The new PeerHood connection object
+ * @newport: Used port number for the connection
+ * @newconnectionid: Id of the connection
+ * @newstate: State of the connection
+ * @newjammoid: JamMo id - unused!
+ *
+ * Create new #gems_connection structure with given parameters and initialize
+ * its data. New timers are started for the connection and network buffer is
+ * cleared.
+ *
+ * Returns: a pointer to new initialized #gems_connection struct
+ */
 gems_connection* gems_new_gems_connection(MAbstractConnection* newconn,
 	unsigned short newport,
 	int newconnectionid,
@@ -128,7 +169,14 @@ gems_connection* gems_new_gems_connection(MAbstractConnection* newconn,
 	return new_item;
 }
 
-// Clear the networking buffer
+/**
+ * gems_connection_clear_buffer:
+ * @element: Connection element which buffer needs to be cleared
+ * 
+ * Clear the networking buffer of the @element. Set adding position to 0.
+ *
+ * Returns: void
+ */
 void gems_connection_clear_buffer(gems_connection* element)
 {
 	if(element == NULL) return;
@@ -136,6 +184,14 @@ void gems_connection_clear_buffer(gems_connection* element)
 	element->add_position = 0;
 }
 
+/**
+ * gems_connection_set_action:
+ * @element: Connection element which had some activity
+ *
+ * Record the time of the last action for the connection @element.
+ *
+ * Returns: void
+ */
 void gems_connection_set_action(gems_connection* element)
 {
 	if(element == NULL) return;
@@ -143,6 +199,14 @@ void gems_connection_set_action(gems_connection* element)
 	else g_timer_start(element->last_action);
 }
 
+/**
+ * gems_connection_get_last_action:
+ * @element: Connection element to use
+ *
+ * Get the time it has passed since last event on the connection @element.
+ *
+ * Returns: Time since last activity on the connection @element.
+ */
 double gems_connection_get_last_action(gems_connection* element)
 {
 	if(element == NULL) return 0.0;
@@ -151,6 +215,14 @@ double gems_connection_get_last_action(gems_connection* element)
 	return g_timer_elapsed(element->last_action,NULL);
 }
 
+/**
+ * gems_connection_clear_last_action:
+ * @element: connection element to use
+ *
+ * Clear and delete the last action timer on the connection @element.
+ *
+ * Returns: void
+ */
 void gems_connection_clear_last_action(gems_connection* element)
 {
 	if(element)
@@ -163,7 +235,15 @@ void gems_connection_clear_last_action(gems_connection* element)
 	}
 }
 
-// Add 16bit integer to network buffer
+/**
+ * gems_connection_add_16: 
+ * @element: Connection element where data will be added
+ * @value: Value to add to network buffer
+ *
+ * Add 16bit integer @value to the network buffer of connection @element.
+ *
+ * Returns: void
+ */
 void gems_connection_add_16(gems_connection* element, guint16 value)
 {
 	if(element == NULL) return;
@@ -175,7 +255,15 @@ void gems_connection_add_16(gems_connection* element, guint16 value)
 	element->add_position = element->add_position + sizeof(guint16);
 }
 
-// Add 32bit integer to network buffer
+/**
+ * gems_connection_add_32:
+ * @element: Connection element where data will be added
+ * @value: Value to add to the network buffer
+ *
+ * Add 32bit integer @value to the network buffer of connection @element.
+ *
+ * Returns: void
+ */
 void gems_connection_add_32(gems_connection* element, guint32 value)
 {
 	if(element == NULL) return;
@@ -187,7 +275,15 @@ void gems_connection_add_32(gems_connection* element, guint32 value)
 	element->add_position = element->add_position + sizeof(guint32);
 }
 
-// Add 64bit integer to network buffer
+/**
+ * gems_connection_add_64:
+ * @element: Connection element where data will be added
+ * @value: Value to add to the network buffer 
+ *
+ * Add 64bit integer @value to the network buffer of connection @element.
+ *
+ * Returns: void
+ */
 void gems_connection_add_64(gems_connection* element, guint64 value)
 {
 	if(element == NULL) return;
@@ -199,8 +295,17 @@ void gems_connection_add_64(gems_connection* element, guint64 value)
 	element->add_position = element->add_position + sizeof(guint64);
 }
 
-// Add 32bit float to network buffer. This can be done because message has been received and
-// it will not sent anymore
+/**
+ * gems_connection:
+ * @element: Connection element where data will be added
+ * @value: Value to add to network buffer
+ *
+ * Add 32bit float @value to network buffer of connection @element. This can be
+ * done because message has been received and it will not sent anymore so no
+ * need to take care of host vs. network order.
+ *
+ * Returns: void
+ */
 void gems_connection_add_float(gems_connection* element, gfloat value)
 {
 	if(element == NULL) return;
@@ -212,7 +317,19 @@ void gems_connection_add_float(gems_connection* element, gfloat value)
 	element->add_position = element->add_position + sizeof(gfloat);
 }
 
-// Add characters to network buffer, define need for padding with last value (pad)
+/**
+ * gems_connection_add_char:
+ * @element: Connection element where data will be added
+ * @value: Value to add to network buffer
+ * @length: length of the @value in bytes
+ * @pad: Use padding byte at the end of the added value (at adding position + 
+ * length + 1)
+ *
+ * Add characters (amount = @length) to the network buffer of connection
+ * @element, define need for padding with last value (@pad)
+ *
+ * Returns: void
+ */
 void gems_connection_add_char(gems_connection* element, gchar* value, guint length, gboolean pad)
 {
 	if(element == NULL || value == NULL) return;
@@ -227,7 +344,14 @@ void gems_connection_add_char(gems_connection* element, gchar* value, guint leng
 	if(pad == FALSE) element->add_position = element->add_position - 1;
 }
 
-// Add padding - a NULL character
+/**
+ * gems_connection_add_padding:
+ * @element: Connection element where data will be added
+ *
+ * Add padding byte (NULL) to the network buffer of the connection @element.
+ *
+ * Returns: void
+ */
 void gems_connection_add_padding(gems_connection* element)
 {
 	if(element == NULL) return;
@@ -238,7 +362,17 @@ void gems_connection_add_padding(gems_connection* element)
 	element->add_position = element->add_position + 1;
 }
 
-// Add data to the end of nwbuffer
+/**
+ * gems_connection_add_data:
+ * @element: Connection element where data will be added
+ * @data: data to add
+ * @length: length of @data in bytes
+ *
+ * Add @data to the end of the network buffer of the connection @element with
+ * given @length.
+ *
+ * Returns: void
+ */
 void gems_connection_add_data(gems_connection* element, gchar* data, guint length)
 {
 	if(element == NULL || data == NULL) return;
@@ -249,7 +383,16 @@ void gems_connection_add_data(gems_connection* element, gchar* data, guint lengt
 	element->add_position = element->add_position + length;
 }
 
-// Get 16 bit integer from position
+/**
+ * gems_connection_get_16:
+ * @element: Connection element which has data in its network buffer
+ * @from: Data position in the network buffer of the connection @element
+ *
+ * Get 16 bit integer from the network buffer of the connection @element at
+ * position @from.
+ *
+ * Returns: 16 bit integer value at position @from in the network buffer.
+ */
 guint16 gems_connection_get_16(gems_connection* element, guint from)
 {
 	if(element == NULL) return 0;
@@ -259,7 +402,16 @@ guint16 gems_connection_get_16(gems_connection* element, guint from)
 	return *(guint16*)&element->nwbuffer[from];
 }
 
-// Get 32 bit integer from position
+/**
+ * gems_connection_get_32:
+ * @element: Connection element which has data in its network buffer
+ * @from: Data position in the network buffer of the connection @element
+ *
+ * Get 32 bit integer from the network buffer of the connection @element at
+ * position @from.
+ *
+ * Returns: 32 bit integer value at position @from in the network buffer.
+ */
 guint32 gems_connection_get_32(gems_connection* element, guint from)
 {
 	if(element == NULL) return 0;
@@ -269,7 +421,16 @@ guint32 gems_connection_get_32(gems_connection* element, guint from)
 	return *(guint32*)&element->nwbuffer[from];
 }
 
-// Get 64 bit integer from position
+/**
+ * gems_connection_get_64:
+ * @element: Connection element which has data in its network buffer
+ * @from: Data position in the network buffer of the connection @element
+ *
+ * Get 64 bit integer from the network buffer of the connection @element at
+ * position @from.
+ *
+ * Returns: 64 bit integer value at position @from in the network buffer.
+ */
 guint64 gems_connection_get_64(gems_connection* element, guint from)
 {
 	if(element == NULL) return 0;
@@ -279,7 +440,19 @@ guint64 gems_connection_get_64(gems_connection* element, guint from)
 	return *(guint64*)&element->nwbuffer[from];
 }
 
-// Get 32 bit float from position
+/**
+ * gems_connection_get_float_for_localization:
+ * @element: Connection element which has data in its network buffer
+ * @from: Data position in the network buffer of the connection @element
+ *
+ * Get float from the network buffer of the connection @element at position
+ * @from. The float value is as #guint32 in the network buffer and is unpacked
+ * with ntohf() before returning the #gfloat. To get the float "as-it-is" use
+ * gems_connection_get_float() and use this function when localization for the
+ * float is required.
+ *
+ * Returns: A #gfloat alue at position @from in the network buffer.
+ */
 gfloat gems_connection_get_float_for_localization(gems_connection* element, guint from)
 {
 	if(element == NULL) return 0;
@@ -296,7 +469,16 @@ gfloat gems_connection_get_float_for_localization(gems_connection* element, guin
   return ret;
 }
 
-// Get 32 bit float from position
+/**
+ * gems_connection_get_float:
+ * @element: Connection element which has data in its network buffer
+ * @from: Data position in the network buffer of the connection @element
+ *
+ * Get float from the network buffer of the connection @element at position
+ * @from.
+ *
+ * Returns: A #gfloat value at position @from in the network buffer.
+ */
 gfloat gems_connection_get_float(gems_connection* element, guint from)
 {
 	if(element == NULL) return 0;
@@ -310,7 +492,19 @@ gfloat gems_connection_get_float(gems_connection* element, guint from)
   return value;
 }
 
-// Get characters from position until next NULL character
+/**
+ * gems_connection_get_char:
+ * @element: Connection element which has data in its network buffer
+ * @from: Data position in the network buffer of the connection @element
+ *
+ * Get characters from the network buffer of the connection @element onwards
+ * from position @from until the first NULL character. This is not a safe
+ * way to get data, use gems_connection_get_data() to more safe way of getting
+ * data from network buffer.
+ *
+ * Returns: A #gchar pointer to the network buffer at position @from. Do not
+ * attempt free this value (it has a will of its own)!
+ */
 gchar* gems_connection_get_char(gems_connection* element, guint from)
 {
 	if(element == NULL) return NULL;
@@ -319,7 +513,19 @@ gchar* gems_connection_get_char(gems_connection* element, guint from)
 	return (gchar*)&element->nwbuffer[from];
 }
 
-// Get data as chars from position until lenght is reached. Returns new gchar pointer, remember to free.
+/**
+ * gems_connection_get_data:
+ * @element: Connection element which has data in its network buffer
+ * @from: Data position in the network buffer of the connection @element
+ * @length: Amount of data to be retrieved from the network buffer  in bytes
+ *
+ * Get @length amount of data from the network buffer of the connection
+ * @element at position @from. Allocates new #gchar to hold the copy of the
+ * requested data.
+ *
+ * Returns: A new #gchar containing data with @length from position @from in
+ * the network buffer. Free this after used!
+ */
 gchar* gems_connection_get_data(gems_connection* element, guint from, guint length)
 {
 	if(element == NULL) return NULL;
@@ -331,7 +537,18 @@ gchar* gems_connection_get_data(gems_connection* element, guint from, guint leng
 	return buffer;
 }
 
-// Copies the content in newcontent to nwbuffer of element
+/**
+ * gems_connection_set_content:
+ * @element: Connection element which network buffer is used
+ * @newcontent: New network buffer content to set
+ * @length: Length of the @newcontent in bytes
+ *
+ * Copy the given content (@newcontent) to the network buffer of the given
+ * connection @element. Clears the network buffer from old data and replaces
+ * the content with @newcontent.
+ *
+ * Returns: void
+ */
 void gems_connection_set_content(gems_connection* element, gchar* newcontent, guint length)
 {
 	if(element == NULL) return;
@@ -340,14 +557,29 @@ void gems_connection_set_content(gems_connection* element, gchar* newcontent, gu
 	memcpy(&element->nwbuffer,newcontent,length);
 }
 
-// Get the amount of partial data in the buffer
+/**
+ * gems_connection_partial_data_amount:
+ * @element: Connection element which network buffer is questioned for partial
+ * data
+ *
+ * Return the amount of data in the network buffer of the connection @element.
+ *
+ * Returns: Amount of bytes in the network buffer as #guint.
+ */
 guint gems_connection_partial_data_amount(gems_connection* element)
 {
 	if(element == NULL) return 0;
 	return element->add_position;
 }
 
-// Clear all disconnected gems_connection elements from list
+/**
+ * gems_cleanup_connections_from_list:
+ * @list: The #GList containing pointers to #gems_connection elements
+ *
+ * Clear and free all disconnected #gems_connection elements from given @list.
+ *
+ * Returns: A pointer to given @list after processing.
+ */
 GList* gems_cleanup_connections_from_list(GList* list)
 {
 	if(list == NULL) return NULL;
@@ -377,6 +609,17 @@ GList* gems_cleanup_connections_from_list(GList* list)
 	return list;
 }
 
+/**
+ * gems_new_peer_profile:
+ * @username: Username in the profile
+ * @id: User id in the profile
+ * @age: Age of the user
+ * @avatarid: Id of the users avatar
+ *
+ * Create new #gems_peer_profile struct and fill it with given information.
+ * 
+ * Returns: A pointer to created and set up #gems_peer_profile struct.
+ */
 gems_peer_profile* gems_new_peer_profile(gchar* username, guint32 id, guint16 age, guint32 avatarid)
 {
 	if(username == NULL) return NULL;
@@ -391,6 +634,18 @@ gems_peer_profile* gems_new_peer_profile(gchar* username, guint32 id, guint16 ag
 	return profile;
 }
 
+/**
+ * gems_peer_profile_set_values:
+ * @profile: Profile to fill with new data
+ * @username: Username in the profile
+ * @id: User id in the profile
+ * @age: Age of the user
+ * @avatarid: Id of the users avatar
+ *
+ * Set data to #gems_peer_profile struct.
+ * 
+ * Returns: void
+ */
 void gems_peer_profile_set_values(gems_peer_profile* profile, gchar* username, guint32 id, guint16 age, guint32 avatarid)
 {
 	if(profile == NULL || username == NULL) return;
@@ -401,6 +656,14 @@ void gems_peer_profile_set_values(gems_peer_profile* profile, gchar* username, g
 	profile->age = age;
 }
 
+/**
+ * gems_clear_peer_profile:
+ * @profile: Profile to clear and free
+ *
+ * Clear and free the given @profile.
+ *
+ * Returns: void
+ */
 void gems_clear_peer_profile(gems_peer_profile* profile)
 {
 	if(profile == NULL) return;
@@ -410,6 +673,16 @@ void gems_clear_peer_profile(gems_peer_profile* profile)
 	profile = NULL;
 }
 
+/**
+ * gems_connection_localize_data_in_buffer:
+ * @element: Connection element which network buffer contains data to be
+ * localized
+ *
+ * Localize (from network to host) the message in the network buffer of the
+ * connection @element.
+ *
+ * Returns: void.
+ */
 void gems_connection_localize_data_in_buffer(gems_connection* element)
 {
 	if(element == NULL) return;
@@ -647,7 +920,21 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 	element->add_position = temp_position;
 }
 
-GList* gems_connection_error_add(GList* list, guint device_checksum, guint errortype)
+/**
+ * gems_connection_error_add:
+ * @list: A #GList containing pointers to #gems_connection_error structs
+ * @device_checksum: Checksum of the device to be added into error list
+ * @errortype: The classification of the error related to the device
+ *
+ * Add error to device with #device_checkum into given @list, if the device is
+ * found from the @list update information, otherwise add new device as 
+ * #gems_connection_error type struct with @errortype. Initialize timers for
+ * the device if the error is related to existing connection. For "plain"
+ * errors increase the counter for errors. 
+ *
+ * Returns: A pointer to the @list after modifications.
+ */
+GList* gems_connection_error_add(GList* list, guint device_checksum, GemsConnErrType errortype)
 {
 	gchar* logmsg = NULL;
 	gems_connection_error* item = NULL;
@@ -715,6 +1002,16 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 	return list;
 }
 
+/**
+ * gems_connection_error_get:
+ * @list: a #GList containing pointers to #gems_connection_error structs
+ * @device_checksum: device which error data is to be retrieved from @list
+ *
+ * Searches the given @list for occurances of devices with @device_checksum.
+ * Returns the error data or NULL if not found.
+ *
+ * Returns: A pointer to the error data or NULL if not found.
+ */
 gems_connection_error* gems_connection_error_get(GList* list, guint device_checksum)
 {
 	GList* iterator = NULL;
@@ -734,6 +1031,16 @@ gems_connection_error* gems_connection_error_get(GList* list, guint device_check
 	return NULL;	
 }
 
+/**
+ * gems_connection_error_get_connection_error_count:
+ * @list: a #GList containing pointers to #gems_connection_error structs
+ * @device_checksum: device which error data is to be retrieved from @list
+ *
+ * Get error count for given @device_checksum in the @list.
+ *
+ * Returns: Amount of connection errors for the device with #device_checksum. 0
+ * will be returned if not found.
+ */
 guint gems_connection_error_get_connection_error_count(GList* list, guint device_checksum)
 {
 	gems_connection_error* item = gems_connection_error_get(list,device_checksum);
@@ -741,6 +1048,20 @@ guint gems_connection_error_get_connection_error_count(GList* list, guint device
 	else return item->connection_errors;
 }
 
+/**
+ * gems_connection_error_attempt_connection:
+ * @list: a #GList containing pointers to #gems_connection_error structs
+ * @device_checksum: device which the connection is attempted to, searched from
+ * the @list
+ *
+ * Ask if the device with #device_checksum can be connected to. Will return
+ * FALSE if enough time has not passed from previous errorous attempt or the
+ * delay for existing connection is not passed. FALSE is returned always if the
+ * connection to device was previously rejected.
+ * 
+ * Returns: TRUE if the connection could be attempted, FALSE if it is a 
+ * rejected connection, or enough time has not passed.
+ */
 gboolean gems_connection_error_attempt_connection(GList* list, guint device_checksum)
 {
 	gems_connection_error* item = gems_connection_error_get(list,device_checksum);
@@ -785,6 +1106,17 @@ gboolean gems_connection_error_attempt_connection(GList* list, guint device_chec
 	return TRUE;
 }
 
+/**
+ * gems_connection_error_remove:
+ * @list: a #GList containing pointers to #gems_connection_error structs
+ * @device_checksum: Device to remove from the given errorlist @list
+ *
+ * Remove the error data of the device with #device_checksum from the given 
+ * @list. Usually called after a succesfull connection or the device has been
+ * in the list long enough.
+ *
+ * Returns: A pointer to given @list after processing.
+ */
 GList* gems_connection_error_remove(GList* list, guint device_checksum)
 {
 	GList* iterator = NULL;
@@ -814,6 +1146,14 @@ GList* gems_connection_error_remove(GList* list, guint device_checksum)
 	return list;
 }
 
+/**
+ * gems_clear_connection_error:
+ * @element: Connection error element to clear and free
+ *
+ * Clear and free the given connection error @element.
+ *
+ * Returns: void
+ */
 void gems_clear_connection_error(gems_connection_error* element)
 {
 	if(element == NULL) return;
@@ -823,6 +1163,15 @@ void gems_clear_connection_error(gems_connection_error* element)
 	return;
 }
 
+/**
+ * gems_process_rejected:
+ * @list: A #GList to be processed for rejected connections
+ *
+ * Remove rejected connections from @list which have been in the list for more
+ * than %REJECTED_LIST_REMOVE_LIMIT time.
+ * 
+ * Returns: A pointer to given @list after processing.
+ */
 GList* gems_process_rejected(GList* list)
 {
 	if(list == NULL) return NULL;
