@@ -18,6 +18,14 @@
 gchar** list_of_profiles = NULL;
 guint list_of_profiles_size = 0;
 
+/**
+ * gems_all_integer:
+ * @c: charstring to check
+ *
+ * Check if all characters in @c are digits.
+ *
+ * Returns: TRUE, all digits, FALSE, at least one is not digit.
+ */
 gboolean gems_all_integers(gchar* c)
 {
 	if(c == NULL) return FALSE;
@@ -26,6 +34,15 @@ gboolean gems_all_integers(gchar* c)
 	return TRUE;
 }
 
+/**
+ * gems_erase_newline:
+ * @c: charstring where newline is erased
+ *
+ * Erase newline marker from given charstring @c. Searches the charstring @c
+ * for newline marker and replaces it with NULL char.
+ *
+ * Returns: void
+ */
 void gems_erase_newline(gchar* c)
 {
 	if(c == NULL) return;
@@ -36,6 +53,16 @@ void gems_erase_newline(gchar* c)
 	if(pos) pos[0] = '\0'; 
 }
 
+/**
+ * gems_check_illegal_characters:
+ * @data: Charstring to check for illegal characters
+ *
+ * Checks if the given @data contains any illegal characters defined in 
+ * %ILLEGAL_CHARS.
+ *
+ * Returns: TRUE if at least one illegal character is found, FALSE if the
+ * @data is "clean".
+ */
 gboolean gems_check_illegal_characters(const gchar* data)
 {
 	if(data == NULL) return FALSE;
@@ -55,6 +82,17 @@ gboolean gems_check_illegal_characters(const gchar* data)
 	return FALSE;
 }
 
+/**
+ * gems_list_saved_profiles:
+ * @count: Amount of profiles in the returned list is stored into this variable
+ *
+ * Searches all compatible profiles from configure_get_jammo_directory()/
+ * %JAMMOPROFILE directory. The profile list is saved into static variable and
+ * is retrieved only once unless gems_free_list_saved_profiles() is called.
+ *
+ * Returns: A pointer array with @count amount of elements, each element is a
+ * profile username.
+ */
 gchar** gems_list_saved_profiles(guint* count)
 {
 	if(count == NULL) return FALSE;
@@ -146,6 +184,13 @@ gchar** gems_list_saved_profiles(guint* count)
 	return list_of_profiles;
 }
 
+/**
+ * gems_free_list_saved_profiles:
+ *
+ * Free the list of saved profiles.
+ *
+ * Returns: void
+ */
 void gems_free_list_saved_profiles()
 {
 	
@@ -158,6 +203,16 @@ void gems_free_list_saved_profiles()
 	}
 }
 
+/**
+ * gems_check_profile_version:
+ * @filename: Full path to profile file
+ *
+ * Check the version of the given profile @filename. Reads the first byte from
+ * the profile @filename and checks if it can be used with current application
+ * version.
+ *
+ * Returns: TRUE when profile with @filename is compatible, FALSE otherwise.
+ */
 gboolean gems_check_profile_version(gchar* filename)
 {
 	gboolean rval = FALSE;
@@ -189,12 +244,22 @@ gboolean gems_check_profile_version(gchar* filename)
 	return rval;
 }
 
-/*
- * Should guarantee that secret is erased from memory even with compiler optimizations 
- * From http://www.dwheeler.com/secure-programs/Secure-Programs-HOWTO/protect-secrets.html
+/**
+ * gems_guaranteed_memset:
+ * @data: Data to be changed
+ * @value: Value to set to @data
+ * @length: Amount of @value:s to set to @data
+ *
+ * A guaranteed memset, sets the @length amount of bytes of @data to @value.  
+ * Should guarantee that secret is erased from memory even with compiler
+ * optimizations, from: http://www.dwheeler.com/secure-programs/Secure-Programs-
+ * HOWTO/protect-secrets.html
+ *
+ * Returns: void* to @data
  */
 void *gems_guaranteed_memset(void *data, gint value, guint length)
 {
+	if(!data || length == 0) return data;
 	volatile gchar *buffer = data;
 	while(length--) *buffer++ = value;
 	return data;
