@@ -24,17 +24,17 @@ void mentor_send_log_message_to_teacher(char *message,int type)
 	if(gems_teacher_connection_is_connected()) 
 	{
 		element = data->teacher_connection->connection;
-		msg = gems_create_message_mentor_log_message(type, message);
+		msg = gems_create_message_mentor_log_message(LOG_MESSAGE, message);
 	
 		if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
 					{
 						logmsg = g_strdup_printf("Sending log message to teacher failed");
 						cem_add_to_log(logmsg,J_LOG_ERROR);
 						g_free(logmsg);
-						gems_clear_message(msg);
 					}
+		gems_clear_message(msg);
 	}	
 
 
-	gems_clear_message(msg);
+	
 }
