@@ -600,7 +600,7 @@ static void gst_jammo_looper_get_times (GstBaseSrc * basesrc, GstBuffer * buffer
 	GstJammoLooper * src = GST_JAMMO_LOOPER(basesrc);
 
 	GstClockTime timestamp = GST_BUFFER_TIMESTAMP (buffer);
-	src->time=timestamp/2;
+	src->time=timestamp;
   /* for live sources, sync on the timestamp of the buffer */
   if (gst_base_src_is_live (basesrc)) {
     
@@ -906,8 +906,8 @@ static void gst_jammo_looper_set_property (GObject * object, guint prop_id,
   	  	JammoLooperLoop * loop = g_value_get_pointer(value);
   	  	LooperLoop * add_loop = g_malloc(sizeof(LooperLoop));
   	  	memset(add_loop, 0, sizeof(LooperLoop));
-  	  	add_loop->start=loop->start;
-  	  	add_loop->original_start=loop->start;
+  	  	add_loop->start=loop->start*2; //This is needed. I don't know why.
+  	  	add_loop->original_start=loop->start; //This is not multiplied, it is used for removing samples
   	  	add_loop->filename=g_strdup(loop->filename);
   	  	open_loop_file(add_loop, src->tempo, src->pitch);
 	    	src->loops=g_list_insert_sorted(src->loops, add_loop, loop_compare);
