@@ -570,23 +570,23 @@ static gboolean gst_jammo_metronome_stop (GstBaseSrc * basesrc)
 static gboolean gst_jammo_metronome_do_seek (GstBaseSrc * basesrc, GstSegment * segment)
 {
   GstJammoMetronome *src = GST_JAMMO_METRONOME (basesrc);
-  GstClockTime time;
+  GstClockTime time_to_seek;
 
   segment->time = segment->start;
-  time = segment->last_stop;
+  time_to_seek = segment->last_stop;
 
   /* now move to the time indicated */
   src->next_sample =
-      gst_util_uint64_scale_int (time, src->samplerate, GST_SECOND);
+      gst_util_uint64_scale_int (time_to_seek, src->samplerate, GST_SECOND);
   src->next_byte = src->next_sample * src->sample_size;
   src->next_time =
       gst_util_uint64_scale_int (src->next_sample, GST_SECOND, src->samplerate);
 
-  g_assert (src->next_time <= time);
+  g_assert (src->next_time <= time_to_seek);
 
   if (GST_CLOCK_TIME_IS_VALID (segment->stop)) {
-    time = segment->stop;
-    src->sample_stop = gst_util_uint64_scale_int (time, src->samplerate,
+    time_to_seek = segment->stop;
+    src->sample_stop = gst_util_uint64_scale_int (time_to_seek, src->samplerate,
         GST_SECOND);
     src->check_seek_stop = TRUE;
   } else {
