@@ -14,6 +14,8 @@
 #include <string.h>
 
 #include <tangle.h> //For tangle_lookup_filename
+#include "../cem/cem.h"
+
 G_DEFINE_TYPE(JammoBackingTrack, jammo_backing_track, JAMMO_TYPE_PLAYING_TRACK);
 
 enum {
@@ -103,8 +105,9 @@ static guint64 jammo_backing_track_get_duration(JammoTrack* track) {
 	if (backing_track->priv->real_filename &&
 	    backing_track->priv->duration == JAMMO_DURATION_INVALID &&
 	    ((backing_track->priv->duration = jammo_meam_get_cached_duration(backing_track->priv->real_filename)) == JAMMO_DURATION_INVALID)) {
-		g_message("No cached duration for '%s', prerolling.", backing_track->priv->real_filename);
-
+		gchar* message = g_strdup_printf("No cached duration for backing-track-sample '%s', prerolling.", backing_track->priv->real_filename);
+		cem_add_to_log(message,J_LOG_WARN);
+		g_free(message);
 		preroll(backing_track);
 	}
 
