@@ -272,6 +272,8 @@ void jammo_slider_track_add_event(JammoSliderTrack* slider_track,float freq, Jam
 	new_event->timestamp = timestamp;
 	new_event->type = type;
 
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	g_object_set(G_OBJECT(slider_track->priv->slider), "add-event", new_event, NULL);
 	g_free(new_event);
 }
@@ -282,19 +284,27 @@ void jammo_slider_track_remove_event(JammoSliderTrack* slider_track,float freq,
 	new_event->type = type;
 	new_event->timestamp = timestamp;
 
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	g_object_set(G_OBJECT(slider_track->priv->slider), "remove-event", new_event, NULL);
 	g_free(new_event);
 }
 
 void jammo_slider_track_set_frequency_realtime(JammoSliderTrack* slider_track,float frequency){
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	jammo_slider_track_add_event(slider_track, frequency, JAMMO_SLIDER_EVENT_MOTION, 18446744073709551615ULL); //MAX
 }
 
 void jammo_slider_track_set_on_realtime(JammoSliderTrack* slider_track, float frequency){
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	jammo_slider_track_add_event(slider_track, frequency, JAMMO_SLIDER_EVENT_ON, 18446744073709551615ULL); //MAX
 }
 
 void jammo_slider_track_set_off_realtime(JammoSliderTrack* slider_track, float frequency){
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	jammo_slider_track_add_event(slider_track, frequency, JAMMO_SLIDER_EVENT_OFF, 18446744073709551615ULL); //MAX
 }
 
@@ -304,20 +314,29 @@ static void jammo_slider_track_init(JammoSliderTrack* slider_track) {
 
 GList * jammo_slider_track_get_event_list(JammoSliderTrack* slider_track) {
 	GList * eventlist;
+
+	g_return_val_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track), NULL);
+
 	g_object_get(G_OBJECT(slider_track->priv->slider),"eventlist", &eventlist, NULL);
 
 	return eventlist;
 }
 
 void jammo_slider_track_set_event_list(JammoSliderTrack* slider_track, GList* eventlist) {
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	g_object_set(G_OBJECT(slider_track->priv->slider),"eventlist", eventlist, NULL);
 }
 
 void jammo_slider_track_set_recording(JammoSliderTrack* slider_track, gboolean recording) {
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	g_object_set(G_OBJECT(slider_track->priv->slider),"recording", recording, NULL);
 }
 
 void jammo_slider_track_set_live(JammoSliderTrack* slider_track, gboolean state){
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	g_object_set(G_OBJECT(slider_track->priv->slider), "is-live", state, NULL);
 }
 
@@ -328,6 +347,8 @@ void jammo_slider_track_dump_events(JammoSliderTrack* slider_track){
 	GList* list= jammo_slider_track_get_event_list(JAMMO_SLIDER_TRACK(slider_track));
 	JammoSliderEvent* n;
 
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	printf("Track:\n");
 	for (; list; list = list->next) {
 			n = (list->data);
@@ -340,5 +361,7 @@ void jammo_slider_track_dump_events(JammoSliderTrack* slider_track){
 	Clears event list of sampler. All recorded and added events are lost.
 **/
 void jammo_slider_track_clear_events(JammoSliderTrack* slider_track) {
+	g_return_if_fail(JAMMO_IS_SLIDER_TRACK(slider_track));
+
 	g_object_set(slider_track->priv->slider, "clear-events", TRUE, NULL);
 }
