@@ -57,14 +57,14 @@ int main(int argc, char** argv) {
 	play_button = tangle_button_new();
 
 	clutter_actor_set_position(play_button, 100.0, 400.0);
-	tangle_widget_add_after(TANGLE_WIDGET(play_button), clutter_texture_new_from_file("test_image_100x74.jpg", NULL), NULL, NULL, NULL);
+	tangle_widget_add_after(TANGLE_WIDGET(play_button), tangle_texture_new("test_image_100x74.jpg"), NULL, NULL, NULL);
 	g_signal_connect(play_button, "clicked", G_CALLBACK(on_play_button_clicked), sequencer);
 	clutter_container_add(CLUTTER_CONTAINER(stage), play_button, NULL);
 
 	stop_button = tangle_button_new();
 
 	clutter_actor_set_position(stop_button, 300.0, 400.0);
-	tangle_widget_add_after(TANGLE_WIDGET(stop_button), clutter_texture_new_from_file("test_image_100x74.jpg", NULL), NULL, NULL, NULL);
+	tangle_widget_add_after(TANGLE_WIDGET(stop_button), tangle_texture_new("test_image_100x74.jpg"), NULL, NULL, NULL);
 	g_signal_connect(stop_button, "clicked", G_CALLBACK(on_stop_button_clicked), sequencer);
 	clutter_container_add(CLUTTER_CONTAINER(stage), stop_button, NULL);
 
